Class: Spatio::AccountListResponse

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/account_list_response.rb

Overview

‘GET /v1/accounts` returns `total_accounts` on production today. Schema kept open until the consumers migrate to a flat `accounts` array.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AccountListResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/spatio-sdk/models/account_list_response.rb', line 62

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::AccountListResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::AccountListResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'accounts_by_platform')
    if (value = attributes[:'accounts_by_platform']).is_a?(Hash)
      self.accounts_by_platform = value
    end
  end

  if attributes.key?(:'total_accounts')
    self.total_accounts = attributes[:'total_accounts']
  end

  if attributes.key?(:'accounts')
    if (value = attributes[:'accounts']).is_a?(Array)
      self.accounts = value
    end
  end
end

Instance Attribute Details

#accountsObject

Returns the value of attribute accounts.



23
24
25
# File 'lib/spatio-sdk/models/account_list_response.rb', line 23

def accounts
  @accounts
end

#accounts_by_platformObject

Returns the value of attribute accounts_by_platform.



19
20
21
# File 'lib/spatio-sdk/models/account_list_response.rb', line 19

def accounts_by_platform
  @accounts_by_platform
end

#total_accountsObject

Returns the value of attribute total_accounts.



21
22
23
# File 'lib/spatio-sdk/models/account_list_response.rb', line 21

def total_accounts
  @total_accounts
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



35
36
37
# File 'lib/spatio-sdk/models/account_list_response.rb', line 35

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



40
41
42
# File 'lib/spatio-sdk/models/account_list_response.rb', line 40

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



26
27
28
29
30
31
32
# File 'lib/spatio-sdk/models/account_list_response.rb', line 26

def self.attribute_map
  {
    :'accounts_by_platform' => :'accounts_by_platform',
    :'total_accounts' => :'total_accounts',
    :'accounts' => :'accounts'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/spatio-sdk/models/account_list_response.rb', line 133

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



54
55
56
57
58
# File 'lib/spatio-sdk/models/account_list_response.rb', line 54

def self.openapi_nullable
  Set.new([
    :'accounts'
  ])
end

.openapi_typesObject

Attribute type mapping.



45
46
47
48
49
50
51
# File 'lib/spatio-sdk/models/account_list_response.rb', line 45

def self.openapi_types
  {
    :'accounts_by_platform' => :'Hash<String, Object>',
    :'total_accounts' => :'Integer',
    :'accounts' => :'Array<Hash>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



110
111
112
113
114
115
116
# File 'lib/spatio-sdk/models/account_list_response.rb', line 110

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      accounts_by_platform == o.accounts_by_platform &&
      total_accounts == o.total_accounts &&
      accounts == o.accounts
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


120
121
122
# File 'lib/spatio-sdk/models/account_list_response.rb', line 120

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



126
127
128
# File 'lib/spatio-sdk/models/account_list_response.rb', line 126

def hash
  [accounts_by_platform, total_accounts, accounts].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



95
96
97
98
99
# File 'lib/spatio-sdk/models/account_list_response.rb', line 95

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/spatio-sdk/models/account_list_response.rb', line 155

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



103
104
105
106
# File 'lib/spatio-sdk/models/account_list_response.rb', line 103

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end