Class: Spatio::ActionDescriptor

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/action_descriptor.rb

Overview

Action manifest entry surfaced by the agent platform. The ‘inputType`/`outputType` references point at internal Go types; treat them as opaque labels.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ActionDescriptor

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/spatio-sdk/models/action_descriptor.rb', line 81

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::ActionDescriptor` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::ActionDescriptor`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'canonical_id')
    self.canonical_id = attributes[:'canonical_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  end

  if attributes.key?(:'input_type')
    self.input_type = attributes[:'input_type']
  end

  if attributes.key?(:'output_type')
    self.output_type = attributes[:'output_type']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end
end

Instance Attribute Details

#canonical_idObject

Returns the value of attribute canonical_id.



21
22
23
# File 'lib/spatio-sdk/models/action_descriptor.rb', line 21

def canonical_id
  @canonical_id
end

#categoryObject

Returns the value of attribute category.



27
28
29
# File 'lib/spatio-sdk/models/action_descriptor.rb', line 27

def category
  @category
end

#descriptionObject

Returns the value of attribute description.



25
26
27
# File 'lib/spatio-sdk/models/action_descriptor.rb', line 25

def description
  @description
end

#idObject

Returns the value of attribute id.



19
20
21
# File 'lib/spatio-sdk/models/action_descriptor.rb', line 19

def id
  @id
end

#input_typeObject

Returns the value of attribute input_type.



29
30
31
# File 'lib/spatio-sdk/models/action_descriptor.rb', line 29

def input_type
  @input_type
end

#metadataObject

Returns the value of attribute metadata.



33
34
35
# File 'lib/spatio-sdk/models/action_descriptor.rb', line 33

def 
  @metadata
end

#nameObject

Returns the value of attribute name.



23
24
25
# File 'lib/spatio-sdk/models/action_descriptor.rb', line 23

def name
  @name
end

#output_typeObject

Returns the value of attribute output_type.



31
32
33
# File 'lib/spatio-sdk/models/action_descriptor.rb', line 31

def output_type
  @output_type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



50
51
52
# File 'lib/spatio-sdk/models/action_descriptor.rb', line 50

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/spatio-sdk/models/action_descriptor.rb', line 55

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
46
47
# File 'lib/spatio-sdk/models/action_descriptor.rb', line 36

def self.attribute_map
  {
    :'id' => :'id',
    :'canonical_id' => :'canonical_id',
    :'name' => :'name',
    :'description' => :'description',
    :'category' => :'category',
    :'input_type' => :'inputType',
    :'output_type' => :'outputType',
    :'metadata' => :'metadata'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/spatio-sdk/models/action_descriptor.rb', line 192

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



74
75
76
77
# File 'lib/spatio-sdk/models/action_descriptor.rb', line 74

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/spatio-sdk/models/action_descriptor.rb', line 60

def self.openapi_types
  {
    :'id' => :'String',
    :'canonical_id' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'category' => :'String',
    :'input_type' => :'String',
    :'output_type' => :'String',
    :'metadata' => :'Hash<String, Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/spatio-sdk/models/action_descriptor.rb', line 164

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      canonical_id == o.canonical_id &&
      name == o.name &&
      description == o.description &&
      category == o.category &&
      input_type == o.input_type &&
      output_type == o.output_type &&
       == o.
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


179
180
181
# File 'lib/spatio-sdk/models/action_descriptor.rb', line 179

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



185
186
187
# File 'lib/spatio-sdk/models/action_descriptor.rb', line 185

def hash
  [id, canonical_id, name, description, category, input_type, output_type, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



134
135
136
137
138
139
140
141
142
# File 'lib/spatio-sdk/models/action_descriptor.rb', line 134

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/spatio-sdk/models/action_descriptor.rb', line 214

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



146
147
148
149
150
# File 'lib/spatio-sdk/models/action_descriptor.rb', line 146

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  true
end