Class: Spatio::Block

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/block.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Block

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/spatio-sdk/models/block.rb', line 112

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::Block` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::Block`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'note_id')
    self.note_id = attributes[:'note_id']
  else
    self.note_id = nil
  end

  if attributes.key?(:'parent_id')
    self.parent_id = attributes[:'parent_id']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'content')
    self.content = attributes[:'content']
  else
    self.content = nil
  end

  if attributes.key?(:'properties')
    if (value = attributes[:'properties']).is_a?(Hash)
      self.properties = value
    end
  end

  if attributes.key?(:'position')
    self.position = attributes[:'position']
  else
    self.position = nil
  end

  if attributes.key?(:'has_children')
    self.has_children = attributes[:'has_children']
  else
    self.has_children = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end
end

Instance Attribute Details

#contentObject

Returns the value of attribute content.



26
27
28
# File 'lib/spatio-sdk/models/block.rb', line 26

def content
  @content
end

#created_atObject

Returns the value of attribute created_at.



35
36
37
# File 'lib/spatio-sdk/models/block.rb', line 35

def created_at
  @created_at
end

#has_childrenObject

Returns the value of attribute has_children.



33
34
35
# File 'lib/spatio-sdk/models/block.rb', line 33

def has_children
  @has_children
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/spatio-sdk/models/block.rb', line 18

def id
  @id
end

#note_idObject

Returns the value of attribute note_id.



20
21
22
# File 'lib/spatio-sdk/models/block.rb', line 20

def note_id
  @note_id
end

#parent_idObject

Returns the value of attribute parent_id.



22
23
24
# File 'lib/spatio-sdk/models/block.rb', line 22

def parent_id
  @parent_id
end

#positionObject

Order within the parent (0-indexed).



31
32
33
# File 'lib/spatio-sdk/models/block.rb', line 31

def position
  @position
end

#propertiesObject

Returns the value of attribute properties.



28
29
30
# File 'lib/spatio-sdk/models/block.rb', line 28

def properties
  @properties
end

#typeObject

Returns the value of attribute type.



24
25
26
# File 'lib/spatio-sdk/models/block.rb', line 24

def type
  @type
end

#updated_atObject

Returns the value of attribute updated_at.



37
38
39
# File 'lib/spatio-sdk/models/block.rb', line 37

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



78
79
80
# File 'lib/spatio-sdk/models/block.rb', line 78

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



83
84
85
# File 'lib/spatio-sdk/models/block.rb', line 83

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/spatio-sdk/models/block.rb', line 62

def self.attribute_map
  {
    :'id' => :'id',
    :'note_id' => :'noteId',
    :'parent_id' => :'parentId',
    :'type' => :'type',
    :'content' => :'content',
    :'properties' => :'properties',
    :'position' => :'position',
    :'has_children' => :'hasChildren',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
# File 'lib/spatio-sdk/models/block.rb', line 352

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



104
105
106
107
108
# File 'lib/spatio-sdk/models/block.rb', line 104

def self.openapi_nullable
  Set.new([
    :'parent_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/spatio-sdk/models/block.rb', line 88

def self.openapi_types
  {
    :'id' => :'String',
    :'note_id' => :'String',
    :'parent_id' => :'String',
    :'type' => :'BlockType',
    :'content' => :'BlockContent',
    :'properties' => :'Hash<String, Object>',
    :'position' => :'Integer',
    :'has_children' => :'Boolean',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/spatio-sdk/models/block.rb', line 322

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      note_id == o.note_id &&
      parent_id == o.parent_id &&
      type == o.type &&
      content == o.content &&
      properties == o.properties &&
      position == o.position &&
      has_children == o.has_children &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


339
340
341
# File 'lib/spatio-sdk/models/block.rb', line 339

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



345
346
347
# File 'lib/spatio-sdk/models/block.rb', line 345

def hash
  [id, note_id, parent_id, type, content, properties, position, has_children, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/spatio-sdk/models/block.rb', line 187

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @note_id.nil?
    invalid_properties.push('invalid value for "note_id", note_id cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @content.nil?
    invalid_properties.push('invalid value for "content", content cannot be nil.')
  end

  if @position.nil?
    invalid_properties.push('invalid value for "position", position cannot be nil.')
  end

  if @has_children.nil?
    invalid_properties.push('invalid value for "has_children", has_children cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



374
375
376
377
378
379
380
381
382
383
384
385
386
# File 'lib/spatio-sdk/models/block.rb', line 374

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/spatio-sdk/models/block.rb', line 227

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @note_id.nil?
  return false if @type.nil?
  return false if @content.nil?
  return false if @position.nil?
  return false if @has_children.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  true
end