Class: Spatio::BlockContent

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/block_content.rb

Overview

Type-specific payload for a block. Fields populated depend on ‘Block.type`. All fields are optional at the schema level; the runtime enforces the per-type contract. Note: this object uses snake_case keys to match the JSON the Go `providers.BlockContent` struct emits and accepts. Other parts of the SpatioAPI use camelCase; blocks are the exception because the block model is shared with external Notion-like providers whose canonical wire format is snake_case.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BlockContent

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/spatio-sdk/models/block_content.rb', line 103

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::BlockContent` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::BlockContent`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'rich_text')
    if (value = attributes[:'rich_text']).is_a?(Array)
      self.rich_text = value
    end
  end

  if attributes.key?(:'language')
    self.language = attributes[:'language']
  end

  if attributes.key?(:'checked')
    self.checked = attributes[:'checked']
  end

  if attributes.key?(:'icon')
    self.icon = attributes[:'icon']
  end

  if attributes.key?(:'color')
    self.color = attributes[:'color']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'caption')
    self.caption = attributes[:'caption']
  end

  if attributes.key?(:'alt_text')
    self.alt_text = attributes[:'alt_text']
  end

  if attributes.key?(:'embed_url')
    self.embed_url = attributes[:'embed_url']
  end

  if attributes.key?(:'cells')
    if (value = attributes[:'cells']).is_a?(Array)
      self.cells = value
    end
  end

  if attributes.key?(:'expression')
    self.expression = attributes[:'expression']
  end
end

Instance Attribute Details

#alt_textObject

Screen-reader description for media blocks. Distinct from ‘caption` (visible to readers) — required for accessible notes when the image conveys meaning.



40
41
42
# File 'lib/spatio-sdk/models/block_content.rb', line 40

def alt_text
  @alt_text
end

#captionObject

Visible caption for media blocks.



37
38
39
# File 'lib/spatio-sdk/models/block_content.rb', line 37

def caption
  @caption
end

#cellsObject

2D rich-text grid for ‘table` and `table_row` blocks.



46
47
48
# File 'lib/spatio-sdk/models/block_content.rb', line 46

def cells
  @cells
end

#checkedObject

Toggle state for ‘to_do` blocks.



25
26
27
# File 'lib/spatio-sdk/models/block_content.rb', line 25

def checked
  @checked
end

#colorObject

Theme color for ‘callout` blocks.



31
32
33
# File 'lib/spatio-sdk/models/block_content.rb', line 31

def color
  @color
end

#embed_urlObject

Source URL for ‘embed` blocks.



43
44
45
# File 'lib/spatio-sdk/models/block_content.rb', line 43

def embed_url
  @embed_url
end

#expressionObject

TeX/MathJax expression for ‘equation` blocks.



49
50
51
# File 'lib/spatio-sdk/models/block_content.rb', line 49

def expression
  @expression
end

#iconObject

Emoji or short string for ‘callout` blocks.



28
29
30
# File 'lib/spatio-sdk/models/block_content.rb', line 28

def icon
  @icon
end

#languageObject

Programming language for ‘code` blocks.



22
23
24
# File 'lib/spatio-sdk/models/block_content.rb', line 22

def language
  @language
end

#rich_textObject

Returns the value of attribute rich_text.



19
20
21
# File 'lib/spatio-sdk/models/block_content.rb', line 19

def rich_text
  @rich_text
end

#urlObject

Source URL for ‘image`, `video`, `file` blocks.



34
35
36
# File 'lib/spatio-sdk/models/block_content.rb', line 34

def url
  @url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



69
70
71
# File 'lib/spatio-sdk/models/block_content.rb', line 69

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/spatio-sdk/models/block_content.rb', line 74

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/spatio-sdk/models/block_content.rb', line 52

def self.attribute_map
  {
    :'rich_text' => :'rich_text',
    :'language' => :'language',
    :'checked' => :'checked',
    :'icon' => :'icon',
    :'color' => :'color',
    :'url' => :'url',
    :'caption' => :'caption',
    :'alt_text' => :'alt_text',
    :'embed_url' => :'embed_url',
    :'cells' => :'cells',
    :'expression' => :'expression'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/spatio-sdk/models/block_content.rb', line 214

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



96
97
98
99
# File 'lib/spatio-sdk/models/block_content.rb', line 96

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/spatio-sdk/models/block_content.rb', line 79

def self.openapi_types
  {
    :'rich_text' => :'Array<RichTextObject>',
    :'language' => :'String',
    :'checked' => :'Boolean',
    :'icon' => :'String',
    :'color' => :'String',
    :'url' => :'String',
    :'caption' => :'String',
    :'alt_text' => :'String',
    :'embed_url' => :'String',
    :'cells' => :'Array<Array<RichTextObject>>',
    :'expression' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/spatio-sdk/models/block_content.rb', line 183

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      rich_text == o.rich_text &&
      language == o.language &&
      checked == o.checked &&
      icon == o.icon &&
      color == o.color &&
      url == o.url &&
      caption == o.caption &&
      alt_text == o.alt_text &&
      embed_url == o.embed_url &&
      cells == o.cells &&
      expression == o.expression
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


201
202
203
# File 'lib/spatio-sdk/models/block_content.rb', line 201

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



207
208
209
# File 'lib/spatio-sdk/models/block_content.rb', line 207

def hash
  [rich_text, language, checked, icon, color, url, caption, alt_text, embed_url, cells, expression].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



168
169
170
171
172
# File 'lib/spatio-sdk/models/block_content.rb', line 168

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/spatio-sdk/models/block_content.rb', line 236

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



176
177
178
179
# File 'lib/spatio-sdk/models/block_content.rb', line 176

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end