Class: Spatio::BulkDeleteTasksRequest

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/bulk_delete_tasks_request.rb

Overview

Either populate ‘taskIds` (with optional parallel `accountIds`) for multi-task delete, or `taskId` (with optional `accountId`) for the single-task fallback. `taskIds` wins when both are set.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BulkDeleteTasksRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/spatio-sdk/models/bulk_delete_tasks_request.rb', line 67

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::BulkDeleteTasksRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::BulkDeleteTasksRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'task_ids')
    if (value = attributes[:'task_ids']).is_a?(Array)
      self.task_ids = value
    end
  end

  if attributes.key?(:'account_ids')
    if (value = attributes[:'account_ids']).is_a?(Array)
      self. = value
    end
  end

  if attributes.key?(:'task_id')
    self.task_id = attributes[:'task_id']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



27
28
29
# File 'lib/spatio-sdk/models/bulk_delete_tasks_request.rb', line 27

def 
  @account_id
end

#account_idsObject

Parallel slice with taskIds — accountIds targets taskIds.



22
23
24
# File 'lib/spatio-sdk/models/bulk_delete_tasks_request.rb', line 22

def 
  @account_ids
end

#task_idObject

Singular fallback when only deleting one task.



25
26
27
# File 'lib/spatio-sdk/models/bulk_delete_tasks_request.rb', line 25

def task_id
  @task_id
end

#task_idsObject

Returns the value of attribute task_ids.



19
20
21
# File 'lib/spatio-sdk/models/bulk_delete_tasks_request.rb', line 19

def task_ids
  @task_ids
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



40
41
42
# File 'lib/spatio-sdk/models/bulk_delete_tasks_request.rb', line 40

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



45
46
47
# File 'lib/spatio-sdk/models/bulk_delete_tasks_request.rb', line 45

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



30
31
32
33
34
35
36
37
# File 'lib/spatio-sdk/models/bulk_delete_tasks_request.rb', line 30

def self.attribute_map
  {
    :'task_ids' => :'taskIds',
    :'account_ids' => :'accountIds',
    :'task_id' => :'taskId',
    :'account_id' => :'accountId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/spatio-sdk/models/bulk_delete_tasks_request.rb', line 143

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



60
61
62
63
# File 'lib/spatio-sdk/models/bulk_delete_tasks_request.rb', line 60

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



50
51
52
53
54
55
56
57
# File 'lib/spatio-sdk/models/bulk_delete_tasks_request.rb', line 50

def self.openapi_types
  {
    :'task_ids' => :'Array<String>',
    :'account_ids' => :'Array<String>',
    :'task_id' => :'String',
    :'account_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



119
120
121
122
123
124
125
126
# File 'lib/spatio-sdk/models/bulk_delete_tasks_request.rb', line 119

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      task_ids == o.task_ids &&
       == o. &&
      task_id == o.task_id &&
       == o.
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


130
131
132
# File 'lib/spatio-sdk/models/bulk_delete_tasks_request.rb', line 130

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



136
137
138
# File 'lib/spatio-sdk/models/bulk_delete_tasks_request.rb', line 136

def hash
  [task_ids, , task_id, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



104
105
106
107
108
# File 'lib/spatio-sdk/models/bulk_delete_tasks_request.rb', line 104

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/spatio-sdk/models/bulk_delete_tasks_request.rb', line 165

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



112
113
114
115
# File 'lib/spatio-sdk/models/bulk_delete_tasks_request.rb', line 112

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end