Class: Spatio::CalendarOperationResult
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Spatio::CalendarOperationResult
- Defined in:
- lib/spatio-sdk/models/calendar_operation_result.rb
Overview
Generic platform-operation envelope used by Calendar list/create/ update/delete responses. ‘data` is operation-specific: - listEvents: `ListEventsData` - createEvent / updateEvent: `Event` - deleteEvent: empty / metadata-only
Instance Attribute Summary collapse
-
#data ⇒ Object
Operation-specific payload.
-
#errors ⇒ Object
Returns the value of attribute errors.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#success ⇒ Object
Returns the value of attribute success.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CalendarOperationResult
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CalendarOperationResult
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/spatio-sdk/models/calendar_operation_result.rb', line 67 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::CalendarOperationResult` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::CalendarOperationResult`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'success') self.success = attributes[:'success'] else self.success = nil end if attributes.key?(:'data') self.data = attributes[:'data'] end if attributes.key?(:'errors') if (value = attributes[:'errors']).is_a?(Array) self.errors = value end end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end end |
Instance Attribute Details
#data ⇒ Object
Operation-specific payload. See the operation’s response description for the concrete shape.
22 23 24 |
# File 'lib/spatio-sdk/models/calendar_operation_result.rb', line 22 def data @data end |
#errors ⇒ Object
Returns the value of attribute errors.
24 25 26 |
# File 'lib/spatio-sdk/models/calendar_operation_result.rb', line 24 def errors @errors end |
#metadata ⇒ Object
Returns the value of attribute metadata.
26 27 28 |
# File 'lib/spatio-sdk/models/calendar_operation_result.rb', line 26 def @metadata end |
#success ⇒ Object
Returns the value of attribute success.
19 20 21 |
# File 'lib/spatio-sdk/models/calendar_operation_result.rb', line 19 def success @success end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
39 40 41 |
# File 'lib/spatio-sdk/models/calendar_operation_result.rb', line 39 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
44 45 46 |
# File 'lib/spatio-sdk/models/calendar_operation_result.rb', line 44 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 |
# File 'lib/spatio-sdk/models/calendar_operation_result.rb', line 29 def self.attribute_map { :'success' => :'success', :'data' => :'data', :'errors' => :'errors', :'metadata' => :'metadata' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/spatio-sdk/models/calendar_operation_result.rb', line 160 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
59 60 61 62 63 |
# File 'lib/spatio-sdk/models/calendar_operation_result.rb', line 59 def self.openapi_nullable Set.new([ :'data', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
49 50 51 52 53 54 55 56 |
# File 'lib/spatio-sdk/models/calendar_operation_result.rb', line 49 def self.openapi_types { :'success' => :'Boolean', :'data' => :'Object', :'errors' => :'Array<CalendarAccountError>', :'metadata' => :'Hash<String, Object>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
136 137 138 139 140 141 142 143 |
# File 'lib/spatio-sdk/models/calendar_operation_result.rb', line 136 def ==(o) return true if self.equal?(o) self.class == o.class && success == o.success && data == o.data && errors == o.errors && == o. end |
#eql?(o) ⇒ Boolean
147 148 149 |
# File 'lib/spatio-sdk/models/calendar_operation_result.rb', line 147 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
153 154 155 |
# File 'lib/spatio-sdk/models/calendar_operation_result.rb', line 153 def hash [success, data, errors, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
106 107 108 109 110 111 112 113 114 |
# File 'lib/spatio-sdk/models/calendar_operation_result.rb', line 106 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @success.nil? invalid_properties.push('invalid value for "success", success cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/spatio-sdk/models/calendar_operation_result.rb', line 182 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
118 119 120 121 122 |
# File 'lib/spatio-sdk/models/calendar_operation_result.rb', line 118 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @success.nil? true end |