Class: Spatio::ChatUser

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/chat_user.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ChatUser

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/spatio-sdk/models/chat_user.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::ChatUser` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::ChatUser`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'provider')
    self.provider = attributes[:'provider']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'real_name')
    self.real_name = attributes[:'real_name']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'avatar')
    self.avatar = attributes[:'avatar']
  end

  if attributes.key?(:'is_bot')
    self.is_bot = attributes[:'is_bot']
  else
    self.is_bot = nil
  end

  if attributes.key?(:'is_active')
    self.is_active = attributes[:'is_active']
  else
    self.is_active = nil
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



22
23
24
# File 'lib/spatio-sdk/models/chat_user.rb', line 22

def 
  @account_id
end

#avatarObject

Returns the value of attribute avatar.



30
31
32
# File 'lib/spatio-sdk/models/chat_user.rb', line 30

def avatar
  @avatar
end

#emailObject

Returns the value of attribute email.



28
29
30
# File 'lib/spatio-sdk/models/chat_user.rb', line 28

def email
  @email
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/spatio-sdk/models/chat_user.rb', line 18

def id
  @id
end

#is_activeObject

Returns the value of attribute is_active.



34
35
36
# File 'lib/spatio-sdk/models/chat_user.rb', line 34

def is_active
  @is_active
end

#is_botObject

Returns the value of attribute is_bot.



32
33
34
# File 'lib/spatio-sdk/models/chat_user.rb', line 32

def is_bot
  @is_bot
end

#nameObject

Returns the value of attribute name.



24
25
26
# File 'lib/spatio-sdk/models/chat_user.rb', line 24

def name
  @name
end

#providerObject

Returns the value of attribute provider.



20
21
22
# File 'lib/spatio-sdk/models/chat_user.rb', line 20

def provider
  @provider
end

#real_nameObject

Returns the value of attribute real_name.



26
27
28
# File 'lib/spatio-sdk/models/chat_user.rb', line 26

def real_name
  @real_name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



52
53
54
# File 'lib/spatio-sdk/models/chat_user.rb', line 52

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



57
58
59
# File 'lib/spatio-sdk/models/chat_user.rb', line 57

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/spatio-sdk/models/chat_user.rb', line 37

def self.attribute_map
  {
    :'id' => :'id',
    :'provider' => :'provider',
    :'account_id' => :'accountId',
    :'name' => :'name',
    :'real_name' => :'realName',
    :'email' => :'email',
    :'avatar' => :'avatar',
    :'is_bot' => :'isBot',
    :'is_active' => :'isActive'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/spatio-sdk/models/chat_user.rb', line 249

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



77
78
79
80
# File 'lib/spatio-sdk/models/chat_user.rb', line 77

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/spatio-sdk/models/chat_user.rb', line 62

def self.openapi_types
  {
    :'id' => :'String',
    :'provider' => :'String',
    :'account_id' => :'String',
    :'name' => :'String',
    :'real_name' => :'String',
    :'email' => :'String',
    :'avatar' => :'String',
    :'is_bot' => :'Boolean',
    :'is_active' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/spatio-sdk/models/chat_user.rb', line 220

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      provider == o.provider &&
       == o. &&
      name == o.name &&
      real_name == o.real_name &&
      email == o.email &&
      avatar == o.avatar &&
      is_bot == o.is_bot &&
      is_active == o.is_active
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


236
237
238
# File 'lib/spatio-sdk/models/chat_user.rb', line 236

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



242
243
244
# File 'lib/spatio-sdk/models/chat_user.rb', line 242

def hash
  [id, provider, , name, real_name, email, avatar, is_bot, is_active].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/spatio-sdk/models/chat_user.rb', line 145

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @is_bot.nil?
    invalid_properties.push('invalid value for "is_bot", is_bot cannot be nil.')
  end

  if @is_active.nil?
    invalid_properties.push('invalid value for "is_active", is_active cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/spatio-sdk/models/chat_user.rb', line 271

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



169
170
171
172
173
174
175
176
# File 'lib/spatio-sdk/models/chat_user.rb', line 169

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @is_bot.nil?
  return false if @is_active.nil?
  true
end