Class: Spatio::ChunkedFileManifest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Spatio::ChunkedFileManifest
- Defined in:
- lib/spatio-sdk/models/chunked_file_manifest.rb
Overview
Block-level manifest for a chunked-uploaded file. Returned by ‘GET /v1/files/id/manifest`. Only meaningful for files uploaded via the chunked path; legacy uploads return `404`.
Instance Attribute Summary collapse
-
#block_count ⇒ Object
Returns the value of attribute block_count.
-
#blocks ⇒ Object
Returns the value of attribute blocks.
-
#chunking_algorithm ⇒ Object
Returns the value of attribute chunking_algorithm.
-
#file_checksum ⇒ Object
Returns the value of attribute file_checksum.
-
#file_id ⇒ Object
Returns the value of attribute file_id.
-
#file_name ⇒ Object
Returns the value of attribute file_name.
-
#manifest_id ⇒ Object
Returns the value of attribute manifest_id.
-
#total_size ⇒ Object
Returns the value of attribute total_size.
-
#version ⇒ Object
Returns the value of attribute version.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ChunkedFileManifest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ChunkedFileManifest
Initializes the object
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/spatio-sdk/models/chunked_file_manifest.rb', line 85 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::ChunkedFileManifest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::ChunkedFileManifest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'manifest_id') self.manifest_id = attributes[:'manifest_id'] else self.manifest_id = nil end if attributes.key?(:'file_id') self.file_id = attributes[:'file_id'] else self.file_id = nil end if attributes.key?(:'file_name') self.file_name = attributes[:'file_name'] else self.file_name = nil end if attributes.key?(:'version') self.version = attributes[:'version'] else self.version = nil end if attributes.key?(:'total_size') self.total_size = attributes[:'total_size'] else self.total_size = nil end if attributes.key?(:'block_count') self.block_count = attributes[:'block_count'] else self.block_count = nil end if attributes.key?(:'chunking_algorithm') self.chunking_algorithm = attributes[:'chunking_algorithm'] end if attributes.key?(:'file_checksum') self.file_checksum = attributes[:'file_checksum'] end if attributes.key?(:'blocks') if (value = attributes[:'blocks']).is_a?(Array) self.blocks = value end end end |
Instance Attribute Details
#block_count ⇒ Object
Returns the value of attribute block_count.
29 30 31 |
# File 'lib/spatio-sdk/models/chunked_file_manifest.rb', line 29 def block_count @block_count end |
#blocks ⇒ Object
Returns the value of attribute blocks.
35 36 37 |
# File 'lib/spatio-sdk/models/chunked_file_manifest.rb', line 35 def blocks @blocks end |
#chunking_algorithm ⇒ Object
Returns the value of attribute chunking_algorithm.
31 32 33 |
# File 'lib/spatio-sdk/models/chunked_file_manifest.rb', line 31 def chunking_algorithm @chunking_algorithm end |
#file_checksum ⇒ Object
Returns the value of attribute file_checksum.
33 34 35 |
# File 'lib/spatio-sdk/models/chunked_file_manifest.rb', line 33 def file_checksum @file_checksum end |
#file_id ⇒ Object
Returns the value of attribute file_id.
21 22 23 |
# File 'lib/spatio-sdk/models/chunked_file_manifest.rb', line 21 def file_id @file_id end |
#file_name ⇒ Object
Returns the value of attribute file_name.
23 24 25 |
# File 'lib/spatio-sdk/models/chunked_file_manifest.rb', line 23 def file_name @file_name end |
#manifest_id ⇒ Object
Returns the value of attribute manifest_id.
19 20 21 |
# File 'lib/spatio-sdk/models/chunked_file_manifest.rb', line 19 def manifest_id @manifest_id end |
#total_size ⇒ Object
Returns the value of attribute total_size.
27 28 29 |
# File 'lib/spatio-sdk/models/chunked_file_manifest.rb', line 27 def total_size @total_size end |
#version ⇒ Object
Returns the value of attribute version.
25 26 27 |
# File 'lib/spatio-sdk/models/chunked_file_manifest.rb', line 25 def version @version end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
53 54 55 |
# File 'lib/spatio-sdk/models/chunked_file_manifest.rb', line 53 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/spatio-sdk/models/chunked_file_manifest.rb', line 58 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/spatio-sdk/models/chunked_file_manifest.rb', line 38 def self.attribute_map { :'manifest_id' => :'manifestId', :'file_id' => :'fileId', :'file_name' => :'fileName', :'version' => :'version', :'total_size' => :'totalSize', :'block_count' => :'blockCount', :'chunking_algorithm' => :'chunkingAlgorithm', :'file_checksum' => :'fileChecksum', :'blocks' => :'blocks' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/spatio-sdk/models/chunked_file_manifest.rb', line 286 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
78 79 80 81 |
# File 'lib/spatio-sdk/models/chunked_file_manifest.rb', line 78 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/spatio-sdk/models/chunked_file_manifest.rb', line 63 def self.openapi_types { :'manifest_id' => :'String', :'file_id' => :'String', :'file_name' => :'String', :'version' => :'Integer', :'total_size' => :'Integer', :'block_count' => :'Integer', :'chunking_algorithm' => :'String', :'file_checksum' => :'String', :'blocks' => :'Array<Hash<String, Object>>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/spatio-sdk/models/chunked_file_manifest.rb', line 257 def ==(o) return true if self.equal?(o) self.class == o.class && manifest_id == o.manifest_id && file_id == o.file_id && file_name == o.file_name && version == o.version && total_size == o.total_size && block_count == o.block_count && chunking_algorithm == o.chunking_algorithm && file_checksum == o.file_checksum && blocks == o.blocks end |
#eql?(o) ⇒ Boolean
273 274 275 |
# File 'lib/spatio-sdk/models/chunked_file_manifest.rb', line 273 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
279 280 281 |
# File 'lib/spatio-sdk/models/chunked_file_manifest.rb', line 279 def hash [manifest_id, file_id, file_name, version, total_size, block_count, chunking_algorithm, file_checksum, blocks].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/spatio-sdk/models/chunked_file_manifest.rb', line 152 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @manifest_id.nil? invalid_properties.push('invalid value for "manifest_id", manifest_id cannot be nil.') end if @file_id.nil? invalid_properties.push('invalid value for "file_id", file_id cannot be nil.') end if @file_name.nil? invalid_properties.push('invalid value for "file_name", file_name cannot be nil.') end if @version.nil? invalid_properties.push('invalid value for "version", version cannot be nil.') end if @total_size.nil? invalid_properties.push('invalid value for "total_size", total_size cannot be nil.') end if @block_count.nil? invalid_properties.push('invalid value for "block_count", block_count cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/spatio-sdk/models/chunked_file_manifest.rb', line 308 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
184 185 186 187 188 189 190 191 192 193 |
# File 'lib/spatio-sdk/models/chunked_file_manifest.rb', line 184 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @manifest_id.nil? return false if @file_id.nil? return false if @file_name.nil? return false if @version.nil? return false if @total_size.nil? return false if @block_count.nil? true end |