Class: Spatio::Comment

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/comment.rb

Overview

Threaded comment on a note. Top-level comments have ‘parentCommentId: null`; replies set it to the parent comment’s id. ‘blockId` anchors the comment to a specific block; comments without a `blockId` are note-level ("general") comments.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Comment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/spatio-sdk/models/comment.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::Comment` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::Comment`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'note_id')
    self.note_id = attributes[:'note_id']
  else
    self.note_id = nil
  end

  if attributes.key?(:'parent_comment_id')
    self.parent_comment_id = attributes[:'parent_comment_id']
  end

  if attributes.key?(:'block_id')
    self.block_id = attributes[:'block_id']
  end

  if attributes.key?(:'body')
    self.body = attributes[:'body']
  else
    self.body = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end

  if attributes.key?(:'author')
    self.author = attributes[:'author']
  else
    self.author = nil
  end
end

Instance Attribute Details

#authorObject

Returns the value of attribute author.



33
34
35
# File 'lib/spatio-sdk/models/comment.rb', line 33

def author
  @author
end

#block_idObject

Returns the value of attribute block_id.



25
26
27
# File 'lib/spatio-sdk/models/comment.rb', line 25

def block_id
  @block_id
end

#bodyObject

Returns the value of attribute body.



27
28
29
# File 'lib/spatio-sdk/models/comment.rb', line 27

def body
  @body
end

#created_atObject

Returns the value of attribute created_at.



29
30
31
# File 'lib/spatio-sdk/models/comment.rb', line 29

def created_at
  @created_at
end

#idObject

Returns the value of attribute id.



19
20
21
# File 'lib/spatio-sdk/models/comment.rb', line 19

def id
  @id
end

#note_idObject

Returns the value of attribute note_id.



21
22
23
# File 'lib/spatio-sdk/models/comment.rb', line 21

def note_id
  @note_id
end

#parent_comment_idObject

Returns the value of attribute parent_comment_id.



23
24
25
# File 'lib/spatio-sdk/models/comment.rb', line 23

def parent_comment_id
  @parent_comment_id
end

#updated_atObject

Returns the value of attribute updated_at.



31
32
33
# File 'lib/spatio-sdk/models/comment.rb', line 31

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



50
51
52
# File 'lib/spatio-sdk/models/comment.rb', line 50

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/spatio-sdk/models/comment.rb', line 55

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
46
47
# File 'lib/spatio-sdk/models/comment.rb', line 36

def self.attribute_map
  {
    :'id' => :'id',
    :'note_id' => :'noteId',
    :'parent_comment_id' => :'parentCommentId',
    :'block_id' => :'blockId',
    :'body' => :'body',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt',
    :'author' => :'author'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/spatio-sdk/models/comment.rb', line 277

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



74
75
76
77
78
79
# File 'lib/spatio-sdk/models/comment.rb', line 74

def self.openapi_nullable
  Set.new([
    :'parent_comment_id',
    :'block_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/spatio-sdk/models/comment.rb', line 60

def self.openapi_types
  {
    :'id' => :'String',
    :'note_id' => :'String',
    :'parent_comment_id' => :'String',
    :'block_id' => :'String',
    :'body' => :'String',
    :'created_at' => :'Time',
    :'updated_at' => :'Time',
    :'author' => :'CommentAuthor'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/spatio-sdk/models/comment.rb', line 249

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      note_id == o.note_id &&
      parent_comment_id == o.parent_comment_id &&
      block_id == o.block_id &&
      body == o.body &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
      author == o.author
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


264
265
266
# File 'lib/spatio-sdk/models/comment.rb', line 264

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



270
271
272
# File 'lib/spatio-sdk/models/comment.rb', line 270

def hash
  [id, note_id, parent_comment_id, block_id, body, created_at, updated_at, author].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/spatio-sdk/models/comment.rb', line 144

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @note_id.nil?
    invalid_properties.push('invalid value for "note_id", note_id cannot be nil.')
  end

  if @body.nil?
    invalid_properties.push('invalid value for "body", body cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  if @author.nil?
    invalid_properties.push('invalid value for "author", author cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/spatio-sdk/models/comment.rb', line 299

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



176
177
178
179
180
181
182
183
184
185
# File 'lib/spatio-sdk/models/comment.rb', line 176

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @note_id.nil?
  return false if @body.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  return false if @author.nil?
  true
end