Class: Spatio::CommitChunkedUploadResponse

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/commit_chunked_upload_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CommitChunkedUploadResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/spatio-sdk/models/commit_chunked_upload_response.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::CommitChunkedUploadResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::CommitChunkedUploadResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'success')
    self.success = attributes[:'success']
  else
    self.success = nil
  end

  if attributes.key?(:'file_id')
    self.file_id = attributes[:'file_id']
  else
    self.file_id = nil
  end

  if attributes.key?(:'manifest_id')
    self.manifest_id = attributes[:'manifest_id']
  else
    self.manifest_id = nil
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  else
    self.version = nil
  end

  if attributes.key?(:'total_size')
    self.total_size = attributes[:'total_size']
  else
    self.total_size = nil
  end

  if attributes.key?(:'physical_size')
    self.physical_size = attributes[:'physical_size']
  end

  if attributes.key?(:'deduplication_pct')
    self.deduplication_pct = attributes[:'deduplication_pct']
  end

  if attributes.key?(:'total_blocks')
    self.total_blocks = attributes[:'total_blocks']
  end

  if attributes.key?(:'new_blocks')
    self.new_blocks = attributes[:'new_blocks']
  end

  if attributes.key?(:'deduplicated_blocks')
    self.deduplicated_blocks = attributes[:'deduplicated_blocks']
  end
end

Instance Attribute Details

#deduplicated_blocksObject

Returns the value of attribute deduplicated_blocks.



36
37
38
# File 'lib/spatio-sdk/models/commit_chunked_upload_response.rb', line 36

def deduplicated_blocks
  @deduplicated_blocks
end

#deduplication_pctObject

Returns the value of attribute deduplication_pct.



30
31
32
# File 'lib/spatio-sdk/models/commit_chunked_upload_response.rb', line 30

def deduplication_pct
  @deduplication_pct
end

#file_idObject

Returns the value of attribute file_id.



20
21
22
# File 'lib/spatio-sdk/models/commit_chunked_upload_response.rb', line 20

def file_id
  @file_id
end

#manifest_idObject

Returns the value of attribute manifest_id.



22
23
24
# File 'lib/spatio-sdk/models/commit_chunked_upload_response.rb', line 22

def manifest_id
  @manifest_id
end

#new_blocksObject

Returns the value of attribute new_blocks.



34
35
36
# File 'lib/spatio-sdk/models/commit_chunked_upload_response.rb', line 34

def new_blocks
  @new_blocks
end

#physical_sizeObject

Returns the value of attribute physical_size.



28
29
30
# File 'lib/spatio-sdk/models/commit_chunked_upload_response.rb', line 28

def physical_size
  @physical_size
end

#successObject

Returns the value of attribute success.



18
19
20
# File 'lib/spatio-sdk/models/commit_chunked_upload_response.rb', line 18

def success
  @success
end

#total_blocksObject

Returns the value of attribute total_blocks.



32
33
34
# File 'lib/spatio-sdk/models/commit_chunked_upload_response.rb', line 32

def total_blocks
  @total_blocks
end

#total_sizeObject

Returns the value of attribute total_size.



26
27
28
# File 'lib/spatio-sdk/models/commit_chunked_upload_response.rb', line 26

def total_size
  @total_size
end

#versionObject

Returns the value of attribute version.



24
25
26
# File 'lib/spatio-sdk/models/commit_chunked_upload_response.rb', line 24

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



55
56
57
# File 'lib/spatio-sdk/models/commit_chunked_upload_response.rb', line 55

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



60
61
62
# File 'lib/spatio-sdk/models/commit_chunked_upload_response.rb', line 60

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/spatio-sdk/models/commit_chunked_upload_response.rb', line 39

def self.attribute_map
  {
    :'success' => :'success',
    :'file_id' => :'fileId',
    :'manifest_id' => :'manifestId',
    :'version' => :'version',
    :'total_size' => :'totalSize',
    :'physical_size' => :'physicalSize',
    :'deduplication_pct' => :'deduplicationPct',
    :'total_blocks' => :'totalBlocks',
    :'new_blocks' => :'newBlocks',
    :'deduplicated_blocks' => :'deduplicatedBlocks'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/spatio-sdk/models/commit_chunked_upload_response.rb', line 275

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/spatio-sdk/models/commit_chunked_upload_response.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/spatio-sdk/models/commit_chunked_upload_response.rb', line 65

def self.openapi_types
  {
    :'success' => :'Boolean',
    :'file_id' => :'String',
    :'manifest_id' => :'String',
    :'version' => :'Integer',
    :'total_size' => :'Integer',
    :'physical_size' => :'Integer',
    :'deduplication_pct' => :'Float',
    :'total_blocks' => :'Integer',
    :'new_blocks' => :'Integer',
    :'deduplicated_blocks' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/spatio-sdk/models/commit_chunked_upload_response.rb', line 245

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      success == o.success &&
      file_id == o.file_id &&
      manifest_id == o.manifest_id &&
      version == o.version &&
      total_size == o.total_size &&
      physical_size == o.physical_size &&
      deduplication_pct == o.deduplication_pct &&
      total_blocks == o.total_blocks &&
      new_blocks == o.new_blocks &&
      deduplicated_blocks == o.deduplicated_blocks
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


262
263
264
# File 'lib/spatio-sdk/models/commit_chunked_upload_response.rb', line 262

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



268
269
270
# File 'lib/spatio-sdk/models/commit_chunked_upload_response.rb', line 268

def hash
  [success, file_id, manifest_id, version, total_size, physical_size, deduplication_pct, total_blocks, new_blocks, deduplicated_blocks].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/spatio-sdk/models/commit_chunked_upload_response.rb', line 155

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @success.nil?
    invalid_properties.push('invalid value for "success", success cannot be nil.')
  end

  if @file_id.nil?
    invalid_properties.push('invalid value for "file_id", file_id cannot be nil.')
  end

  if @manifest_id.nil?
    invalid_properties.push('invalid value for "manifest_id", manifest_id cannot be nil.')
  end

  if @version.nil?
    invalid_properties.push('invalid value for "version", version cannot be nil.')
  end

  if @total_size.nil?
    invalid_properties.push('invalid value for "total_size", total_size cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/spatio-sdk/models/commit_chunked_upload_response.rb', line 297

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



183
184
185
186
187
188
189
190
191
# File 'lib/spatio-sdk/models/commit_chunked_upload_response.rb', line 183

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @success.nil?
  return false if @file_id.nil?
  return false if @manifest_id.nil?
  return false if @version.nil?
  return false if @total_size.nil?
  true
end