Class: Spatio::ConnectedAppItem
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Spatio::ConnectedAppItem
- Defined in:
- lib/spatio-sdk/models/connected_app_item.rb
Instance Attribute Summary collapse
-
#client_id ⇒ Object
Returns the value of attribute client_id.
-
#client_name ⇒ Object
Returns the value of attribute client_name.
-
#client_uri ⇒ Object
Returns the value of attribute client_uri.
-
#granted_at ⇒ Object
Returns the value of attribute granted_at.
-
#logo_uri ⇒ Object
Returns the value of attribute logo_uri.
-
#policy_uri ⇒ Object
Returns the value of attribute policy_uri.
-
#scope_labels ⇒ Object
Returns the value of attribute scope_labels.
-
#scopes ⇒ Object
Returns the value of attribute scopes.
-
#tos_uri ⇒ Object
Returns the value of attribute tos_uri.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConnectedAppItem
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ConnectedAppItem
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/spatio-sdk/models/connected_app_item.rb', line 84 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::ConnectedAppItem` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::ConnectedAppItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'client_id') self.client_id = attributes[:'client_id'] else self.client_id = nil end if attributes.key?(:'client_name') self.client_name = attributes[:'client_name'] else self.client_name = nil end if attributes.key?(:'logo_uri') self.logo_uri = attributes[:'logo_uri'] end if attributes.key?(:'client_uri') self.client_uri = attributes[:'client_uri'] end if attributes.key?(:'policy_uri') self.policy_uri = attributes[:'policy_uri'] end if attributes.key?(:'tos_uri') self.tos_uri = attributes[:'tos_uri'] end if attributes.key?(:'scopes') if (value = attributes[:'scopes']).is_a?(Array) self.scopes = value end else self.scopes = nil end if attributes.key?(:'scope_labels') if (value = attributes[:'scope_labels']).is_a?(Array) self.scope_labels = value end else self.scope_labels = nil end if attributes.key?(:'granted_at') self.granted_at = attributes[:'granted_at'] else self.granted_at = nil end end |
Instance Attribute Details
#client_id ⇒ Object
Returns the value of attribute client_id.
18 19 20 |
# File 'lib/spatio-sdk/models/connected_app_item.rb', line 18 def client_id @client_id end |
#client_name ⇒ Object
Returns the value of attribute client_name.
20 21 22 |
# File 'lib/spatio-sdk/models/connected_app_item.rb', line 20 def client_name @client_name end |
#client_uri ⇒ Object
Returns the value of attribute client_uri.
24 25 26 |
# File 'lib/spatio-sdk/models/connected_app_item.rb', line 24 def client_uri @client_uri end |
#granted_at ⇒ Object
Returns the value of attribute granted_at.
34 35 36 |
# File 'lib/spatio-sdk/models/connected_app_item.rb', line 34 def granted_at @granted_at end |
#logo_uri ⇒ Object
Returns the value of attribute logo_uri.
22 23 24 |
# File 'lib/spatio-sdk/models/connected_app_item.rb', line 22 def logo_uri @logo_uri end |
#policy_uri ⇒ Object
Returns the value of attribute policy_uri.
26 27 28 |
# File 'lib/spatio-sdk/models/connected_app_item.rb', line 26 def policy_uri @policy_uri end |
#scope_labels ⇒ Object
Returns the value of attribute scope_labels.
32 33 34 |
# File 'lib/spatio-sdk/models/connected_app_item.rb', line 32 def scope_labels @scope_labels end |
#scopes ⇒ Object
Returns the value of attribute scopes.
30 31 32 |
# File 'lib/spatio-sdk/models/connected_app_item.rb', line 30 def scopes @scopes end |
#tos_uri ⇒ Object
Returns the value of attribute tos_uri.
28 29 30 |
# File 'lib/spatio-sdk/models/connected_app_item.rb', line 28 def tos_uri @tos_uri end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
52 53 54 |
# File 'lib/spatio-sdk/models/connected_app_item.rb', line 52 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
57 58 59 |
# File 'lib/spatio-sdk/models/connected_app_item.rb', line 57 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/spatio-sdk/models/connected_app_item.rb', line 37 def self.attribute_map { :'client_id' => :'client_id', :'client_name' => :'client_name', :'logo_uri' => :'logo_uri', :'client_uri' => :'client_uri', :'policy_uri' => :'policy_uri', :'tos_uri' => :'tos_uri', :'scopes' => :'scopes', :'scope_labels' => :'scope_labels', :'granted_at' => :'granted_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/spatio-sdk/models/connected_app_item.rb', line 270 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
77 78 79 80 |
# File 'lib/spatio-sdk/models/connected_app_item.rb', line 77 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/spatio-sdk/models/connected_app_item.rb', line 62 def self.openapi_types { :'client_id' => :'String', :'client_name' => :'String', :'logo_uri' => :'String', :'client_uri' => :'String', :'policy_uri' => :'String', :'tos_uri' => :'String', :'scopes' => :'Array<String>', :'scope_labels' => :'Array<String>', :'granted_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/spatio-sdk/models/connected_app_item.rb', line 241 def ==(o) return true if self.equal?(o) self.class == o.class && client_id == o.client_id && client_name == o.client_name && logo_uri == o.logo_uri && client_uri == o.client_uri && policy_uri == o.policy_uri && tos_uri == o.tos_uri && scopes == o.scopes && scope_labels == o.scope_labels && granted_at == o.granted_at end |
#eql?(o) ⇒ Boolean
257 258 259 |
# File 'lib/spatio-sdk/models/connected_app_item.rb', line 257 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
263 264 265 |
# File 'lib/spatio-sdk/models/connected_app_item.rb', line 263 def hash [client_id, client_name, logo_uri, client_uri, policy_uri, tos_uri, scopes, scope_labels, granted_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/spatio-sdk/models/connected_app_item.rb', line 151 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @client_id.nil? invalid_properties.push('invalid value for "client_id", client_id cannot be nil.') end if @client_name.nil? invalid_properties.push('invalid value for "client_name", client_name cannot be nil.') end if @scopes.nil? invalid_properties.push('invalid value for "scopes", scopes cannot be nil.') end if @scope_labels.nil? invalid_properties.push('invalid value for "scope_labels", scope_labels cannot be nil.') end if @granted_at.nil? invalid_properties.push('invalid value for "granted_at", granted_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/spatio-sdk/models/connected_app_item.rb', line 292 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
179 180 181 182 183 184 185 186 187 |
# File 'lib/spatio-sdk/models/connected_app_item.rb', line 179 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @client_id.nil? return false if @client_name.nil? return false if @scopes.nil? return false if @scope_labels.nil? return false if @granted_at.nil? true end |