Class: Spatio::Contact

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/contact.rb

Overview

Snake-case wire format (legacy).

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Contact

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/spatio-sdk/models/contact.rb', line 110

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::Contact` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::Contact`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'organization_id')
    self.organization_id = attributes[:'organization_id']
  end

  if attributes.key?(:'first_name')
    self.first_name = attributes[:'first_name']
  end

  if attributes.key?(:'last_name')
    self.last_name = attributes[:'last_name']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'phone')
    self.phone = attributes[:'phone']
  end

  if attributes.key?(:'company')
    self.company = attributes[:'company']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'notes')
    self.notes = attributes[:'notes']
  end

  if attributes.key?(:'scope')
    self.scope = attributes[:'scope']
  end

  if attributes.key?(:'provider')
    self.provider = attributes[:'provider']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#companyObject

Returns the value of attribute company.



33
34
35
# File 'lib/spatio-sdk/models/contact.rb', line 33

def company
  @company
end

#created_atObject

Returns the value of attribute created_at.



45
46
47
# File 'lib/spatio-sdk/models/contact.rb', line 45

def created_at
  @created_at
end

#emailObject

Returns the value of attribute email.



29
30
31
# File 'lib/spatio-sdk/models/contact.rb', line 29

def email
  @email
end

#first_nameObject

Returns the value of attribute first_name.



25
26
27
# File 'lib/spatio-sdk/models/contact.rb', line 25

def first_name
  @first_name
end

#idObject

Returns the value of attribute id.



19
20
21
# File 'lib/spatio-sdk/models/contact.rb', line 19

def id
  @id
end

#last_nameObject

Returns the value of attribute last_name.



27
28
29
# File 'lib/spatio-sdk/models/contact.rb', line 27

def last_name
  @last_name
end

#metadataObject

Returns the value of attribute metadata.



43
44
45
# File 'lib/spatio-sdk/models/contact.rb', line 43

def 
  @metadata
end

#notesObject

Returns the value of attribute notes.



37
38
39
# File 'lib/spatio-sdk/models/contact.rb', line 37

def notes
  @notes
end

#organization_idObject

Returns the value of attribute organization_id.



23
24
25
# File 'lib/spatio-sdk/models/contact.rb', line 23

def organization_id
  @organization_id
end

#phoneObject

Returns the value of attribute phone.



31
32
33
# File 'lib/spatio-sdk/models/contact.rb', line 31

def phone
  @phone
end

#providerObject

Returns the value of attribute provider.



41
42
43
# File 'lib/spatio-sdk/models/contact.rb', line 41

def provider
  @provider
end

#scopeObject

Returns the value of attribute scope.



39
40
41
# File 'lib/spatio-sdk/models/contact.rb', line 39

def scope
  @scope
end

#titleObject

Returns the value of attribute title.



35
36
37
# File 'lib/spatio-sdk/models/contact.rb', line 35

def title
  @title
end

#updated_atObject

Returns the value of attribute updated_at.



47
48
49
# File 'lib/spatio-sdk/models/contact.rb', line 47

def updated_at
  @updated_at
end

#user_idObject

Returns the value of attribute user_id.



21
22
23
# File 'lib/spatio-sdk/models/contact.rb', line 21

def user_id
  @user_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/spatio-sdk/models/contact.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/spatio-sdk/models/contact.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/spatio-sdk/models/contact.rb', line 50

def self.attribute_map
  {
    :'id' => :'id',
    :'user_id' => :'user_id',
    :'organization_id' => :'organization_id',
    :'first_name' => :'first_name',
    :'last_name' => :'last_name',
    :'email' => :'email',
    :'phone' => :'phone',
    :'company' => :'company',
    :'title' => :'title',
    :'notes' => :'notes',
    :'scope' => :'scope',
    :'provider' => :'provider',
    :'metadata' => :'metadata',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/spatio-sdk/models/contact.rb', line 256

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
106
# File 'lib/spatio-sdk/models/contact.rb', line 102

def self.openapi_nullable
  Set.new([
    :'organization_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/spatio-sdk/models/contact.rb', line 81

def self.openapi_types
  {
    :'id' => :'String',
    :'user_id' => :'String',
    :'organization_id' => :'String',
    :'first_name' => :'String',
    :'last_name' => :'String',
    :'email' => :'String',
    :'phone' => :'String',
    :'company' => :'String',
    :'title' => :'String',
    :'notes' => :'String',
    :'scope' => :'String',
    :'provider' => :'String',
    :'metadata' => :'Hash<String, Object>',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/spatio-sdk/models/contact.rb', line 221

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      user_id == o.user_id &&
      organization_id == o.organization_id &&
      first_name == o.first_name &&
      last_name == o.last_name &&
      email == o.email &&
      phone == o.phone &&
      company == o.company &&
      title == o.title &&
      notes == o.notes &&
      scope == o.scope &&
      provider == o.provider &&
       == o. &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


243
244
245
# File 'lib/spatio-sdk/models/contact.rb', line 243

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



249
250
251
# File 'lib/spatio-sdk/models/contact.rb', line 249

def hash
  [id, user_id, organization_id, first_name, last_name, email, phone, company, title, notes, scope, provider, , created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



191
192
193
194
195
196
197
198
199
# File 'lib/spatio-sdk/models/contact.rb', line 191

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/spatio-sdk/models/contact.rb', line 278

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



203
204
205
206
207
# File 'lib/spatio-sdk/models/contact.rb', line 203

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  true
end