Class: Spatio::ConversationsApi
- Inherits:
-
Object
- Object
- Spatio::ConversationsApi
- Defined in:
- lib/spatio-sdk/api/conversations_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_conversation(opts = {}) ⇒ Conversation
Persist a new LLM conversation.
-
#create_conversation_with_http_info(opts = {}) ⇒ Array<(Conversation, Integer, Hash)>
Persist a new LLM conversation.
-
#delete_conversation(id, opts = {}) ⇒ nil
Soft-delete a conversation.
-
#delete_conversation_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Soft-delete a conversation.
-
#get_conversation(id, opts = {}) ⇒ Conversation
Fetch one conversation.
-
#get_conversation_with_http_info(id, opts = {}) ⇒ Array<(Conversation, Integer, Hash)>
Fetch one conversation.
-
#get_latest_conversation_for_context(context, opts = {}) ⇒ Conversation
Fetch the most recently active conversation for a given context tag.
-
#get_latest_conversation_for_context_with_http_info(context, opts = {}) ⇒ Array<(Conversation, Integer, Hash)>
Fetch the most recently active conversation for a given context tag.
-
#initialize(api_client = ApiClient.default) ⇒ ConversationsApi
constructor
A new instance of ConversationsApi.
-
#list_conversation_messages(id, opts = {}) ⇒ Array<ConversationMessage>
List messages in a conversation.
-
#list_conversation_messages_with_http_info(id, opts = {}) ⇒ Array<(Array<ConversationMessage>, Integer, Hash)>
List messages in a conversation.
-
#list_conversations(opts = {}) ⇒ Array<Conversation>
List the caller’s persisted LLM conversations.
-
#list_conversations_with_http_info(opts = {}) ⇒ Array<(Array<Conversation>, Integer, Hash)>
List the caller's persisted LLM conversations.
-
#save_conversation_message(id, save_message_request, opts = {}) ⇒ ConversationMessage
Append a message to a conversation.
-
#save_conversation_message_with_http_info(id, save_message_request, opts = {}) ⇒ Array<(ConversationMessage, Integer, Hash)>
Append a message to a conversation.
-
#update_conversation(id, update_conversation_request, opts = {}) ⇒ Conversation
Update conversation metadata (title, context, cwd, session_id, pinned).
-
#update_conversation_message_metadata(id, update_message_metadata_request, opts = {}) ⇒ ConversationMessage
Patch metadata on an existing message.
-
#update_conversation_message_metadata_with_http_info(id, update_message_metadata_request, opts = {}) ⇒ Array<(ConversationMessage, Integer, Hash)>
Patch metadata on an existing message.
-
#update_conversation_with_http_info(id, update_conversation_request, opts = {}) ⇒ Array<(Conversation, Integer, Hash)>
Update conversation metadata (title, context, cwd, session_id, pinned).
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ConversationsApi
Returns a new instance of ConversationsApi.
19 20 21 |
# File 'lib/spatio-sdk/api/conversations_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/spatio-sdk/api/conversations_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_conversation(opts = {}) ⇒ Conversation
Persist a new LLM conversation.
26 27 28 29 |
# File 'lib/spatio-sdk/api/conversations_api.rb', line 26 def create_conversation(opts = {}) data, _status_code, _headers = create_conversation_with_http_info(opts) data end |
#create_conversation_with_http_info(opts = {}) ⇒ Array<(Conversation, Integer, Hash)>
Persist a new LLM conversation.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/spatio-sdk/api/conversations_api.rb', line 35 def create_conversation_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ConversationsApi.create_conversation ...' end # resource path local_var_path = '/v1/conversations' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'create_conversation_request']) # return_type return_type = opts[:debug_return_type] || 'Conversation' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"ConversationsApi.create_conversation", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ConversationsApi#create_conversation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_conversation(id, opts = {}) ⇒ nil
Soft-delete a conversation.
88 89 90 91 |
# File 'lib/spatio-sdk/api/conversations_api.rb', line 88 def delete_conversation(id, opts = {}) delete_conversation_with_http_info(id, opts) nil end |
#delete_conversation_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Soft-delete a conversation.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/spatio-sdk/api/conversations_api.rb', line 97 def delete_conversation_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ConversationsApi.delete_conversation ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ConversationsApi.delete_conversation" end # resource path local_var_path = '/v1/conversations/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"ConversationsApi.delete_conversation", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ConversationsApi#delete_conversation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_conversation(id, opts = {}) ⇒ Conversation
Fetch one conversation.
149 150 151 152 |
# File 'lib/spatio-sdk/api/conversations_api.rb', line 149 def get_conversation(id, opts = {}) data, _status_code, _headers = get_conversation_with_http_info(id, opts) data end |
#get_conversation_with_http_info(id, opts = {}) ⇒ Array<(Conversation, Integer, Hash)>
Fetch one conversation.
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/spatio-sdk/api/conversations_api.rb', line 158 def get_conversation_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ConversationsApi.get_conversation ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ConversationsApi.get_conversation" end # resource path local_var_path = '/v1/conversations/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Conversation' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"ConversationsApi.get_conversation", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ConversationsApi#get_conversation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_latest_conversation_for_context(context, opts = {}) ⇒ Conversation
Fetch the most recently active conversation for a given context tag.
210 211 212 213 |
# File 'lib/spatio-sdk/api/conversations_api.rb', line 210 def get_latest_conversation_for_context(context, opts = {}) data, _status_code, _headers = get_latest_conversation_for_context_with_http_info(context, opts) data end |
#get_latest_conversation_for_context_with_http_info(context, opts = {}) ⇒ Array<(Conversation, Integer, Hash)>
Fetch the most recently active conversation for a given context tag.
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/spatio-sdk/api/conversations_api.rb', line 219 def get_latest_conversation_for_context_with_http_info(context, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ConversationsApi.get_latest_conversation_for_context ...' end # verify the required parameter 'context' is set if @api_client.config.client_side_validation && context.nil? fail ArgumentError, "Missing the required parameter 'context' when calling ConversationsApi.get_latest_conversation_for_context" end # resource path local_var_path = '/v1/conversations/latest' # query parameters query_params = opts[:query_params] || {} query_params[:'context'] = context # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Conversation' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"ConversationsApi.get_latest_conversation_for_context", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ConversationsApi#get_latest_conversation_for_context\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_conversation_messages(id, opts = {}) ⇒ Array<ConversationMessage>
List messages in a conversation.
274 275 276 277 |
# File 'lib/spatio-sdk/api/conversations_api.rb', line 274 def (id, opts = {}) data, _status_code, _headers = (id, opts) data end |
#list_conversation_messages_with_http_info(id, opts = {}) ⇒ Array<(Array<ConversationMessage>, Integer, Hash)>
List messages in a conversation.
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/spatio-sdk/api/conversations_api.rb', line 285 def (id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ConversationsApi.list_conversation_messages ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ConversationsApi.list_conversation_messages" end # resource path local_var_path = '/v1/conversations/{id}/messages'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'before'] = opts[:'before'] if !opts[:'before'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<ConversationMessage>' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"ConversationsApi.list_conversation_messages", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ConversationsApi#list_conversation_messages\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_conversations(opts = {}) ⇒ Array<Conversation>
List the caller’s persisted LLM conversations.
340 341 342 343 |
# File 'lib/spatio-sdk/api/conversations_api.rb', line 340 def list_conversations(opts = {}) data, _status_code, _headers = list_conversations_with_http_info(opts) data end |
#list_conversations_with_http_info(opts = {}) ⇒ Array<(Array<Conversation>, Integer, Hash)>
List the caller's persisted LLM conversations.
350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'lib/spatio-sdk/api/conversations_api.rb', line 350 def list_conversations_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ConversationsApi.list_conversations ...' end # resource path local_var_path = '/v1/conversations' # query parameters query_params = opts[:query_params] || {} query_params[:'context'] = opts[:'context'] if !opts[:'context'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<Conversation>' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"ConversationsApi.list_conversations", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ConversationsApi#list_conversations\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#save_conversation_message(id, save_message_request, opts = {}) ⇒ ConversationMessage
Append a message to a conversation.
401 402 403 404 |
# File 'lib/spatio-sdk/api/conversations_api.rb', line 401 def (id, , opts = {}) data, _status_code, _headers = (id, , opts) data end |
#save_conversation_message_with_http_info(id, save_message_request, opts = {}) ⇒ Array<(ConversationMessage, Integer, Hash)>
Append a message to a conversation.
411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 |
# File 'lib/spatio-sdk/api/conversations_api.rb', line 411 def (id, , opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ConversationsApi.save_conversation_message ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ConversationsApi.save_conversation_message" end # verify the required parameter 'save_message_request' is set if @api_client.config.client_side_validation && .nil? fail ArgumentError, "Missing the required parameter 'save_message_request' when calling ConversationsApi.save_conversation_message" end # resource path local_var_path = '/v1/conversations/{id}/messages'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body() # return_type return_type = opts[:debug_return_type] || 'ConversationMessage' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"ConversationsApi.save_conversation_message", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ConversationsApi#save_conversation_message\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_conversation(id, update_conversation_request, opts = {}) ⇒ Conversation
Update conversation metadata (title, context, cwd, session_id, pinned).
473 474 475 476 |
# File 'lib/spatio-sdk/api/conversations_api.rb', line 473 def update_conversation(id, update_conversation_request, opts = {}) data, _status_code, _headers = update_conversation_with_http_info(id, update_conversation_request, opts) data end |
#update_conversation_message_metadata(id, update_message_metadata_request, opts = {}) ⇒ ConversationMessage
Patch metadata on an existing message. Body must include the message id (path is the conversation id, not the message).
545 546 547 548 |
# File 'lib/spatio-sdk/api/conversations_api.rb', line 545 def (id, , opts = {}) data, _status_code, _headers = (id, , opts) data end |
#update_conversation_message_metadata_with_http_info(id, update_message_metadata_request, opts = {}) ⇒ Array<(ConversationMessage, Integer, Hash)>
Patch metadata on an existing message. Body must include the message id (path is the conversation id, not the message).
555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 |
# File 'lib/spatio-sdk/api/conversations_api.rb', line 555 def (id, , opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ConversationsApi.update_conversation_message_metadata ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ConversationsApi.update_conversation_message_metadata" end # verify the required parameter 'update_message_metadata_request' is set if @api_client.config.client_side_validation && .nil? fail ArgumentError, "Missing the required parameter 'update_message_metadata_request' when calling ConversationsApi.update_conversation_message_metadata" end # resource path local_var_path = '/v1/conversations/{id}/messages'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body() # return_type return_type = opts[:debug_return_type] || 'ConversationMessage' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"ConversationsApi.update_conversation_message_metadata", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ConversationsApi#update_conversation_message_metadata\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_conversation_with_http_info(id, update_conversation_request, opts = {}) ⇒ Array<(Conversation, Integer, Hash)>
Update conversation metadata (title, context, cwd, session_id, pinned).
483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 |
# File 'lib/spatio-sdk/api/conversations_api.rb', line 483 def update_conversation_with_http_info(id, update_conversation_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ConversationsApi.update_conversation ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ConversationsApi.update_conversation" end # verify the required parameter 'update_conversation_request' is set if @api_client.config.client_side_validation && update_conversation_request.nil? fail ArgumentError, "Missing the required parameter 'update_conversation_request' when calling ConversationsApi.update_conversation" end # resource path local_var_path = '/v1/conversations/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(update_conversation_request) # return_type return_type = opts[:debug_return_type] || 'Conversation' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"ConversationsApi.update_conversation", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ConversationsApi#update_conversation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |