Class: Spatio::CoreAction

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/core_action.rb

Overview

Renderer-curated "core action" entry. These are the keyboard + command-palette surfaced actions; superset of the platform-tagged agent actions. Schema kept open since the platform metadata varies by category.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CoreAction

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/spatio-sdk/models/core_action.rb', line 77

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::CoreAction` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::CoreAction`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  end

  if attributes.key?(:'icon')
    self.icon = attributes[:'icon']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end
end

Instance Attribute Details

#categoryObject

Returns the value of attribute category.



27
28
29
# File 'lib/spatio-sdk/models/core_action.rb', line 27

def category
  @category
end

#descriptionObject

Returns the value of attribute description.



23
24
25
# File 'lib/spatio-sdk/models/core_action.rb', line 23

def description
  @description
end

#iconObject

Returns the value of attribute icon.



29
30
31
# File 'lib/spatio-sdk/models/core_action.rb', line 29

def icon
  @icon
end

#idObject

Returns the value of attribute id.



19
20
21
# File 'lib/spatio-sdk/models/core_action.rb', line 19

def id
  @id
end

#metadataObject

Returns the value of attribute metadata.



31
32
33
# File 'lib/spatio-sdk/models/core_action.rb', line 31

def 
  @metadata
end

#nameObject

Returns the value of attribute name.



21
22
23
# File 'lib/spatio-sdk/models/core_action.rb', line 21

def name
  @name
end

#platformObject

Returns the value of attribute platform.



25
26
27
# File 'lib/spatio-sdk/models/core_action.rb', line 25

def platform
  @platform
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



47
48
49
# File 'lib/spatio-sdk/models/core_action.rb', line 47

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



52
53
54
# File 'lib/spatio-sdk/models/core_action.rb', line 52

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
43
44
# File 'lib/spatio-sdk/models/core_action.rb', line 34

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'description' => :'description',
    :'platform' => :'platform',
    :'category' => :'category',
    :'icon' => :'icon',
    :'metadata' => :'metadata'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/spatio-sdk/models/core_action.rb', line 183

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



70
71
72
73
# File 'lib/spatio-sdk/models/core_action.rb', line 70

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



57
58
59
60
61
62
63
64
65
66
67
# File 'lib/spatio-sdk/models/core_action.rb', line 57

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'platform' => :'String',
    :'category' => :'String',
    :'icon' => :'String',
    :'metadata' => :'Hash<String, Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



156
157
158
159
160
161
162
163
164
165
166
# File 'lib/spatio-sdk/models/core_action.rb', line 156

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      description == o.description &&
      platform == o.platform &&
      category == o.category &&
      icon == o.icon &&
       == o.
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


170
171
172
# File 'lib/spatio-sdk/models/core_action.rb', line 170

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



176
177
178
# File 'lib/spatio-sdk/models/core_action.rb', line 176

def hash
  [id, name, description, platform, category, icon, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



126
127
128
129
130
131
132
133
134
# File 'lib/spatio-sdk/models/core_action.rb', line 126

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/spatio-sdk/models/core_action.rb', line 205

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



138
139
140
141
142
# File 'lib/spatio-sdk/models/core_action.rb', line 138

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  true
end