Class: Spatio::CreateBlockRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Spatio::CreateBlockRequest
- Defined in:
- lib/spatio-sdk/models/create_block_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#content ⇒ Object
Returns the value of attribute content.
-
#parent_id ⇒ Object
Parent block id for nested blocks.
-
#position ⇒ Object
Returns the value of attribute position.
-
#properties ⇒ Object
Returns the value of attribute properties.
-
#type ⇒ Object
Returns the value of attribute type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateBlockRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateBlockRequest
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/spatio-sdk/models/create_block_request.rb', line 92 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::CreateBlockRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::CreateBlockRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'content') self.content = attributes[:'content'] else self.content = nil end if attributes.key?(:'parent_id') self.parent_id = attributes[:'parent_id'] end if attributes.key?(:'position') self.position = attributes[:'position'] else self.position = nil end if attributes.key?(:'properties') if (value = attributes[:'properties']).is_a?(Hash) self.properties = value end end end |
Instance Attribute Details
#content ⇒ Object
Returns the value of attribute content.
20 21 22 |
# File 'lib/spatio-sdk/models/create_block_request.rb', line 20 def content @content end |
#parent_id ⇒ Object
Parent block id for nested blocks.
23 24 25 |
# File 'lib/spatio-sdk/models/create_block_request.rb', line 23 def parent_id @parent_id end |
#position ⇒ Object
Returns the value of attribute position.
25 26 27 |
# File 'lib/spatio-sdk/models/create_block_request.rb', line 25 def position @position end |
#properties ⇒ Object
Returns the value of attribute properties.
27 28 29 |
# File 'lib/spatio-sdk/models/create_block_request.rb', line 27 def properties @properties end |
#type ⇒ Object
Returns the value of attribute type.
18 19 20 |
# File 'lib/spatio-sdk/models/create_block_request.rb', line 18 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
63 64 65 |
# File 'lib/spatio-sdk/models/create_block_request.rb', line 63 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
68 69 70 |
# File 'lib/spatio-sdk/models/create_block_request.rb', line 68 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 |
# File 'lib/spatio-sdk/models/create_block_request.rb', line 52 def self.attribute_map { :'type' => :'type', :'content' => :'content', :'parent_id' => :'parentId', :'position' => :'position', :'properties' => :'properties' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/spatio-sdk/models/create_block_request.rb', line 222 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
84 85 86 87 88 |
# File 'lib/spatio-sdk/models/create_block_request.rb', line 84 def self.openapi_nullable Set.new([ :'parent_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 81 |
# File 'lib/spatio-sdk/models/create_block_request.rb', line 73 def self.openapi_types { :'type' => :'BlockType', :'content' => :'BlockContent', :'parent_id' => :'String', :'position' => :'Integer', :'properties' => :'Hash<String, Object>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
197 198 199 200 201 202 203 204 205 |
# File 'lib/spatio-sdk/models/create_block_request.rb', line 197 def ==(o) return true if self.equal?(o) self.class == o.class && type == o.type && content == o.content && parent_id == o.parent_id && position == o.position && properties == o.properties end |
#eql?(o) ⇒ Boolean
209 210 211 |
# File 'lib/spatio-sdk/models/create_block_request.rb', line 209 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
215 216 217 |
# File 'lib/spatio-sdk/models/create_block_request.rb', line 215 def hash [type, content, parent_id, position, properties].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/spatio-sdk/models/create_block_request.rb', line 137 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @content.nil? invalid_properties.push('invalid value for "content", content cannot be nil.') end if @position.nil? invalid_properties.push('invalid value for "position", position cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/spatio-sdk/models/create_block_request.rb', line 244 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
157 158 159 160 161 162 163 |
# File 'lib/spatio-sdk/models/create_block_request.rb', line 157 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @type.nil? return false if @content.nil? return false if @position.nil? true end |