Class: Spatio::CreateCalendarEvent201Response

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/spatio-sdk/models/create_calendar_event201_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateCalendarEvent201Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/spatio-sdk/models/create_calendar_event201_response.rb', line 71

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::CreateCalendarEvent201Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::CreateCalendarEvent201Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'success')
    self.success = attributes[:'success']
  else
    self.success = nil
  end

  if attributes.key?(:'data')
    self.data = attributes[:'data']
  end

  if attributes.key?(:'errors')
    if (value = attributes[:'errors']).is_a?(Array)
      self.errors = value
    end
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end
end

Instance Attribute Details

#dataObject

Returns the value of attribute data.



20
21
22
# File 'lib/spatio-sdk/models/create_calendar_event201_response.rb', line 20

def data
  @data
end

#errorsObject

Returns the value of attribute errors.



22
23
24
# File 'lib/spatio-sdk/models/create_calendar_event201_response.rb', line 22

def errors
  @errors
end

#metadataObject

Returns the value of attribute metadata.



24
25
26
# File 'lib/spatio-sdk/models/create_calendar_event201_response.rb', line 24

def 
  @metadata
end

#successObject

Returns the value of attribute success.



18
19
20
# File 'lib/spatio-sdk/models/create_calendar_event201_response.rb', line 18

def success
  @success
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



37
38
39
# File 'lib/spatio-sdk/models/create_calendar_event201_response.rb', line 37

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/spatio-sdk/models/create_calendar_event201_response.rb', line 42

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
34
# File 'lib/spatio-sdk/models/create_calendar_event201_response.rb', line 27

def self.attribute_map
  {
    :'success' => :'success',
    :'data' => :'data',
    :'errors' => :'errors',
    :'metadata' => :'metadata'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/spatio-sdk/models/create_calendar_event201_response.rb', line 164

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



63
64
65
66
67
# File 'lib/spatio-sdk/models/create_calendar_event201_response.rb', line 63

def self.openapi_all_of
  [
  :'CalendarOperationResult'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



57
58
59
60
# File 'lib/spatio-sdk/models/create_calendar_event201_response.rb', line 57

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
54
# File 'lib/spatio-sdk/models/create_calendar_event201_response.rb', line 47

def self.openapi_types
  {
    :'success' => :'Boolean',
    :'data' => :'SpatioEvent',
    :'errors' => :'Array<CalendarAccountError>',
    :'metadata' => :'Hash<String, Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



140
141
142
143
144
145
146
147
# File 'lib/spatio-sdk/models/create_calendar_event201_response.rb', line 140

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      success == o.success &&
      data == o.data &&
      errors == o.errors &&
       == o.
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


151
152
153
# File 'lib/spatio-sdk/models/create_calendar_event201_response.rb', line 151

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



157
158
159
# File 'lib/spatio-sdk/models/create_calendar_event201_response.rb', line 157

def hash
  [success, data, errors, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



110
111
112
113
114
115
116
117
118
# File 'lib/spatio-sdk/models/create_calendar_event201_response.rb', line 110

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @success.nil?
    invalid_properties.push('invalid value for "success", success cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/spatio-sdk/models/create_calendar_event201_response.rb', line 186

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



122
123
124
125
126
# File 'lib/spatio-sdk/models/create_calendar_event201_response.rb', line 122

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @success.nil?
  true
end