Class: Spatio::CreateContactRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Spatio::CreateContactRequest
- Defined in:
- lib/spatio-sdk/models/create_contact_request.rb
Instance Attribute Summary collapse
-
#company ⇒ Object
Returns the value of attribute company.
-
#email ⇒ Object
Returns the value of attribute email.
-
#first_name ⇒ Object
Returns the value of attribute first_name.
-
#last_name ⇒ Object
Returns the value of attribute last_name.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#notes ⇒ Object
Returns the value of attribute notes.
-
#phone ⇒ Object
Returns the value of attribute phone.
-
#title ⇒ Object
Returns the value of attribute title.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateContactRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateContactRequest
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/spatio-sdk/models/create_contact_request.rb', line 80 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::CreateContactRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::CreateContactRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'first_name') self.first_name = attributes[:'first_name'] end if attributes.key?(:'last_name') self.last_name = attributes[:'last_name'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'phone') self.phone = attributes[:'phone'] end if attributes.key?(:'company') self.company = attributes[:'company'] end if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'notes') self.notes = attributes[:'notes'] end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end end |
Instance Attribute Details
#company ⇒ Object
Returns the value of attribute company.
26 27 28 |
# File 'lib/spatio-sdk/models/create_contact_request.rb', line 26 def company @company end |
#email ⇒ Object
Returns the value of attribute email.
22 23 24 |
# File 'lib/spatio-sdk/models/create_contact_request.rb', line 22 def email @email end |
#first_name ⇒ Object
Returns the value of attribute first_name.
18 19 20 |
# File 'lib/spatio-sdk/models/create_contact_request.rb', line 18 def first_name @first_name end |
#last_name ⇒ Object
Returns the value of attribute last_name.
20 21 22 |
# File 'lib/spatio-sdk/models/create_contact_request.rb', line 20 def last_name @last_name end |
#metadata ⇒ Object
Returns the value of attribute metadata.
32 33 34 |
# File 'lib/spatio-sdk/models/create_contact_request.rb', line 32 def @metadata end |
#notes ⇒ Object
Returns the value of attribute notes.
30 31 32 |
# File 'lib/spatio-sdk/models/create_contact_request.rb', line 30 def notes @notes end |
#phone ⇒ Object
Returns the value of attribute phone.
24 25 26 |
# File 'lib/spatio-sdk/models/create_contact_request.rb', line 24 def phone @phone end |
#title ⇒ Object
Returns the value of attribute title.
28 29 30 |
# File 'lib/spatio-sdk/models/create_contact_request.rb', line 28 def title @title end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/spatio-sdk/models/create_contact_request.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/spatio-sdk/models/create_contact_request.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/spatio-sdk/models/create_contact_request.rb', line 35 def self.attribute_map { :'first_name' => :'first_name', :'last_name' => :'last_name', :'email' => :'email', :'phone' => :'phone', :'company' => :'company', :'title' => :'title', :'notes' => :'notes', :'metadata' => :'metadata' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/spatio-sdk/models/create_contact_request.rb', line 174 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
73 74 75 76 |
# File 'lib/spatio-sdk/models/create_contact_request.rb', line 73 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/spatio-sdk/models/create_contact_request.rb', line 59 def self.openapi_types { :'first_name' => :'String', :'last_name' => :'String', :'email' => :'String', :'phone' => :'String', :'company' => :'String', :'title' => :'String', :'notes' => :'String', :'metadata' => :'Hash<String, Object>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/spatio-sdk/models/create_contact_request.rb', line 146 def ==(o) return true if self.equal?(o) self.class == o.class && first_name == o.first_name && last_name == o.last_name && email == o.email && phone == o.phone && company == o.company && title == o.title && notes == o.notes && == o. end |
#eql?(o) ⇒ Boolean
161 162 163 |
# File 'lib/spatio-sdk/models/create_contact_request.rb', line 161 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
167 168 169 |
# File 'lib/spatio-sdk/models/create_contact_request.rb', line 167 def hash [first_name, last_name, email, phone, company, title, notes, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
131 132 133 134 135 |
# File 'lib/spatio-sdk/models/create_contact_request.rb', line 131 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/spatio-sdk/models/create_contact_request.rb', line 196 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
139 140 141 142 |
# File 'lib/spatio-sdk/models/create_contact_request.rb', line 139 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |