Class: Spatio::CreateEventRequest

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/create_event_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateEventRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/spatio-sdk/models/create_event_request.rb', line 93

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::CreateEventRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::CreateEventRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'calendar_id')
    self.calendar_id = attributes[:'calendar_id']
  end

  if attributes.key?(:'event')
    self.event = attributes[:'event']
  else
    self.event = nil
  end

  if attributes.key?(:'send_updates')
    self.send_updates = attributes[:'send_updates']
  end

  if attributes.key?(:'conference_type')
    self.conference_type = attributes[:'conference_type']
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



18
19
20
# File 'lib/spatio-sdk/models/create_event_request.rb', line 18

def 
  @account_id
end

#calendar_idObject

Specific calendar within the account; omit for the default.



21
22
23
# File 'lib/spatio-sdk/models/create_event_request.rb', line 21

def calendar_id
  @calendar_id
end

#conference_typeObject

When set, the platform will auto-attach a conference link of the matching type (‘spatio`, `meet`, `zoom`, `teams`).



29
30
31
# File 'lib/spatio-sdk/models/create_event_request.rb', line 29

def conference_type
  @conference_type
end

#eventObject

Returns the value of attribute event.



23
24
25
# File 'lib/spatio-sdk/models/create_event_request.rb', line 23

def event
  @event
end

#send_updatesObject

Notification policy passed through to the provider.



26
27
28
# File 'lib/spatio-sdk/models/create_event_request.rb', line 26

def send_updates
  @send_updates
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



65
66
67
# File 'lib/spatio-sdk/models/create_event_request.rb', line 65

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/spatio-sdk/models/create_event_request.rb', line 70

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
# File 'lib/spatio-sdk/models/create_event_request.rb', line 54

def self.attribute_map
  {
    :'account_id' => :'account_id',
    :'calendar_id' => :'calendar_id',
    :'event' => :'event',
    :'send_updates' => :'send_updates',
    :'conference_type' => :'conference_type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/spatio-sdk/models/create_event_request.rb', line 216

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



86
87
88
89
# File 'lib/spatio-sdk/models/create_event_request.rb', line 86

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
# File 'lib/spatio-sdk/models/create_event_request.rb', line 75

def self.openapi_types
  {
    :'account_id' => :'String',
    :'calendar_id' => :'String',
    :'event' => :'SpatioEvent',
    :'send_updates' => :'String',
    :'conference_type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



191
192
193
194
195
196
197
198
199
# File 'lib/spatio-sdk/models/create_event_request.rb', line 191

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      calendar_id == o.calendar_id &&
      event == o.event &&
      send_updates == o.send_updates &&
      conference_type == o.conference_type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


203
204
205
# File 'lib/spatio-sdk/models/create_event_request.rb', line 203

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



209
210
211
# File 'lib/spatio-sdk/models/create_event_request.rb', line 209

def hash
  [, calendar_id, event, send_updates, conference_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/spatio-sdk/models/create_event_request.rb', line 134

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @event.nil?
    invalid_properties.push('invalid value for "event", event cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/spatio-sdk/models/create_event_request.rb', line 238

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



150
151
152
153
154
155
156
157
# File 'lib/spatio-sdk/models/create_event_request.rb', line 150

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @account_id.nil?
  return false if @event.nil?
  send_updates_validator = EnumAttributeValidator.new('String', ["all", "externalOnly", "none"])
  return false unless send_updates_validator.valid?(@send_updates)
  true
end