Class: Spatio::CreateNoteRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Spatio::CreateNoteRequest
- Defined in:
- lib/spatio-sdk/models/create_note_request.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Optional override for the target connected account.
-
#content ⇒ Object
Returns the value of attribute content.
-
#cover_image ⇒ Object
Returns the value of attribute cover_image.
-
#icon ⇒ Object
Returns the value of attribute icon.
-
#parent_id ⇒ Object
Returns the value of attribute parent_id.
-
#properties ⇒ Object
Returns the value of attribute properties.
-
#provider ⇒ Object
Optional provider id (alternative to ‘accountId` when only one account exists for the provider).
-
#title ⇒ Object
Returns the value of attribute title.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateNoteRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateNoteRequest
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/spatio-sdk/models/create_note_request.rb', line 83 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::CreateNoteRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::CreateNoteRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'title') self.title = attributes[:'title'] else self.title = nil end if attributes.key?(:'content') self.content = attributes[:'content'] end if attributes.key?(:'icon') self.icon = attributes[:'icon'] end if attributes.key?(:'cover_image') self.cover_image = attributes[:'cover_image'] end if attributes.key?(:'parent_id') self.parent_id = attributes[:'parent_id'] end if attributes.key?(:'properties') if (value = attributes[:'properties']).is_a?(Hash) self.properties = value end end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'provider') self.provider = attributes[:'provider'] end end |
Instance Attribute Details
#account_id ⇒ Object
Optional override for the target connected account. May also be passed as a ‘?accountId=` query param.
31 32 33 |
# File 'lib/spatio-sdk/models/create_note_request.rb', line 31 def account_id @account_id end |
#content ⇒ Object
Returns the value of attribute content.
20 21 22 |
# File 'lib/spatio-sdk/models/create_note_request.rb', line 20 def content @content end |
#cover_image ⇒ Object
Returns the value of attribute cover_image.
24 25 26 |
# File 'lib/spatio-sdk/models/create_note_request.rb', line 24 def cover_image @cover_image end |
#icon ⇒ Object
Returns the value of attribute icon.
22 23 24 |
# File 'lib/spatio-sdk/models/create_note_request.rb', line 22 def icon @icon end |
#parent_id ⇒ Object
Returns the value of attribute parent_id.
26 27 28 |
# File 'lib/spatio-sdk/models/create_note_request.rb', line 26 def parent_id @parent_id end |
#properties ⇒ Object
Returns the value of attribute properties.
28 29 30 |
# File 'lib/spatio-sdk/models/create_note_request.rb', line 28 def properties @properties end |
#provider ⇒ Object
Optional provider id (alternative to ‘accountId` when only one account exists for the provider). May also be passed as a `?provider=` query param.
34 35 36 |
# File 'lib/spatio-sdk/models/create_note_request.rb', line 34 def provider @provider end |
#title ⇒ Object
Returns the value of attribute title.
18 19 20 |
# File 'lib/spatio-sdk/models/create_note_request.rb', line 18 def title @title end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
51 52 53 |
# File 'lib/spatio-sdk/models/create_note_request.rb', line 51 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
56 57 58 |
# File 'lib/spatio-sdk/models/create_note_request.rb', line 56 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/spatio-sdk/models/create_note_request.rb', line 37 def self.attribute_map { :'title' => :'title', :'content' => :'content', :'icon' => :'icon', :'cover_image' => :'coverImage', :'parent_id' => :'parentId', :'properties' => :'properties', :'account_id' => :'accountId', :'provider' => :'provider' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/spatio-sdk/models/create_note_request.rb', line 194 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
75 76 77 78 79 |
# File 'lib/spatio-sdk/models/create_note_request.rb', line 75 def self.openapi_nullable Set.new([ :'parent_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/spatio-sdk/models/create_note_request.rb', line 61 def self.openapi_types { :'title' => :'String', :'content' => :'String', :'icon' => :'String', :'cover_image' => :'String', :'parent_id' => :'String', :'properties' => :'Hash<String, Object>', :'account_id' => :'String', :'provider' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/spatio-sdk/models/create_note_request.rb', line 166 def ==(o) return true if self.equal?(o) self.class == o.class && title == o.title && content == o.content && icon == o.icon && cover_image == o.cover_image && parent_id == o.parent_id && properties == o.properties && account_id == o.account_id && provider == o.provider end |
#eql?(o) ⇒ Boolean
181 182 183 |
# File 'lib/spatio-sdk/models/create_note_request.rb', line 181 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
187 188 189 |
# File 'lib/spatio-sdk/models/create_note_request.rb', line 187 def hash [title, content, icon, cover_image, parent_id, properties, account_id, provider].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
136 137 138 139 140 141 142 143 144 |
# File 'lib/spatio-sdk/models/create_note_request.rb', line 136 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @title.nil? invalid_properties.push('invalid value for "title", title cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/spatio-sdk/models/create_note_request.rb', line 216 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
148 149 150 151 152 |
# File 'lib/spatio-sdk/models/create_note_request.rb', line 148 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @title.nil? true end |