Class: Spatio::CreateRoutineRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Spatio::CreateRoutineRequest
- Defined in:
- lib/spatio-sdk/models/create_routine_request.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
Returns the value of attribute description.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#name ⇒ Object
Returns the value of attribute name.
-
#schedule ⇒ Object
Returns the value of attribute schedule.
-
#workspace_id ⇒ Object
Returns the value of attribute workspace_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateRoutineRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateRoutineRequest
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/spatio-sdk/models/create_routine_request.rb', line 68 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::CreateRoutineRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::CreateRoutineRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'workspace_id') self.workspace_id = attributes[:'workspace_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'schedule') if (value = attributes[:'schedule']).is_a?(Hash) self.schedule = value end end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end end |
Instance Attribute Details
#description ⇒ Object
Returns the value of attribute description.
22 23 24 |
# File 'lib/spatio-sdk/models/create_routine_request.rb', line 22 def description @description end |
#metadata ⇒ Object
Returns the value of attribute metadata.
26 27 28 |
# File 'lib/spatio-sdk/models/create_routine_request.rb', line 26 def @metadata end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/spatio-sdk/models/create_routine_request.rb', line 20 def name @name end |
#schedule ⇒ Object
Returns the value of attribute schedule.
24 25 26 |
# File 'lib/spatio-sdk/models/create_routine_request.rb', line 24 def schedule @schedule end |
#workspace_id ⇒ Object
Returns the value of attribute workspace_id.
18 19 20 |
# File 'lib/spatio-sdk/models/create_routine_request.rb', line 18 def workspace_id @workspace_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
40 41 42 |
# File 'lib/spatio-sdk/models/create_routine_request.rb', line 40 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
45 46 47 |
# File 'lib/spatio-sdk/models/create_routine_request.rb', line 45 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 37 |
# File 'lib/spatio-sdk/models/create_routine_request.rb', line 29 def self.attribute_map { :'workspace_id' => :'workspaceId', :'name' => :'name', :'description' => :'description', :'schedule' => :'schedule', :'metadata' => :'metadata' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/spatio-sdk/models/create_routine_request.rb', line 166 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
61 62 63 64 |
# File 'lib/spatio-sdk/models/create_routine_request.rb', line 61 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 |
# File 'lib/spatio-sdk/models/create_routine_request.rb', line 50 def self.openapi_types { :'workspace_id' => :'String', :'name' => :'String', :'description' => :'String', :'schedule' => :'Hash<String, Object>', :'metadata' => :'Hash<String, Object>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
141 142 143 144 145 146 147 148 149 |
# File 'lib/spatio-sdk/models/create_routine_request.rb', line 141 def ==(o) return true if self.equal?(o) self.class == o.class && workspace_id == o.workspace_id && name == o.name && description == o.description && schedule == o.schedule && == o. end |
#eql?(o) ⇒ Boolean
153 154 155 |
# File 'lib/spatio-sdk/models/create_routine_request.rb', line 153 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
159 160 161 |
# File 'lib/spatio-sdk/models/create_routine_request.rb', line 159 def hash [workspace_id, name, description, schedule, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
111 112 113 114 115 116 117 118 119 |
# File 'lib/spatio-sdk/models/create_routine_request.rb', line 111 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/spatio-sdk/models/create_routine_request.rb', line 188 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
123 124 125 126 127 |
# File 'lib/spatio-sdk/models/create_routine_request.rb', line 123 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? true end |