Class: Spatio::CreateSheetRequest

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/create_sheet_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateSheetRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/spatio-sdk/models/create_sheet_request.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::CreateSheetRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::CreateSheetRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'data')
    if (value = attributes[:'data']).is_a?(Hash)
      self.data = value
    end
  end

  if attributes.key?(:'row_count')
    self.row_count = attributes[:'row_count']
  end

  if attributes.key?(:'column_count')
    self.column_count = attributes[:'column_count']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'provider')
    self.provider = attributes[:'provider']
  end
end

Instance Attribute Details

#account_idObject

Optional override for the target connected account. May also be passed as ‘?accountId=`.



29
30
31
# File 'lib/spatio-sdk/models/create_sheet_request.rb', line 29

def 
  @account_id
end

#column_countObject

Returns the value of attribute column_count.



26
27
28
# File 'lib/spatio-sdk/models/create_sheet_request.rb', line 26

def column_count
  @column_count
end

#dataObject

Returns the value of attribute data.



22
23
24
# File 'lib/spatio-sdk/models/create_sheet_request.rb', line 22

def data
  @data
end

#descriptionObject

Returns the value of attribute description.



20
21
22
# File 'lib/spatio-sdk/models/create_sheet_request.rb', line 20

def description
  @description
end

#nameObject

Returns the value of attribute name.



18
19
20
# File 'lib/spatio-sdk/models/create_sheet_request.rb', line 18

def name
  @name
end

#providerObject

Returns the value of attribute provider.



31
32
33
# File 'lib/spatio-sdk/models/create_sheet_request.rb', line 31

def provider
  @provider
end

#row_countObject

Returns the value of attribute row_count.



24
25
26
# File 'lib/spatio-sdk/models/create_sheet_request.rb', line 24

def row_count
  @row_count
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



47
48
49
# File 'lib/spatio-sdk/models/create_sheet_request.rb', line 47

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



52
53
54
# File 'lib/spatio-sdk/models/create_sheet_request.rb', line 52

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
43
44
# File 'lib/spatio-sdk/models/create_sheet_request.rb', line 34

def self.attribute_map
  {
    :'name' => :'name',
    :'description' => :'description',
    :'data' => :'data',
    :'row_count' => :'rowCount',
    :'column_count' => :'columnCount',
    :'account_id' => :'accountId',
    :'provider' => :'provider'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/spatio-sdk/models/create_sheet_request.rb', line 184

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



70
71
72
73
74
# File 'lib/spatio-sdk/models/create_sheet_request.rb', line 70

def self.openapi_nullable
  Set.new([
    :'description',
  ])
end

.openapi_typesObject

Attribute type mapping.



57
58
59
60
61
62
63
64
65
66
67
# File 'lib/spatio-sdk/models/create_sheet_request.rb', line 57

def self.openapi_types
  {
    :'name' => :'String',
    :'description' => :'String',
    :'data' => :'Hash<String, Object>',
    :'row_count' => :'Integer',
    :'column_count' => :'Integer',
    :'account_id' => :'String',
    :'provider' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



157
158
159
160
161
162
163
164
165
166
167
# File 'lib/spatio-sdk/models/create_sheet_request.rb', line 157

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      description == o.description &&
      data == o.data &&
      row_count == o.row_count &&
      column_count == o.column_count &&
       == o. &&
      provider == o.provider
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


171
172
173
# File 'lib/spatio-sdk/models/create_sheet_request.rb', line 171

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



177
178
179
# File 'lib/spatio-sdk/models/create_sheet_request.rb', line 177

def hash
  [name, description, data, row_count, column_count, , provider].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



127
128
129
130
131
132
133
134
135
# File 'lib/spatio-sdk/models/create_sheet_request.rb', line 127

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/spatio-sdk/models/create_sheet_request.rb', line 206

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



139
140
141
142
143
# File 'lib/spatio-sdk/models/create_sheet_request.rb', line 139

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  true
end