Class: Spatio::CreateSlideRequest

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/create_slide_request.rb

Overview

‘presentationId` in the body is allowed but redundant when posting to `/v1/slides/id/slides` — the path id wins.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateSlideRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/spatio-sdk/models/create_slide_request.rb', line 85

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::CreateSlideRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::CreateSlideRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'presentation_id')
    self.presentation_id = attributes[:'presentation_id']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'notes')
    self.notes = attributes[:'notes']
  end

  if attributes.key?(:'layout')
    self.layout = attributes[:'layout']
  end

  if attributes.key?(:'background_color')
    self.background_color = attributes[:'background_color']
  end

  if attributes.key?(:'background_image_url')
    self.background_image_url = attributes[:'background_image_url']
  end

  if attributes.key?(:'text_color')
    self.text_color = attributes[:'text_color']
  end

  if attributes.key?(:'transition')
    self.transition = attributes[:'transition']
  end

  if attributes.key?(:'position')
    self.position = attributes[:'position']
  end
end

Instance Attribute Details

#background_colorObject

Returns the value of attribute background_color.



27
28
29
# File 'lib/spatio-sdk/models/create_slide_request.rb', line 27

def background_color
  @background_color
end

#background_image_urlObject

Returns the value of attribute background_image_url.



29
30
31
# File 'lib/spatio-sdk/models/create_slide_request.rb', line 29

def background_image_url
  @background_image_url
end

#layoutObject

Returns the value of attribute layout.



25
26
27
# File 'lib/spatio-sdk/models/create_slide_request.rb', line 25

def layout
  @layout
end

#notesObject

Returns the value of attribute notes.



23
24
25
# File 'lib/spatio-sdk/models/create_slide_request.rb', line 23

def notes
  @notes
end

#positionObject

Returns the value of attribute position.



35
36
37
# File 'lib/spatio-sdk/models/create_slide_request.rb', line 35

def position
  @position
end

#presentation_idObject

Returns the value of attribute presentation_id.



19
20
21
# File 'lib/spatio-sdk/models/create_slide_request.rb', line 19

def presentation_id
  @presentation_id
end

#text_colorObject

Returns the value of attribute text_color.



31
32
33
# File 'lib/spatio-sdk/models/create_slide_request.rb', line 31

def text_color
  @text_color
end

#titleObject

Returns the value of attribute title.



21
22
23
# File 'lib/spatio-sdk/models/create_slide_request.rb', line 21

def title
  @title
end

#transitionObject

Returns the value of attribute transition.



33
34
35
# File 'lib/spatio-sdk/models/create_slide_request.rb', line 33

def transition
  @transition
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/spatio-sdk/models/create_slide_request.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/spatio-sdk/models/create_slide_request.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
49
50
# File 'lib/spatio-sdk/models/create_slide_request.rb', line 38

def self.attribute_map
  {
    :'presentation_id' => :'presentationId',
    :'title' => :'title',
    :'notes' => :'notes',
    :'layout' => :'layout',
    :'background_color' => :'backgroundColor',
    :'background_image_url' => :'backgroundImageUrl',
    :'text_color' => :'textColor',
    :'transition' => :'transition',
    :'position' => :'position'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/spatio-sdk/models/create_slide_request.rb', line 182

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



78
79
80
81
# File 'lib/spatio-sdk/models/create_slide_request.rb', line 78

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/spatio-sdk/models/create_slide_request.rb', line 63

def self.openapi_types
  {
    :'presentation_id' => :'String',
    :'title' => :'String',
    :'notes' => :'String',
    :'layout' => :'String',
    :'background_color' => :'String',
    :'background_image_url' => :'String',
    :'text_color' => :'String',
    :'transition' => :'String',
    :'position' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/spatio-sdk/models/create_slide_request.rb', line 153

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      presentation_id == o.presentation_id &&
      title == o.title &&
      notes == o.notes &&
      layout == o.layout &&
      background_color == o.background_color &&
      background_image_url == o.background_image_url &&
      text_color == o.text_color &&
      transition == o.transition &&
      position == o.position
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


169
170
171
# File 'lib/spatio-sdk/models/create_slide_request.rb', line 169

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



175
176
177
# File 'lib/spatio-sdk/models/create_slide_request.rb', line 175

def hash
  [presentation_id, title, notes, layout, background_color, background_image_url, text_color, transition, position].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



138
139
140
141
142
# File 'lib/spatio-sdk/models/create_slide_request.rb', line 138

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/spatio-sdk/models/create_slide_request.rb', line 204

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



146
147
148
149
# File 'lib/spatio-sdk/models/create_slide_request.rb', line 146

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end