Class: Spatio::DMMuteRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Spatio::DMMuteRequest
- Defined in:
- lib/spatio-sdk/models/dm_mute_request.rb
Overview
Mute either until a specific time (‘untilSeconds`, Unix epoch) or forever (`forever: true`). At least one must be set.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#forever ⇒ Object
Returns the value of attribute forever.
-
#until_seconds ⇒ Object
Returns the value of attribute until_seconds.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DMMuteRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DMMuteRequest
Initializes the object
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/spatio-sdk/models/dm_mute_request.rb', line 61 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::DMMuteRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::DMMuteRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'until_seconds') self.until_seconds = attributes[:'until_seconds'] end if attributes.key?(:'forever') self.forever = attributes[:'forever'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
23 24 25 |
# File 'lib/spatio-sdk/models/dm_mute_request.rb', line 23 def account_id @account_id end |
#forever ⇒ Object
Returns the value of attribute forever.
21 22 23 |
# File 'lib/spatio-sdk/models/dm_mute_request.rb', line 21 def forever @forever end |
#until_seconds ⇒ Object
Returns the value of attribute until_seconds.
19 20 21 |
# File 'lib/spatio-sdk/models/dm_mute_request.rb', line 19 def until_seconds @until_seconds end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
35 36 37 |
# File 'lib/spatio-sdk/models/dm_mute_request.rb', line 35 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
40 41 42 |
# File 'lib/spatio-sdk/models/dm_mute_request.rb', line 40 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 32 |
# File 'lib/spatio-sdk/models/dm_mute_request.rb', line 26 def self.attribute_map { :'until_seconds' => :'untilSeconds', :'forever' => :'forever', :'account_id' => :'accountId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/spatio-sdk/models/dm_mute_request.rb', line 128 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
54 55 56 57 |
# File 'lib/spatio-sdk/models/dm_mute_request.rb', line 54 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
45 46 47 48 49 50 51 |
# File 'lib/spatio-sdk/models/dm_mute_request.rb', line 45 def self.openapi_types { :'until_seconds' => :'Integer', :'forever' => :'Boolean', :'account_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
105 106 107 108 109 110 111 |
# File 'lib/spatio-sdk/models/dm_mute_request.rb', line 105 def ==(o) return true if self.equal?(o) self.class == o.class && until_seconds == o.until_seconds && forever == o.forever && account_id == o.account_id end |
#eql?(o) ⇒ Boolean
115 116 117 |
# File 'lib/spatio-sdk/models/dm_mute_request.rb', line 115 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
121 122 123 |
# File 'lib/spatio-sdk/models/dm_mute_request.rb', line 121 def hash [until_seconds, forever, account_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
90 91 92 93 94 |
# File 'lib/spatio-sdk/models/dm_mute_request.rb', line 90 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/spatio-sdk/models/dm_mute_request.rb', line 150 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
98 99 100 101 |
# File 'lib/spatio-sdk/models/dm_mute_request.rb', line 98 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |