Class: Spatio::EmailFolder
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Spatio::EmailFolder
- Defined in:
- lib/spatio-sdk/models/email_folder.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#id ⇒ Object
Returns the value of attribute id.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#name ⇒ Object
Returns the value of attribute name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EmailFolder
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ EmailFolder
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/spatio-sdk/models/email_folder.rb', line 68 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::EmailFolder` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::EmailFolder`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
22 23 24 |
# File 'lib/spatio-sdk/models/email_folder.rb', line 22 def account_id @account_id end |
#created_at ⇒ Object
Returns the value of attribute created_at.
26 27 28 |
# File 'lib/spatio-sdk/models/email_folder.rb', line 26 def created_at @created_at end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/spatio-sdk/models/email_folder.rb', line 18 def id @id end |
#metadata ⇒ Object
Returns the value of attribute metadata.
24 25 26 |
# File 'lib/spatio-sdk/models/email_folder.rb', line 24 def @metadata end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/spatio-sdk/models/email_folder.rb', line 20 def name @name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
40 41 42 |
# File 'lib/spatio-sdk/models/email_folder.rb', line 40 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
45 46 47 |
# File 'lib/spatio-sdk/models/email_folder.rb', line 45 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 37 |
# File 'lib/spatio-sdk/models/email_folder.rb', line 29 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'account_id' => :'accountId', :'metadata' => :'metadata', :'created_at' => :'createdAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/spatio-sdk/models/email_folder.rb', line 164 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
61 62 63 64 |
# File 'lib/spatio-sdk/models/email_folder.rb', line 61 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 |
# File 'lib/spatio-sdk/models/email_folder.rb', line 50 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'account_id' => :'String', :'metadata' => :'Hash<String, Object>', :'created_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
139 140 141 142 143 144 145 146 147 |
# File 'lib/spatio-sdk/models/email_folder.rb', line 139 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && account_id == o.account_id && == o. && created_at == o.created_at end |
#eql?(o) ⇒ Boolean
151 152 153 |
# File 'lib/spatio-sdk/models/email_folder.rb', line 151 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
157 158 159 |
# File 'lib/spatio-sdk/models/email_folder.rb', line 157 def hash [id, name, account_id, , created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
109 110 111 112 113 114 115 116 117 |
# File 'lib/spatio-sdk/models/email_folder.rb', line 109 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/spatio-sdk/models/email_folder.rb', line 186 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
121 122 123 124 125 |
# File 'lib/spatio-sdk/models/email_folder.rb', line 121 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? true end |