Class: Spatio::FederatedSearchRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Spatio::FederatedSearchRequest
- Defined in:
- lib/spatio-sdk/models/federated_search_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#include_archived ⇒ Object
Returns the value of attribute include_archived.
-
#include_shared ⇒ Object
Returns the value of attribute include_shared.
-
#limit ⇒ Object
Returns the value of attribute limit.
-
#organization_id ⇒ Object
Returns the value of attribute organization_id.
-
#page_tokens ⇒ Object
Per-platform cursor for pagination.
-
#platforms ⇒ Object
Subset to fan out to.
-
#query ⇒ Object
Returns the value of attribute query.
-
#workspace_id ⇒ Object
Returns the value of attribute workspace_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FederatedSearchRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ FederatedSearchRequest
Initializes the object
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/spatio-sdk/models/federated_search_request.rb', line 104 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::FederatedSearchRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::FederatedSearchRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'query') self.query = attributes[:'query'] else self.query = nil end if attributes.key?(:'platforms') if (value = attributes[:'platforms']).is_a?(Array) self.platforms = value end end if attributes.key?(:'limit') self.limit = attributes[:'limit'] else self.limit = 25 end if attributes.key?(:'page_tokens') if (value = attributes[:'page_tokens']).is_a?(Hash) self.page_tokens = value end end if attributes.key?(:'workspace_id') self.workspace_id = attributes[:'workspace_id'] end if attributes.key?(:'organization_id') self.organization_id = attributes[:'organization_id'] end if attributes.key?(:'include_shared') self.include_shared = attributes[:'include_shared'] end if attributes.key?(:'include_archived') self.include_archived = attributes[:'include_archived'] end end |
Instance Attribute Details
#include_archived ⇒ Object
Returns the value of attribute include_archived.
34 35 36 |
# File 'lib/spatio-sdk/models/federated_search_request.rb', line 34 def include_archived @include_archived end |
#include_shared ⇒ Object
Returns the value of attribute include_shared.
32 33 34 |
# File 'lib/spatio-sdk/models/federated_search_request.rb', line 32 def include_shared @include_shared end |
#limit ⇒ Object
Returns the value of attribute limit.
23 24 25 |
# File 'lib/spatio-sdk/models/federated_search_request.rb', line 23 def limit @limit end |
#organization_id ⇒ Object
Returns the value of attribute organization_id.
30 31 32 |
# File 'lib/spatio-sdk/models/federated_search_request.rb', line 30 def organization_id @organization_id end |
#page_tokens ⇒ Object
Per-platform cursor for pagination.
26 27 28 |
# File 'lib/spatio-sdk/models/federated_search_request.rb', line 26 def page_tokens @page_tokens end |
#platforms ⇒ Object
Subset to fan out to. Empty means all available platforms.
21 22 23 |
# File 'lib/spatio-sdk/models/federated_search_request.rb', line 21 def platforms @platforms end |
#query ⇒ Object
Returns the value of attribute query.
18 19 20 |
# File 'lib/spatio-sdk/models/federated_search_request.rb', line 18 def query @query end |
#workspace_id ⇒ Object
Returns the value of attribute workspace_id.
28 29 30 |
# File 'lib/spatio-sdk/models/federated_search_request.rb', line 28 def workspace_id @workspace_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
73 74 75 |
# File 'lib/spatio-sdk/models/federated_search_request.rb', line 73 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
78 79 80 |
# File 'lib/spatio-sdk/models/federated_search_request.rb', line 78 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/spatio-sdk/models/federated_search_request.rb', line 59 def self.attribute_map { :'query' => :'query', :'platforms' => :'platforms', :'limit' => :'limit', :'page_tokens' => :'page_tokens', :'workspace_id' => :'workspace_id', :'organization_id' => :'organization_id', :'include_shared' => :'include_shared', :'include_archived' => :'include_archived' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/spatio-sdk/models/federated_search_request.rb', line 238 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
97 98 99 100 |
# File 'lib/spatio-sdk/models/federated_search_request.rb', line 97 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/spatio-sdk/models/federated_search_request.rb', line 83 def self.openapi_types { :'query' => :'String', :'platforms' => :'Array<String>', :'limit' => :'Integer', :'page_tokens' => :'Hash<String, String>', :'workspace_id' => :'String', :'organization_id' => :'String', :'include_shared' => :'Boolean', :'include_archived' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/spatio-sdk/models/federated_search_request.rb', line 210 def ==(o) return true if self.equal?(o) self.class == o.class && query == o.query && platforms == o.platforms && limit == o.limit && page_tokens == o.page_tokens && workspace_id == o.workspace_id && organization_id == o.organization_id && include_shared == o.include_shared && include_archived == o.include_archived end |
#eql?(o) ⇒ Boolean
225 226 227 |
# File 'lib/spatio-sdk/models/federated_search_request.rb', line 225 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
231 232 233 |
# File 'lib/spatio-sdk/models/federated_search_request.rb', line 231 def hash [query, platforms, limit, page_tokens, workspace_id, organization_id, include_shared, include_archived].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/spatio-sdk/models/federated_search_request.rb', line 161 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @query.nil? invalid_properties.push('invalid value for "query", query cannot be nil.') end if !@limit.nil? && @limit > 100 invalid_properties.push('invalid value for "limit", must be smaller than or equal to 100.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/spatio-sdk/models/federated_search_request.rb', line 260 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
177 178 179 180 181 182 |
# File 'lib/spatio-sdk/models/federated_search_request.rb', line 177 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @query.nil? return false if !@limit.nil? && @limit > 100 true end |