Class: Spatio::FilesAndFoldersResponse

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/files_and_folders_response.rb

Overview

Aggregated ‘folders, accounts` envelope used by the renderer’s file-browser. Calls ‘ListFiles` and `ListFolders` in parallel and merges the results — saves a round-trip when the UI shows both side-by-side.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ FilesAndFoldersResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/spatio-sdk/models/files_and_folders_response.rb', line 75

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::FilesAndFoldersResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::FilesAndFoldersResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'files')
    if (value = attributes[:'files']).is_a?(Array)
      self.files = value
    end
  end

  if attributes.key?(:'folders')
    if (value = attributes[:'folders']).is_a?(Array)
      self.folders = value
    end
  end

  if attributes.key?(:'accounts')
    if (value = attributes[:'accounts']).is_a?(Array)
      self.accounts = value
    end
  end

  if attributes.key?(:'total')
    self.total = attributes[:'total']
  else
    self.total = nil
  end

  if attributes.key?(:'has_more')
    self.has_more = attributes[:'has_more']
  else
    self.has_more = nil
  end

  if attributes.key?(:'next_offset')
    self.next_offset = attributes[:'next_offset']
  end
end

Instance Attribute Details

#accountsObject

Returns the value of attribute accounts.



23
24
25
# File 'lib/spatio-sdk/models/files_and_folders_response.rb', line 23

def accounts
  @accounts
end

#filesObject

Returns the value of attribute files.



19
20
21
# File 'lib/spatio-sdk/models/files_and_folders_response.rb', line 19

def files
  @files
end

#foldersObject

Returns the value of attribute folders.



21
22
23
# File 'lib/spatio-sdk/models/files_and_folders_response.rb', line 21

def folders
  @folders
end

#has_moreObject

Returns the value of attribute has_more.



27
28
29
# File 'lib/spatio-sdk/models/files_and_folders_response.rb', line 27

def has_more
  @has_more
end

#next_offsetObject

Returns the value of attribute next_offset.



29
30
31
# File 'lib/spatio-sdk/models/files_and_folders_response.rb', line 29

def next_offset
  @next_offset
end

#totalObject

Returns the value of attribute total.



25
26
27
# File 'lib/spatio-sdk/models/files_and_folders_response.rb', line 25

def total
  @total
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



44
45
46
# File 'lib/spatio-sdk/models/files_and_folders_response.rb', line 44

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



49
50
51
# File 'lib/spatio-sdk/models/files_and_folders_response.rb', line 49

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
40
41
# File 'lib/spatio-sdk/models/files_and_folders_response.rb', line 32

def self.attribute_map
  {
    :'files' => :'files',
    :'folders' => :'folders',
    :'accounts' => :'accounts',
    :'total' => :'total',
    :'has_more' => :'hasMore',
    :'next_offset' => :'nextOffset'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/spatio-sdk/models/files_and_folders_response.rb', line 197

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
70
71
# File 'lib/spatio-sdk/models/files_and_folders_response.rb', line 66

def self.openapi_nullable
  Set.new([
    :'files',
    :'folders',
  ])
end

.openapi_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
63
# File 'lib/spatio-sdk/models/files_and_folders_response.rb', line 54

def self.openapi_types
  {
    :'files' => :'Array<SpatioFile>',
    :'folders' => :'Array<Folder>',
    :'accounts' => :'Array<AccountStatus>',
    :'total' => :'Integer',
    :'has_more' => :'Boolean',
    :'next_offset' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



171
172
173
174
175
176
177
178
179
180
# File 'lib/spatio-sdk/models/files_and_folders_response.rb', line 171

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      files == o.files &&
      folders == o.folders &&
      accounts == o.accounts &&
      total == o.total &&
      has_more == o.has_more &&
      next_offset == o.next_offset
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


184
185
186
# File 'lib/spatio-sdk/models/files_and_folders_response.rb', line 184

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



190
191
192
# File 'lib/spatio-sdk/models/files_and_folders_response.rb', line 190

def hash
  [files, folders, accounts, total, has_more, next_offset].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/spatio-sdk/models/files_and_folders_response.rb', line 126

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @total.nil?
    invalid_properties.push('invalid value for "total", total cannot be nil.')
  end

  if @has_more.nil?
    invalid_properties.push('invalid value for "has_more", has_more cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/spatio-sdk/models/files_and_folders_response.rb', line 219

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



142
143
144
145
146
147
# File 'lib/spatio-sdk/models/files_and_folders_response.rb', line 142

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @total.nil?
  return false if @has_more.nil?
  true
end