Class: Spatio::Folder
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Spatio::Folder
- Defined in:
- lib/spatio-sdk/models/folder.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#id ⇒ Object
Returns the value of attribute id.
-
#name ⇒ Object
Returns the value of attribute name.
-
#parent_id ⇒ Object
Returns the value of attribute parent_id.
-
#path ⇒ Object
Display path from the root (e.g. ‘/Finance/Q3`).
-
#provider ⇒ Object
Returns the value of attribute provider.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Folder
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Folder
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/spatio-sdk/models/folder.rb', line 82 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::Folder` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::Folder`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'provider') self.provider = attributes[:'provider'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'parent_id') self.parent_id = attributes[:'parent_id'] end if attributes.key?(:'path') self.path = attributes[:'path'] else self.path = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
22 23 24 |
# File 'lib/spatio-sdk/models/folder.rb', line 22 def account_id @account_id end |
#created_at ⇒ Object
Returns the value of attribute created_at.
31 32 33 |
# File 'lib/spatio-sdk/models/folder.rb', line 31 def created_at @created_at end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/spatio-sdk/models/folder.rb', line 18 def id @id end |
#name ⇒ Object
Returns the value of attribute name.
24 25 26 |
# File 'lib/spatio-sdk/models/folder.rb', line 24 def name @name end |
#parent_id ⇒ Object
Returns the value of attribute parent_id.
26 27 28 |
# File 'lib/spatio-sdk/models/folder.rb', line 26 def parent_id @parent_id end |
#path ⇒ Object
Display path from the root (e.g. ‘/Finance/Q3`).
29 30 31 |
# File 'lib/spatio-sdk/models/folder.rb', line 29 def path @path end |
#provider ⇒ Object
Returns the value of attribute provider.
20 21 22 |
# File 'lib/spatio-sdk/models/folder.rb', line 20 def provider @provider end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
33 34 35 |
# File 'lib/spatio-sdk/models/folder.rb', line 33 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
50 51 52 |
# File 'lib/spatio-sdk/models/folder.rb', line 50 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
55 56 57 |
# File 'lib/spatio-sdk/models/folder.rb', line 55 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/spatio-sdk/models/folder.rb', line 36 def self.attribute_map { :'id' => :'id', :'provider' => :'provider', :'account_id' => :'accountId', :'name' => :'name', :'parent_id' => :'parentId', :'path' => :'path', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/spatio-sdk/models/folder.rb', line 259 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
74 75 76 77 78 |
# File 'lib/spatio-sdk/models/folder.rb', line 74 def self.openapi_nullable Set.new([ :'parent_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/spatio-sdk/models/folder.rb', line 60 def self.openapi_types { :'id' => :'String', :'provider' => :'String', :'account_id' => :'String', :'name' => :'String', :'parent_id' => :'String', :'path' => :'String', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/spatio-sdk/models/folder.rb', line 231 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && provider == o.provider && account_id == o.account_id && name == o.name && parent_id == o.parent_id && path == o.path && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
246 247 248 |
# File 'lib/spatio-sdk/models/folder.rb', line 246 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
252 253 254 |
# File 'lib/spatio-sdk/models/folder.rb', line 252 def hash [id, provider, account_id, name, parent_id, path, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/spatio-sdk/models/folder.rb', line 141 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @path.nil? invalid_properties.push('invalid value for "path", path cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/spatio-sdk/models/folder.rb', line 281 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
169 170 171 172 173 174 175 176 177 |
# File 'lib/spatio-sdk/models/folder.rb', line 169 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @name.nil? return false if @path.nil? return false if @created_at.nil? return false if @updated_at.nil? true end |