Class: Spatio::InboxItem

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/inbox_item.rb

Overview

A unified-feed item. Source-aware — ‘category` indicates which upstream platform (mail, dm, channel, mention, system) produced it; `id` is the inbox-item id (not the underlying message id).

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ InboxItem

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/spatio-sdk/models/inbox_item.rb', line 94

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::InboxItem` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::InboxItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  else
    self.category = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'snippet')
    self.snippet = attributes[:'snippet']
  end

  if attributes.key?(:'source')
    self.source = attributes[:'source']
  end

  if attributes.key?(:'source_id')
    self.source_id = attributes[:'source_id']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'is_read')
    self.is_read = attributes[:'is_read']
  end

  if attributes.key?(:'is_mention')
    self.is_mention = attributes[:'is_mention']
  end

  if attributes.key?(:'timestamp')
    self.timestamp = attributes[:'timestamp']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



31
32
33
# File 'lib/spatio-sdk/models/inbox_item.rb', line 31

def 
  @account_id
end

#categoryObject

Returns the value of attribute category.



21
22
23
# File 'lib/spatio-sdk/models/inbox_item.rb', line 21

def category
  @category
end

#idObject

Returns the value of attribute id.



19
20
21
# File 'lib/spatio-sdk/models/inbox_item.rb', line 19

def id
  @id
end

#is_mentionObject

Returns the value of attribute is_mention.



35
36
37
# File 'lib/spatio-sdk/models/inbox_item.rb', line 35

def is_mention
  @is_mention
end

#is_readObject

Returns the value of attribute is_read.



33
34
35
# File 'lib/spatio-sdk/models/inbox_item.rb', line 33

def is_read
  @is_read
end

#metadataObject

Returns the value of attribute metadata.



39
40
41
# File 'lib/spatio-sdk/models/inbox_item.rb', line 39

def 
  @metadata
end

#snippetObject

Returns the value of attribute snippet.



25
26
27
# File 'lib/spatio-sdk/models/inbox_item.rb', line 25

def snippet
  @snippet
end

#sourceObject

Returns the value of attribute source.



27
28
29
# File 'lib/spatio-sdk/models/inbox_item.rb', line 27

def source
  @source
end

#source_idObject

Returns the value of attribute source_id.



29
30
31
# File 'lib/spatio-sdk/models/inbox_item.rb', line 29

def source_id
  @source_id
end

#timestampObject

Returns the value of attribute timestamp.



37
38
39
# File 'lib/spatio-sdk/models/inbox_item.rb', line 37

def timestamp
  @timestamp
end

#titleObject

Returns the value of attribute title.



23
24
25
# File 'lib/spatio-sdk/models/inbox_item.rb', line 23

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



59
60
61
# File 'lib/spatio-sdk/models/inbox_item.rb', line 59

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



64
65
66
# File 'lib/spatio-sdk/models/inbox_item.rb', line 64

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/spatio-sdk/models/inbox_item.rb', line 42

def self.attribute_map
  {
    :'id' => :'id',
    :'category' => :'category',
    :'title' => :'title',
    :'snippet' => :'snippet',
    :'source' => :'source',
    :'source_id' => :'sourceId',
    :'account_id' => :'accountId',
    :'is_read' => :'isRead',
    :'is_mention' => :'isMention',
    :'timestamp' => :'timestamp',
    :'metadata' => :'metadata'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/spatio-sdk/models/inbox_item.rb', line 237

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



86
87
88
89
90
# File 'lib/spatio-sdk/models/inbox_item.rb', line 86

def self.openapi_nullable
  Set.new([
    :'account_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/spatio-sdk/models/inbox_item.rb', line 69

def self.openapi_types
  {
    :'id' => :'String',
    :'category' => :'String',
    :'title' => :'String',
    :'snippet' => :'String',
    :'source' => :'String',
    :'source_id' => :'String',
    :'account_id' => :'String',
    :'is_read' => :'Boolean',
    :'is_mention' => :'Boolean',
    :'timestamp' => :'Time',
    :'metadata' => :'Hash<String, Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/spatio-sdk/models/inbox_item.rb', line 206

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      category == o.category &&
      title == o.title &&
      snippet == o.snippet &&
      source == o.source &&
      source_id == o.source_id &&
       == o. &&
      is_read == o.is_read &&
      is_mention == o.is_mention &&
      timestamp == o.timestamp &&
       == o.
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


224
225
226
# File 'lib/spatio-sdk/models/inbox_item.rb', line 224

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



230
231
232
# File 'lib/spatio-sdk/models/inbox_item.rb', line 230

def hash
  [id, category, title, snippet, source, source_id, , is_read, is_mention, timestamp, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/spatio-sdk/models/inbox_item.rb', line 161

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @category.nil?
    invalid_properties.push('invalid value for "category", category cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/spatio-sdk/models/inbox_item.rb', line 259

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



177
178
179
180
181
182
# File 'lib/spatio-sdk/models/inbox_item.rb', line 177

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @category.nil?
  true
end