Class: Spatio::IntrospectionResponse

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/introspection_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ IntrospectionResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/spatio-sdk/models/introspection_response.rb', line 77

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::IntrospectionResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::IntrospectionResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'active')
    self.active = attributes[:'active']
  else
    self.active = nil
  end

  if attributes.key?(:'token_type')
    self.token_type = attributes[:'token_type']
  end

  if attributes.key?(:'client_id')
    self.client_id = attributes[:'client_id']
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'workspace_id')
    self.workspace_id = attributes[:'workspace_id']
  end

  if attributes.key?(:'scope')
    self.scope = attributes[:'scope']
  end

  if attributes.key?(:'exp')
    self.exp = attributes[:'exp']
  end
end

Instance Attribute Details

#activeObject

Returns the value of attribute active.



18
19
20
# File 'lib/spatio-sdk/models/introspection_response.rb', line 18

def active
  @active
end

#client_idObject

Returns the value of attribute client_id.



23
24
25
# File 'lib/spatio-sdk/models/introspection_response.rb', line 23

def client_id
  @client_id
end

#expObject

Returns the value of attribute exp.



31
32
33
# File 'lib/spatio-sdk/models/introspection_response.rb', line 31

def exp
  @exp
end

#scopeObject

Returns the value of attribute scope.



29
30
31
# File 'lib/spatio-sdk/models/introspection_response.rb', line 29

def scope
  @scope
end

#token_typeObject

‘oauth` or `pat`.



21
22
23
# File 'lib/spatio-sdk/models/introspection_response.rb', line 21

def token_type
  @token_type
end

#user_idObject

Returns the value of attribute user_id.



25
26
27
# File 'lib/spatio-sdk/models/introspection_response.rb', line 25

def user_id
  @user_id
end

#workspace_idObject

Returns the value of attribute workspace_id.



27
28
29
# File 'lib/spatio-sdk/models/introspection_response.rb', line 27

def workspace_id
  @workspace_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



47
48
49
# File 'lib/spatio-sdk/models/introspection_response.rb', line 47

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



52
53
54
# File 'lib/spatio-sdk/models/introspection_response.rb', line 52

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
43
44
# File 'lib/spatio-sdk/models/introspection_response.rb', line 34

def self.attribute_map
  {
    :'active' => :'active',
    :'token_type' => :'token_type',
    :'client_id' => :'client_id',
    :'user_id' => :'user_id',
    :'workspace_id' => :'workspace_id',
    :'scope' => :'scope',
    :'exp' => :'exp'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/spatio-sdk/models/introspection_response.rb', line 181

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



70
71
72
73
# File 'lib/spatio-sdk/models/introspection_response.rb', line 70

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



57
58
59
60
61
62
63
64
65
66
67
# File 'lib/spatio-sdk/models/introspection_response.rb', line 57

def self.openapi_types
  {
    :'active' => :'Boolean',
    :'token_type' => :'String',
    :'client_id' => :'String',
    :'user_id' => :'String',
    :'workspace_id' => :'String',
    :'scope' => :'String',
    :'exp' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



154
155
156
157
158
159
160
161
162
163
164
# File 'lib/spatio-sdk/models/introspection_response.rb', line 154

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      active == o.active &&
      token_type == o.token_type &&
      client_id == o.client_id &&
      user_id == o.user_id &&
      workspace_id == o.workspace_id &&
      scope == o.scope &&
      exp == o.exp
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


168
169
170
# File 'lib/spatio-sdk/models/introspection_response.rb', line 168

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



174
175
176
# File 'lib/spatio-sdk/models/introspection_response.rb', line 174

def hash
  [active, token_type, client_id, user_id, workspace_id, scope, exp].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



124
125
126
127
128
129
130
131
132
# File 'lib/spatio-sdk/models/introspection_response.rb', line 124

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @active.nil?
    invalid_properties.push('invalid value for "active", active cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/spatio-sdk/models/introspection_response.rb', line 203

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



136
137
138
139
140
# File 'lib/spatio-sdk/models/introspection_response.rb', line 136

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @active.nil?
  true
end