Class: Spatio::IssueCollaborationToken200Response
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Spatio::IssueCollaborationToken200Response
- Defined in:
- lib/spatio-sdk/models/issue_collaboration_token200_response.rb
Instance Attribute Summary collapse
-
#expires_at ⇒ Object
Returns the value of attribute expires_at.
-
#expires_in ⇒ Object
Seconds until the token expires.
-
#room ⇒ Object
Returns the value of attribute room.
-
#token ⇒ Object
HS256 JWT, signed with the shared platform/worker secret.
-
#ws_url ⇒ Object
Base WebSocket URL of the Yjs worker.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IssueCollaborationToken200Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ IssueCollaborationToken200Response
Initializes the object
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/spatio-sdk/models/issue_collaboration_token200_response.rb', line 71 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::IssueCollaborationToken200Response` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::IssueCollaborationToken200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'token') self.token = attributes[:'token'] else self.token = nil end if attributes.key?(:'ws_url') self.ws_url = attributes[:'ws_url'] else self.ws_url = nil end if attributes.key?(:'room') self.room = attributes[:'room'] end if attributes.key?(:'expires_at') self.expires_at = attributes[:'expires_at'] else self.expires_at = nil end if attributes.key?(:'expires_in') self.expires_in = attributes[:'expires_in'] else self.expires_in = nil end end |
Instance Attribute Details
#expires_at ⇒ Object
Returns the value of attribute expires_at.
26 27 28 |
# File 'lib/spatio-sdk/models/issue_collaboration_token200_response.rb', line 26 def expires_at @expires_at end |
#expires_in ⇒ Object
Seconds until the token expires.
29 30 31 |
# File 'lib/spatio-sdk/models/issue_collaboration_token200_response.rb', line 29 def expires_in @expires_in end |
#room ⇒ Object
Returns the value of attribute room.
24 25 26 |
# File 'lib/spatio-sdk/models/issue_collaboration_token200_response.rb', line 24 def room @room end |
#token ⇒ Object
HS256 JWT, signed with the shared platform/worker secret.
19 20 21 |
# File 'lib/spatio-sdk/models/issue_collaboration_token200_response.rb', line 19 def token @token end |
#ws_url ⇒ Object
Base WebSocket URL of the Yjs worker.
22 23 24 |
# File 'lib/spatio-sdk/models/issue_collaboration_token200_response.rb', line 22 def ws_url @ws_url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
43 44 45 |
# File 'lib/spatio-sdk/models/issue_collaboration_token200_response.rb', line 43 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
48 49 50 |
# File 'lib/spatio-sdk/models/issue_collaboration_token200_response.rb', line 48 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 |
# File 'lib/spatio-sdk/models/issue_collaboration_token200_response.rb', line 32 def self.attribute_map { :'token' => :'token', :'ws_url' => :'ws_url', :'room' => :'room', :'expires_at' => :'expires_at', :'expires_in' => :'expires_in' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/spatio-sdk/models/issue_collaboration_token200_response.rb', line 216 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
64 65 66 67 |
# File 'lib/spatio-sdk/models/issue_collaboration_token200_response.rb', line 64 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 |
# File 'lib/spatio-sdk/models/issue_collaboration_token200_response.rb', line 53 def self.openapi_types { :'token' => :'String', :'ws_url' => :'String', :'room' => :'String', :'expires_at' => :'Time', :'expires_in' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
191 192 193 194 195 196 197 198 199 |
# File 'lib/spatio-sdk/models/issue_collaboration_token200_response.rb', line 191 def ==(o) return true if self.equal?(o) self.class == o.class && token == o.token && ws_url == o.ws_url && room == o.room && expires_at == o.expires_at && expires_in == o.expires_in end |
#eql?(o) ⇒ Boolean
203 204 205 |
# File 'lib/spatio-sdk/models/issue_collaboration_token200_response.rb', line 203 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
209 210 211 |
# File 'lib/spatio-sdk/models/issue_collaboration_token200_response.rb', line 209 def hash [token, ws_url, room, expires_at, expires_in].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/spatio-sdk/models/issue_collaboration_token200_response.rb', line 116 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @token.nil? invalid_properties.push('invalid value for "token", token cannot be nil.') end if @ws_url.nil? invalid_properties.push('invalid value for "ws_url", ws_url cannot be nil.') end if @expires_at.nil? invalid_properties.push('invalid value for "expires_at", expires_at cannot be nil.') end if @expires_in.nil? invalid_properties.push('invalid value for "expires_in", expires_in cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/spatio-sdk/models/issue_collaboration_token200_response.rb', line 238 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
140 141 142 143 144 145 146 147 |
# File 'lib/spatio-sdk/models/issue_collaboration_token200_response.rb', line 140 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @token.nil? return false if @ws_url.nil? return false if @expires_at.nil? return false if @expires_in.nil? true end |