Class: Spatio::JWK

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/jwk.rb

Overview

A single JSON Web Key (RFC 7517 4) — RSA public key.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ JWK

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/spatio-sdk/models/jwk.rb', line 75

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::JWK` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::JWK`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'kty')
    self.kty = attributes[:'kty']
  else
    self.kty = nil
  end

  if attributes.key?(:'use')
    self.use = attributes[:'use']
  else
    self.use = nil
  end

  if attributes.key?(:'alg')
    self.alg = attributes[:'alg']
  else
    self.alg = nil
  end

  if attributes.key?(:'kid')
    self.kid = attributes[:'kid']
  else
    self.kid = nil
  end

  if attributes.key?(:'n')
    self.n = attributes[:'n']
  else
    self.n = nil
  end

  if attributes.key?(:'e')
    self.e = attributes[:'e']
  else
    self.e = nil
  end
end

Instance Attribute Details

#algObject

Returns the value of attribute alg.



23
24
25
# File 'lib/spatio-sdk/models/jwk.rb', line 23

def alg
  @alg
end

#eObject

Base64url-encoded RSA exponent. Almost always "AQAB".



31
32
33
# File 'lib/spatio-sdk/models/jwk.rb', line 31

def e
  @e
end

#kidObject

Returns the value of attribute kid.



25
26
27
# File 'lib/spatio-sdk/models/jwk.rb', line 25

def kid
  @kid
end

#ktyObject

Returns the value of attribute kty.



19
20
21
# File 'lib/spatio-sdk/models/jwk.rb', line 19

def kty
  @kty
end

#nObject

Base64url-encoded RSA modulus.



28
29
30
# File 'lib/spatio-sdk/models/jwk.rb', line 28

def n
  @n
end

#useObject

Returns the value of attribute use.



21
22
23
# File 'lib/spatio-sdk/models/jwk.rb', line 21

def use
  @use
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



46
47
48
# File 'lib/spatio-sdk/models/jwk.rb', line 46

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/spatio-sdk/models/jwk.rb', line 51

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
43
# File 'lib/spatio-sdk/models/jwk.rb', line 34

def self.attribute_map
  {
    :'kty' => :'kty',
    :'use' => :'use',
    :'alg' => :'alg',
    :'kid' => :'kid',
    :'n' => :'n',
    :'e' => :'e'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/spatio-sdk/models/jwk.rb', line 259

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



68
69
70
71
# File 'lib/spatio-sdk/models/jwk.rb', line 68

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
65
# File 'lib/spatio-sdk/models/jwk.rb', line 56

def self.openapi_types
  {
    :'kty' => :'String',
    :'use' => :'String',
    :'alg' => :'String',
    :'kid' => :'String',
    :'n' => :'String',
    :'e' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



233
234
235
236
237
238
239
240
241
242
# File 'lib/spatio-sdk/models/jwk.rb', line 233

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      kty == o.kty &&
      use == o.use &&
      alg == o.alg &&
      kid == o.kid &&
      n == o.n &&
      e == o.e
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


246
247
248
# File 'lib/spatio-sdk/models/jwk.rb', line 246

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



252
253
254
# File 'lib/spatio-sdk/models/jwk.rb', line 252

def hash
  [kty, use, alg, kid, n, e].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/spatio-sdk/models/jwk.rb', line 128

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @kty.nil?
    invalid_properties.push('invalid value for "kty", kty cannot be nil.')
  end

  if @use.nil?
    invalid_properties.push('invalid value for "use", use cannot be nil.')
  end

  if @alg.nil?
    invalid_properties.push('invalid value for "alg", alg cannot be nil.')
  end

  if @kid.nil?
    invalid_properties.push('invalid value for "kid", kid cannot be nil.')
  end

  if @n.nil?
    invalid_properties.push('invalid value for "n", n cannot be nil.')
  end

  if @e.nil?
    invalid_properties.push('invalid value for "e", e cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/spatio-sdk/models/jwk.rb', line 281

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



160
161
162
163
164
165
166
167
168
169
# File 'lib/spatio-sdk/models/jwk.rb', line 160

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @kty.nil?
  return false if @use.nil?
  return false if @alg.nil?
  return false if @kid.nil?
  return false if @n.nil?
  return false if @e.nil?
  true
end