Class: Spatio::KeyBinding

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/key_binding.rb

Overview

Merged user-customized key binding.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ KeyBinding

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/spatio-sdk/models/key_binding.rb', line 93

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::KeyBinding` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::KeyBinding`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'action_id')
    self.action_id = attributes[:'action_id']
  else
    self.action_id = nil
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  end

  if attributes.key?(:'modifiers')
    if (value = attributes[:'modifiers']).is_a?(Array)
      self.modifiers = value
    end
  end

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  end

  if attributes.key?(:'scope')
    self.scope = attributes[:'scope']
  end

  if attributes.key?(:'display_order')
    self.display_order = attributes[:'display_order']
  end

  if attributes.key?(:'is_custom')
    self.is_custom = attributes[:'is_custom']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end
end

Instance Attribute Details

#action_idObject

Returns the value of attribute action_id.



21
22
23
# File 'lib/spatio-sdk/models/key_binding.rb', line 21

def action_id
  @action_id
end

#categoryObject

Returns the value of attribute category.



31
32
33
# File 'lib/spatio-sdk/models/key_binding.rb', line 31

def category
  @category
end

#descriptionObject

Returns the value of attribute description.



25
26
27
# File 'lib/spatio-sdk/models/key_binding.rb', line 25

def description
  @description
end

#display_nameObject

Returns the value of attribute display_name.



23
24
25
# File 'lib/spatio-sdk/models/key_binding.rb', line 23

def display_name
  @display_name
end

#display_orderObject

Returns the value of attribute display_order.



35
36
37
# File 'lib/spatio-sdk/models/key_binding.rb', line 35

def display_order
  @display_order
end

#idObject

Returns the value of attribute id.



19
20
21
# File 'lib/spatio-sdk/models/key_binding.rb', line 19

def id
  @id
end

#is_customObject

Returns the value of attribute is_custom.



37
38
39
# File 'lib/spatio-sdk/models/key_binding.rb', line 37

def is_custom
  @is_custom
end

#keyObject

Returns the value of attribute key.



27
28
29
# File 'lib/spatio-sdk/models/key_binding.rb', line 27

def key
  @key
end

#metadataObject

Returns the value of attribute metadata.



39
40
41
# File 'lib/spatio-sdk/models/key_binding.rb', line 39

def 
  @metadata
end

#modifiersObject

Returns the value of attribute modifiers.



29
30
31
# File 'lib/spatio-sdk/models/key_binding.rb', line 29

def modifiers
  @modifiers
end

#scopeObject

Returns the value of attribute scope.



33
34
35
# File 'lib/spatio-sdk/models/key_binding.rb', line 33

def scope
  @scope
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



59
60
61
# File 'lib/spatio-sdk/models/key_binding.rb', line 59

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



64
65
66
# File 'lib/spatio-sdk/models/key_binding.rb', line 64

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/spatio-sdk/models/key_binding.rb', line 42

def self.attribute_map
  {
    :'id' => :'id',
    :'action_id' => :'actionId',
    :'display_name' => :'displayName',
    :'description' => :'description',
    :'key' => :'key',
    :'modifiers' => :'modifiers',
    :'category' => :'category',
    :'scope' => :'scope',
    :'display_order' => :'displayOrder',
    :'is_custom' => :'isCustom',
    :'metadata' => :'metadata'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/spatio-sdk/models/key_binding.rb', line 238

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



86
87
88
89
# File 'lib/spatio-sdk/models/key_binding.rb', line 86

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/spatio-sdk/models/key_binding.rb', line 69

def self.openapi_types
  {
    :'id' => :'String',
    :'action_id' => :'String',
    :'display_name' => :'String',
    :'description' => :'String',
    :'key' => :'String',
    :'modifiers' => :'Array<String>',
    :'category' => :'String',
    :'scope' => :'String',
    :'display_order' => :'Integer',
    :'is_custom' => :'Boolean',
    :'metadata' => :'Hash<String, Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/spatio-sdk/models/key_binding.rb', line 207

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      action_id == o.action_id &&
      display_name == o.display_name &&
      description == o.description &&
      key == o.key &&
      modifiers == o.modifiers &&
      category == o.category &&
      scope == o.scope &&
      display_order == o.display_order &&
      is_custom == o.is_custom &&
       == o.
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


225
226
227
# File 'lib/spatio-sdk/models/key_binding.rb', line 225

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



231
232
233
# File 'lib/spatio-sdk/models/key_binding.rb', line 231

def hash
  [id, action_id, display_name, description, key, modifiers, category, scope, display_order, is_custom, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/spatio-sdk/models/key_binding.rb', line 162

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @action_id.nil?
    invalid_properties.push('invalid value for "action_id", action_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/spatio-sdk/models/key_binding.rb', line 260

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



178
179
180
181
182
183
# File 'lib/spatio-sdk/models/key_binding.rb', line 178

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @action_id.nil?
  true
end