Class: Spatio::ListChannelsResponse

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/list_channels_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListChannelsResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/spatio-sdk/models/list_channels_response.rb', line 66

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::ListChannelsResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::ListChannelsResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'channels')
    if (value = attributes[:'channels']).is_a?(Array)
      self.channels = value
    end
  end

  if attributes.key?(:'total')
    self.total = attributes[:'total']
  else
    self.total = nil
  end

  if attributes.key?(:'next_cursor')
    self.next_cursor = attributes[:'next_cursor']
  end

  if attributes.key?(:'provider')
    self.provider = attributes[:'provider']
  else
    self.provider = nil
  end
end

Instance Attribute Details

#channelsObject

‘null` when no results (Go nil-slice serialization).



19
20
21
# File 'lib/spatio-sdk/models/list_channels_response.rb', line 19

def channels
  @channels
end

#next_cursorObject

Returns the value of attribute next_cursor.



23
24
25
# File 'lib/spatio-sdk/models/list_channels_response.rb', line 23

def next_cursor
  @next_cursor
end

#providerObject

Returns the value of attribute provider.



25
26
27
# File 'lib/spatio-sdk/models/list_channels_response.rb', line 25

def provider
  @provider
end

#totalObject

Returns the value of attribute total.



21
22
23
# File 'lib/spatio-sdk/models/list_channels_response.rb', line 21

def total
  @total
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



38
39
40
# File 'lib/spatio-sdk/models/list_channels_response.rb', line 38

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



43
44
45
# File 'lib/spatio-sdk/models/list_channels_response.rb', line 43

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
35
# File 'lib/spatio-sdk/models/list_channels_response.rb', line 28

def self.attribute_map
  {
    :'channels' => :'channels',
    :'total' => :'total',
    :'next_cursor' => :'nextCursor',
    :'provider' => :'provider'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/spatio-sdk/models/list_channels_response.rb', line 174

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



58
59
60
61
62
# File 'lib/spatio-sdk/models/list_channels_response.rb', line 58

def self.openapi_nullable
  Set.new([
    :'channels',
  ])
end

.openapi_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
55
# File 'lib/spatio-sdk/models/list_channels_response.rb', line 48

def self.openapi_types
  {
    :'channels' => :'Array<Channel>',
    :'total' => :'Integer',
    :'next_cursor' => :'String',
    :'provider' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



150
151
152
153
154
155
156
157
# File 'lib/spatio-sdk/models/list_channels_response.rb', line 150

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      channels == o.channels &&
      total == o.total &&
      next_cursor == o.next_cursor &&
      provider == o.provider
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


161
162
163
# File 'lib/spatio-sdk/models/list_channels_response.rb', line 161

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



167
168
169
# File 'lib/spatio-sdk/models/list_channels_response.rb', line 167

def hash
  [channels, total, next_cursor, provider].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/spatio-sdk/models/list_channels_response.rb', line 105

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @total.nil?
    invalid_properties.push('invalid value for "total", total cannot be nil.')
  end

  if @provider.nil?
    invalid_properties.push('invalid value for "provider", provider cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/spatio-sdk/models/list_channels_response.rb', line 196

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



121
122
123
124
125
126
# File 'lib/spatio-sdk/models/list_channels_response.rb', line 121

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @total.nil?
  return false if @provider.nil?
  true
end