Class: Spatio::ListEventsData
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Spatio::ListEventsData
- Defined in:
- lib/spatio-sdk/models/list_events_data.rb
Overview
Shape of ‘data` when returned by `listEvents`. Wrapped inside a CalendarOperationResult — clients should access this as `result.data` after checking `result.success`.
Instance Attribute Summary collapse
-
#events ⇒ Object
‘null` when there are no results (Go nil-slice serialization).
-
#next_page_token ⇒ Object
Returns the value of attribute next_page_token.
-
#total_results ⇒ Object
Returns the value of attribute total_results.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListEventsData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListEventsData
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/spatio-sdk/models/list_events_data.rb', line 67 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::ListEventsData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::ListEventsData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'events') if (value = attributes[:'events']).is_a?(Array) self.events = value end end if attributes.key?(:'next_page_token') self.next_page_token = attributes[:'next_page_token'] end if attributes.key?(:'total_results') self.total_results = attributes[:'total_results'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end end |
Instance Attribute Details
#events ⇒ Object
‘null` when there are no results (Go nil-slice serialization).
20 21 22 |
# File 'lib/spatio-sdk/models/list_events_data.rb', line 20 def events @events end |
#next_page_token ⇒ Object
Returns the value of attribute next_page_token.
22 23 24 |
# File 'lib/spatio-sdk/models/list_events_data.rb', line 22 def next_page_token @next_page_token end |
#total_results ⇒ Object
Returns the value of attribute total_results.
24 25 26 |
# File 'lib/spatio-sdk/models/list_events_data.rb', line 24 def total_results @total_results end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
26 27 28 |
# File 'lib/spatio-sdk/models/list_events_data.rb', line 26 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
39 40 41 |
# File 'lib/spatio-sdk/models/list_events_data.rb', line 39 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
44 45 46 |
# File 'lib/spatio-sdk/models/list_events_data.rb', line 44 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 |
# File 'lib/spatio-sdk/models/list_events_data.rb', line 29 def self.attribute_map { :'events' => :'events', :'next_page_token' => :'next_page_token', :'total_results' => :'total_results', :'updated_at' => :'updated_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/spatio-sdk/models/list_events_data.rb', line 158 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
59 60 61 62 63 |
# File 'lib/spatio-sdk/models/list_events_data.rb', line 59 def self.openapi_nullable Set.new([ :'events', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
49 50 51 52 53 54 55 56 |
# File 'lib/spatio-sdk/models/list_events_data.rb', line 49 def self.openapi_types { :'events' => :'Array<SpatioEvent>', :'next_page_token' => :'String', :'total_results' => :'Integer', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
134 135 136 137 138 139 140 141 |
# File 'lib/spatio-sdk/models/list_events_data.rb', line 134 def ==(o) return true if self.equal?(o) self.class == o.class && events == o.events && next_page_token == o.next_page_token && total_results == o.total_results && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
145 146 147 |
# File 'lib/spatio-sdk/models/list_events_data.rb', line 145 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
151 152 153 |
# File 'lib/spatio-sdk/models/list_events_data.rb', line 151 def hash [events, next_page_token, total_results, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
104 105 106 107 108 109 110 111 112 |
# File 'lib/spatio-sdk/models/list_events_data.rb', line 104 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/spatio-sdk/models/list_events_data.rb', line 180 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
116 117 118 119 120 |
# File 'lib/spatio-sdk/models/list_events_data.rb', line 116 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @updated_at.nil? true end |