Class: Spatio::LogosApi
- Inherits:
-
Object
- Object
- Spatio::LogosApi
- Defined in:
- lib/spatio-sdk/api/logos_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_domain_logo(domain, opts = {}) ⇒ GetDomainLogo200Response
Resolve a domain to its logo URL (CDN-cached 24h).
-
#get_domain_logo_with_http_info(domain, opts = {}) ⇒ Array<(GetDomainLogo200Response, Integer, Hash)>
Resolve a domain to its logo URL (CDN-cached 24h).
-
#get_email_logo(email, opts = {}) ⇒ Hash<String, Object>
Resolve an email address to its domain logo URL.
-
#get_email_logo_with_http_info(email, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Resolve an email address to its domain logo URL.
-
#get_logos_batch(request_body, opts = {}) ⇒ Hash<String, Object>
Batch-resolve a list of domains/emails to logo URLs in one call.
-
#get_logos_batch_with_http_info(request_body, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Batch-resolve a list of domains/emails to logo URLs in one call.
-
#initialize(api_client = ApiClient.default) ⇒ LogosApi
constructor
A new instance of LogosApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/spatio-sdk/api/logos_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_domain_logo(domain, opts = {}) ⇒ GetDomainLogo200Response
Resolve a domain to its logo URL (CDN-cached 24h).
26 27 28 29 |
# File 'lib/spatio-sdk/api/logos_api.rb', line 26 def get_domain_logo(domain, opts = {}) data, _status_code, _headers = get_domain_logo_with_http_info(domain, opts) data end |
#get_domain_logo_with_http_info(domain, opts = {}) ⇒ Array<(GetDomainLogo200Response, Integer, Hash)>
Resolve a domain to its logo URL (CDN-cached 24h).
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/spatio-sdk/api/logos_api.rb', line 35 def get_domain_logo_with_http_info(domain, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LogosApi.get_domain_logo ...' end # verify the required parameter 'domain' is set if @api_client.config.client_side_validation && domain.nil? fail ArgumentError, "Missing the required parameter 'domain' when calling LogosApi.get_domain_logo" end # resource path local_var_path = '/v1/logos/domain/{domain}'.sub('{domain}', CGI.escape(domain.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetDomainLogo200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"LogosApi.get_domain_logo", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LogosApi#get_domain_logo\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_email_logo(email, opts = {}) ⇒ Hash<String, Object>
Resolve an email address to its domain logo URL.
87 88 89 90 |
# File 'lib/spatio-sdk/api/logos_api.rb', line 87 def get_email_logo(email, opts = {}) data, _status_code, _headers = get_email_logo_with_http_info(email, opts) data end |
#get_email_logo_with_http_info(email, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Resolve an email address to its domain logo URL.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/spatio-sdk/api/logos_api.rb', line 96 def get_email_logo_with_http_info(email, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LogosApi.get_email_logo ...' end # verify the required parameter 'email' is set if @api_client.config.client_side_validation && email.nil? fail ArgumentError, "Missing the required parameter 'email' when calling LogosApi.get_email_logo" end # resource path local_var_path = '/v1/logos/email/{email}'.sub('{email}', CGI.escape(email.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Hash<String, Object>' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"LogosApi.get_email_logo", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LogosApi#get_email_logo\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_logos_batch(request_body, opts = {}) ⇒ Hash<String, Object>
Batch-resolve a list of domains/emails to logo URLs in one call.
148 149 150 151 |
# File 'lib/spatio-sdk/api/logos_api.rb', line 148 def get_logos_batch(request_body, opts = {}) data, _status_code, _headers = get_logos_batch_with_http_info(request_body, opts) data end |
#get_logos_batch_with_http_info(request_body, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Batch-resolve a list of domains/emails to logo URLs in one call.
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/spatio-sdk/api/logos_api.rb', line 157 def get_logos_batch_with_http_info(request_body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LogosApi.get_logos_batch ...' end # verify the required parameter 'request_body' is set if @api_client.config.client_side_validation && request_body.nil? fail ArgumentError, "Missing the required parameter 'request_body' when calling LogosApi.get_logos_batch" end # resource path local_var_path = '/v1/logos/batch' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(request_body) # return_type return_type = opts[:debug_return_type] || 'Hash<String, Object>' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"LogosApi.get_logos_batch", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LogosApi#get_logos_batch\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |