Class: Spatio::OrganizationInvitation

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/organization_invitation.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OrganizationInvitation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/spatio-sdk/models/organization_invitation.rb', line 118

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::OrganizationInvitation` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::OrganizationInvitation`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'organization_id')
    self.organization_id = attributes[:'organization_id']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  else
    self.email = nil
  end

  if attributes.key?(:'role')
    self.role = attributes[:'role']
  else
    self.role = nil
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'accepted_at')
    self.accepted_at = attributes[:'accepted_at']
  end

  if attributes.key?(:'revoked_at')
    self.revoked_at = attributes[:'revoked_at']
  end

  if attributes.key?(:'invited_by')
    self.invited_by = attributes[:'invited_by']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end
end

Instance Attribute Details

#accepted_atObject

Returns the value of attribute accepted_at.



33
34
35
# File 'lib/spatio-sdk/models/organization_invitation.rb', line 33

def accepted_at
  @accepted_at
end

#created_atObject

Returns the value of attribute created_at.



31
32
33
# File 'lib/spatio-sdk/models/organization_invitation.rb', line 31

def created_at
  @created_at
end

#emailObject

Returns the value of attribute email.



22
23
24
# File 'lib/spatio-sdk/models/organization_invitation.rb', line 22

def email
  @email
end

#expires_atObject

Returns the value of attribute expires_at.



29
30
31
# File 'lib/spatio-sdk/models/organization_invitation.rb', line 29

def expires_at
  @expires_at
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/spatio-sdk/models/organization_invitation.rb', line 18

def id
  @id
end

#invited_byObject

Returns the value of attribute invited_by.



37
38
39
# File 'lib/spatio-sdk/models/organization_invitation.rb', line 37

def invited_by
  @invited_by
end

#organization_idObject

Returns the value of attribute organization_id.



20
21
22
# File 'lib/spatio-sdk/models/organization_invitation.rb', line 20

def organization_id
  @organization_id
end

#revoked_atObject

Returns the value of attribute revoked_at.



35
36
37
# File 'lib/spatio-sdk/models/organization_invitation.rb', line 35

def revoked_at
  @revoked_at
end

#roleObject

Returns the value of attribute role.



24
25
26
# File 'lib/spatio-sdk/models/organization_invitation.rb', line 24

def role
  @role
end

#statusObject

Returns the value of attribute status.



39
40
41
# File 'lib/spatio-sdk/models/organization_invitation.rb', line 39

def status
  @status
end

#tokenObject

Opaque invitation token (omitted on list responses).



27
28
29
# File 'lib/spatio-sdk/models/organization_invitation.rb', line 27

def token
  @token
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



81
82
83
# File 'lib/spatio-sdk/models/organization_invitation.rb', line 81

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



86
87
88
# File 'lib/spatio-sdk/models/organization_invitation.rb', line 86

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/spatio-sdk/models/organization_invitation.rb', line 64

def self.attribute_map
  {
    :'id' => :'id',
    :'organization_id' => :'organizationId',
    :'email' => :'email',
    :'role' => :'role',
    :'token' => :'token',
    :'expires_at' => :'expiresAt',
    :'created_at' => :'createdAt',
    :'accepted_at' => :'acceptedAt',
    :'revoked_at' => :'revokedAt',
    :'invited_by' => :'invitedBy',
    :'status' => :'status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/spatio-sdk/models/organization_invitation.rb', line 305

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



108
109
110
111
112
113
114
# File 'lib/spatio-sdk/models/organization_invitation.rb', line 108

def self.openapi_nullable
  Set.new([
    :'expires_at',
    :'accepted_at',
    :'revoked_at',
  ])
end

.openapi_typesObject

Attribute type mapping.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/spatio-sdk/models/organization_invitation.rb', line 91

def self.openapi_types
  {
    :'id' => :'String',
    :'organization_id' => :'String',
    :'email' => :'String',
    :'role' => :'String',
    :'token' => :'String',
    :'expires_at' => :'Time',
    :'created_at' => :'Time',
    :'accepted_at' => :'Time',
    :'revoked_at' => :'Time',
    :'invited_by' => :'OrganizationMemberInvitedBy',
    :'status' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/spatio-sdk/models/organization_invitation.rb', line 274

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      organization_id == o.organization_id &&
      email == o.email &&
      role == o.role &&
      token == o.token &&
      expires_at == o.expires_at &&
      created_at == o.created_at &&
      accepted_at == o.accepted_at &&
      revoked_at == o.revoked_at &&
      invited_by == o.invited_by &&
      status == o.status
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


292
293
294
# File 'lib/spatio-sdk/models/organization_invitation.rb', line 292

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



298
299
300
# File 'lib/spatio-sdk/models/organization_invitation.rb', line 298

def hash
  [id, organization_id, email, role, token, expires_at, created_at, accepted_at, revoked_at, invited_by, status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/spatio-sdk/models/organization_invitation.rb', line 187

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @email.nil?
    invalid_properties.push('invalid value for "email", email cannot be nil.')
  end

  if @role.nil?
    invalid_properties.push('invalid value for "role", role cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



327
328
329
330
331
332
333
334
335
336
337
338
339
# File 'lib/spatio-sdk/models/organization_invitation.rb', line 327

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



211
212
213
214
215
216
217
218
219
220
# File 'lib/spatio-sdk/models/organization_invitation.rb', line 211

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @email.nil?
  return false if @role.nil?
  return false if @created_at.nil?
  status_validator = EnumAttributeValidator.new('String', ["pending", "accepted", "revoked", "expired"])
  return false unless status_validator.valid?(@status)
  true
end