Class: Spatio::OrganizationMember

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/organization_member.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OrganizationMember

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/spatio-sdk/models/organization_member.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::OrganizationMember` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::OrganizationMember`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  else
    self.user_id = nil
  end

  if attributes.key?(:'role')
    self.role = attributes[:'role']
  else
    self.role = nil
  end

  if attributes.key?(:'joined_at')
    self.joined_at = attributes[:'joined_at']
  else
    self.joined_at = nil
  end

  if attributes.key?(:'invited_by')
    self.invited_by = attributes[:'invited_by']
  end

  if attributes.key?(:'user')
    if (value = attributes[:'user']).is_a?(Hash)
      self.user = value
    end
  end
end

Instance Attribute Details

#idObject

‘OrganizationMember` row id.



19
20
21
# File 'lib/spatio-sdk/models/organization_member.rb', line 19

def id
  @id
end

#invited_byObject

Returns the value of attribute invited_by.



27
28
29
# File 'lib/spatio-sdk/models/organization_member.rb', line 27

def invited_by
  @invited_by
end

#joined_atObject

Returns the value of attribute joined_at.



25
26
27
# File 'lib/spatio-sdk/models/organization_member.rb', line 25

def joined_at
  @joined_at
end

#roleObject

Returns the value of attribute role.



23
24
25
# File 'lib/spatio-sdk/models/organization_member.rb', line 23

def role
  @role
end

#userObject

Embedded user-profile fields (id, email, name, profilePhoto, …).



30
31
32
# File 'lib/spatio-sdk/models/organization_member.rb', line 30

def user
  @user
end

#user_idObject

Returns the value of attribute user_id.



21
22
23
# File 'lib/spatio-sdk/models/organization_member.rb', line 21

def user_id
  @user_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



67
68
69
# File 'lib/spatio-sdk/models/organization_member.rb', line 67

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



72
73
74
# File 'lib/spatio-sdk/models/organization_member.rb', line 72

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
# File 'lib/spatio-sdk/models/organization_member.rb', line 55

def self.attribute_map
  {
    :'id' => :'id',
    :'user_id' => :'userId',
    :'role' => :'role',
    :'joined_at' => :'joinedAt',
    :'invited_by' => :'invitedBy',
    :'user' => :'user'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/spatio-sdk/models/organization_member.rb', line 250

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



89
90
91
92
# File 'lib/spatio-sdk/models/organization_member.rb', line 89

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



77
78
79
80
81
82
83
84
85
86
# File 'lib/spatio-sdk/models/organization_member.rb', line 77

def self.openapi_types
  {
    :'id' => :'String',
    :'user_id' => :'String',
    :'role' => :'String',
    :'joined_at' => :'Time',
    :'invited_by' => :'OrganizationMemberInvitedBy',
    :'user' => :'Hash<String, Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



224
225
226
227
228
229
230
231
232
233
# File 'lib/spatio-sdk/models/organization_member.rb', line 224

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      user_id == o.user_id &&
      role == o.role &&
      joined_at == o.joined_at &&
      invited_by == o.invited_by &&
      user == o.user
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


237
238
239
# File 'lib/spatio-sdk/models/organization_member.rb', line 237

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



243
244
245
# File 'lib/spatio-sdk/models/organization_member.rb', line 243

def hash
  [id, user_id, role, joined_at, invited_by, user].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/spatio-sdk/models/organization_member.rb', line 147

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @user_id.nil?
    invalid_properties.push('invalid value for "user_id", user_id cannot be nil.')
  end

  if @role.nil?
    invalid_properties.push('invalid value for "role", role cannot be nil.')
  end

  if @joined_at.nil?
    invalid_properties.push('invalid value for "joined_at", joined_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/spatio-sdk/models/organization_member.rb', line 272

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



171
172
173
174
175
176
177
178
179
180
# File 'lib/spatio-sdk/models/organization_member.rb', line 171

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @user_id.nil?
  return false if @role.nil?
  role_validator = EnumAttributeValidator.new('String', ["owner", "admin", "billing_admin", "member"])
  return false unless role_validator.valid?(@role)
  return false if @joined_at.nil?
  true
end