Class: Spatio::PersonalAccessToken

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/personal_access_token.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PersonalAccessToken

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/spatio-sdk/models/personal_access_token.rb', line 87

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::PersonalAccessToken` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::PersonalAccessToken`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'scopes')
    if (value = attributes[:'scopes']).is_a?(Array)
      self.scopes = value
    end
  end

  if attributes.key?(:'workspace_id')
    self.workspace_id = attributes[:'workspace_id']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'last_used_at')
    self.last_used_at = attributes[:'last_used_at']
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  end

  if attributes.key?(:'token_prefix')
    self.token_prefix = attributes[:'token_prefix']
  end
end

Instance Attribute Details

#created_atObject

Returns the value of attribute created_at.



28
29
30
# File 'lib/spatio-sdk/models/personal_access_token.rb', line 28

def created_at
  @created_at
end

#descriptionObject

Returns the value of attribute description.



22
23
24
# File 'lib/spatio-sdk/models/personal_access_token.rb', line 22

def description
  @description
end

#expires_atObject

Returns the value of attribute expires_at.



32
33
34
# File 'lib/spatio-sdk/models/personal_access_token.rb', line 32

def expires_at
  @expires_at
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/spatio-sdk/models/personal_access_token.rb', line 18

def id
  @id
end

#last_used_atObject

Returns the value of attribute last_used_at.



30
31
32
# File 'lib/spatio-sdk/models/personal_access_token.rb', line 30

def last_used_at
  @last_used_at
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/spatio-sdk/models/personal_access_token.rb', line 20

def name
  @name
end

#scopesObject

Returns the value of attribute scopes.



24
25
26
# File 'lib/spatio-sdk/models/personal_access_token.rb', line 24

def scopes
  @scopes
end

#token_prefixObject

Returns the value of attribute token_prefix.



34
35
36
# File 'lib/spatio-sdk/models/personal_access_token.rb', line 34

def token_prefix
  @token_prefix
end

#workspace_idObject

Returns the value of attribute workspace_id.



26
27
28
# File 'lib/spatio-sdk/models/personal_access_token.rb', line 26

def workspace_id
  @workspace_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



52
53
54
# File 'lib/spatio-sdk/models/personal_access_token.rb', line 52

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



57
58
59
# File 'lib/spatio-sdk/models/personal_access_token.rb', line 57

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/spatio-sdk/models/personal_access_token.rb', line 37

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'description' => :'description',
    :'scopes' => :'scopes',
    :'workspace_id' => :'workspaceId',
    :'created_at' => :'createdAt',
    :'last_used_at' => :'lastUsedAt',
    :'expires_at' => :'expiresAt',
    :'token_prefix' => :'tokenPrefix'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/spatio-sdk/models/personal_access_token.rb', line 203

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



77
78
79
80
81
82
83
# File 'lib/spatio-sdk/models/personal_access_token.rb', line 77

def self.openapi_nullable
  Set.new([
    :'workspace_id',
    :'last_used_at',
    :'expires_at',
  ])
end

.openapi_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/spatio-sdk/models/personal_access_token.rb', line 62

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'scopes' => :'Array<String>',
    :'workspace_id' => :'String',
    :'created_at' => :'Time',
    :'last_used_at' => :'Time',
    :'expires_at' => :'Time',
    :'token_prefix' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/spatio-sdk/models/personal_access_token.rb', line 174

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      description == o.description &&
      scopes == o.scopes &&
      workspace_id == o.workspace_id &&
      created_at == o.created_at &&
      last_used_at == o.last_used_at &&
      expires_at == o.expires_at &&
      token_prefix == o.token_prefix
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


190
191
192
# File 'lib/spatio-sdk/models/personal_access_token.rb', line 190

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



196
197
198
# File 'lib/spatio-sdk/models/personal_access_token.rb', line 196

def hash
  [id, name, description, scopes, workspace_id, created_at, last_used_at, expires_at, token_prefix].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



144
145
146
147
148
149
150
151
152
# File 'lib/spatio-sdk/models/personal_access_token.rb', line 144

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/spatio-sdk/models/personal_access_token.rb', line 225

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



156
157
158
159
160
# File 'lib/spatio-sdk/models/personal_access_token.rb', line 156

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  true
end