Class: Spatio::PlatformsApi
- Inherits:
-
Object
- Object
- Spatio::PlatformsApi
- Defined in:
- lib/spatio-sdk/api/platforms_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#add_platform_provider_account(platform_id, provider, request_body, opts = {}) ⇒ Hash<String, Object>
Add a connected account for a platform/provider pair.
-
#add_platform_provider_account_with_http_info(platform_id, provider, request_body, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Add a connected account for a platform/provider pair.
-
#create_or_update_platform_secret(platform_id, request_body, opts = {}) ⇒ Hash<String, Object>
Create or update a secret value.
-
#create_or_update_platform_secret_with_http_info(platform_id, request_body, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Create or update a secret value.
-
#delete_platform_secret(platform_id, name, opts = {}) ⇒ nil
Delete a secret.
-
#delete_platform_secret_with_http_info(platform_id, name, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete a secret.
-
#exec_platform_data(platform_id, request_body, opts = {}) ⇒ Hash<String, Object>
Run an INSERT/UPDATE/DELETE statement against a platform’s store.
-
#exec_platform_data_with_http_info(platform_id, request_body, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Run an INSERT/UPDATE/DELETE statement against a platform's store.
-
#export_platform_secrets(platform_id, opts = {}) ⇒ Hash<String, Object>
Export all secrets for a platform (values included).
-
#export_platform_secrets_with_http_info(platform_id, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Export all secrets for a platform (values included).
-
#generate_platform_backend_token(platform_id, opts = {}) ⇒ Hash<String, Object>
Generate a short-lived backend JWT a platform’s worker can use to call back into platform-service.
-
#generate_platform_backend_token_with_http_info(platform_id, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Generate a short-lived backend JWT a platform's worker can use to call back into platform-service.
-
#get_platform_catalog(opts = {}) ⇒ Hash<String, Object>
List the global platform catalog — every platform that exists, not just the ones the caller has installed.
-
#get_platform_catalog_with_http_info(opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
List the global platform catalog — every platform that exists, not just the ones the caller has installed.
-
#get_platform_manifest(platform_id, opts = {}) ⇒ Hash<String, Object>
Fetch a platform’s manifest (capabilities, schema, UI metadata).
-
#get_platform_manifest_with_http_info(platform_id, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Fetch a platform's manifest (capabilities, schema, UI metadata).
-
#initialize(api_client = ApiClient.default) ⇒ PlatformsApi
constructor
A new instance of PlatformsApi.
-
#list_platform_accounts(platform_id, opts = {}) ⇒ Hash<String, Object>
List accounts the caller has connected for a platform.
-
#list_platform_accounts_with_http_info(platform_id, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
List accounts the caller has connected for a platform.
-
#list_platform_providers(platform_id, opts = {}) ⇒ Hash<String, Object>
Discover supported providers + capabilities for a platform.
-
#list_platform_providers_with_http_info(platform_id, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Discover supported providers + capabilities for a platform.
-
#list_platform_secrets(platform_id, opts = {}) ⇒ Hash<String, Object>
List secret keys (values redacted).
-
#list_platform_secrets_with_http_info(platform_id, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
List secret keys (values redacted).
-
#list_platform_tables(platform_id, opts = {}) ⇒ Hash<String, Object>
List tables in a platform’s data store.
-
#list_platform_tables_with_http_info(platform_id, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
List tables in a platform's data store.
-
#list_platforms(opts = {}) ⇒ Hash<String, Object>
List installed platforms for the sidebar.
-
#list_platforms_with_http_info(opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
List installed platforms for the sidebar.
-
#query_platform_data(platform_id, request_body, opts = {}) ⇒ Hash<String, Object>
Run a SELECT query against a platform’s data store.
-
#query_platform_data_with_http_info(platform_id, request_body, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Run a SELECT query against a platform's data store.
-
#run_platform_migrations(platform_id, opts = {}) ⇒ Hash<String, Object>
Run pending migrations for a platform.
-
#run_platform_migrations_with_http_info(platform_id, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Run pending migrations for a platform.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ PlatformsApi
Returns a new instance of PlatformsApi.
19 20 21 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#add_platform_provider_account(platform_id, provider, request_body, opts = {}) ⇒ Hash<String, Object>
Add a connected account for a platform/provider pair.
28 29 30 31 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 28 def add_platform_provider_account(platform_id, provider, request_body, opts = {}) data, _status_code, _headers = add_platform_provider_account_with_http_info(platform_id, provider, request_body, opts) data end |
#add_platform_provider_account_with_http_info(platform_id, provider, request_body, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Add a connected account for a platform/provider pair.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 39 def add_platform_provider_account_with_http_info(platform_id, provider, request_body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlatformsApi.add_platform_provider_account ...' end # verify the required parameter 'platform_id' is set if @api_client.config.client_side_validation && platform_id.nil? fail ArgumentError, "Missing the required parameter 'platform_id' when calling PlatformsApi.add_platform_provider_account" end # verify the required parameter 'provider' is set if @api_client.config.client_side_validation && provider.nil? fail ArgumentError, "Missing the required parameter 'provider' when calling PlatformsApi.add_platform_provider_account" end # verify the required parameter 'request_body' is set if @api_client.config.client_side_validation && request_body.nil? fail ArgumentError, "Missing the required parameter 'request_body' when calling PlatformsApi.add_platform_provider_account" end # resource path local_var_path = '/v1/platforms/{platformId}/providers/{provider}/accounts'.sub('{platformId}', CGI.escape(platform_id.to_s)).sub('{provider}', CGI.escape(provider.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(request_body) # return_type return_type = opts[:debug_return_type] || 'Hash<String, Object>' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PlatformsApi.add_platform_provider_account", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlatformsApi#add_platform_provider_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_or_update_platform_secret(platform_id, request_body, opts = {}) ⇒ Hash<String, Object>
Create or update a secret value.
105 106 107 108 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 105 def create_or_update_platform_secret(platform_id, request_body, opts = {}) data, _status_code, _headers = create_or_update_platform_secret_with_http_info(platform_id, request_body, opts) data end |
#create_or_update_platform_secret_with_http_info(platform_id, request_body, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Create or update a secret value.
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 115 def create_or_update_platform_secret_with_http_info(platform_id, request_body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlatformsApi.create_or_update_platform_secret ...' end # verify the required parameter 'platform_id' is set if @api_client.config.client_side_validation && platform_id.nil? fail ArgumentError, "Missing the required parameter 'platform_id' when calling PlatformsApi.create_or_update_platform_secret" end # verify the required parameter 'request_body' is set if @api_client.config.client_side_validation && request_body.nil? fail ArgumentError, "Missing the required parameter 'request_body' when calling PlatformsApi.create_or_update_platform_secret" end # resource path local_var_path = '/v1/platforms/{platformId}/secrets'.sub('{platformId}', CGI.escape(platform_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(request_body) # return_type return_type = opts[:debug_return_type] || 'Hash<String, Object>' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PlatformsApi.create_or_update_platform_secret", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlatformsApi#create_or_update_platform_secret\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_platform_secret(platform_id, name, opts = {}) ⇒ nil
Delete a secret.
177 178 179 180 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 177 def delete_platform_secret(platform_id, name, opts = {}) delete_platform_secret_with_http_info(platform_id, name, opts) nil end |
#delete_platform_secret_with_http_info(platform_id, name, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete a secret.
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 187 def delete_platform_secret_with_http_info(platform_id, name, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlatformsApi.delete_platform_secret ...' end # verify the required parameter 'platform_id' is set if @api_client.config.client_side_validation && platform_id.nil? fail ArgumentError, "Missing the required parameter 'platform_id' when calling PlatformsApi.delete_platform_secret" end # verify the required parameter 'name' is set if @api_client.config.client_side_validation && name.nil? fail ArgumentError, "Missing the required parameter 'name' when calling PlatformsApi.delete_platform_secret" end # resource path local_var_path = '/v1/platforms/{platformId}/secrets/{name}'.sub('{platformId}', CGI.escape(platform_id.to_s)).sub('{name}', CGI.escape(name.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PlatformsApi.delete_platform_secret", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlatformsApi#delete_platform_secret\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#exec_platform_data(platform_id, request_body, opts = {}) ⇒ Hash<String, Object>
Run an INSERT/UPDATE/DELETE statement against a platform’s store.
244 245 246 247 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 244 def exec_platform_data(platform_id, request_body, opts = {}) data, _status_code, _headers = exec_platform_data_with_http_info(platform_id, request_body, opts) data end |
#exec_platform_data_with_http_info(platform_id, request_body, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Run an INSERT/UPDATE/DELETE statement against a platform's store.
254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 254 def exec_platform_data_with_http_info(platform_id, request_body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlatformsApi.exec_platform_data ...' end # verify the required parameter 'platform_id' is set if @api_client.config.client_side_validation && platform_id.nil? fail ArgumentError, "Missing the required parameter 'platform_id' when calling PlatformsApi.exec_platform_data" end # verify the required parameter 'request_body' is set if @api_client.config.client_side_validation && request_body.nil? fail ArgumentError, "Missing the required parameter 'request_body' when calling PlatformsApi.exec_platform_data" end # resource path local_var_path = '/v1/platforms/{platformId}/exec'.sub('{platformId}', CGI.escape(platform_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(request_body) # return_type return_type = opts[:debug_return_type] || 'Hash<String, Object>' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PlatformsApi.exec_platform_data", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlatformsApi#exec_platform_data\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#export_platform_secrets(platform_id, opts = {}) ⇒ Hash<String, Object>
Export all secrets for a platform (values included). Caller must be the platform owner.
315 316 317 318 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 315 def export_platform_secrets(platform_id, opts = {}) data, _status_code, _headers = export_platform_secrets_with_http_info(platform_id, opts) data end |
#export_platform_secrets_with_http_info(platform_id, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Export all secrets for a platform (values included). Caller must be the platform owner.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 324 def export_platform_secrets_with_http_info(platform_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlatformsApi.export_platform_secrets ...' end # verify the required parameter 'platform_id' is set if @api_client.config.client_side_validation && platform_id.nil? fail ArgumentError, "Missing the required parameter 'platform_id' when calling PlatformsApi.export_platform_secrets" end # resource path local_var_path = '/v1/platforms/{platformId}/secrets/export'.sub('{platformId}', CGI.escape(platform_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Hash<String, Object>' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PlatformsApi.export_platform_secrets", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlatformsApi#export_platform_secrets\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#generate_platform_backend_token(platform_id, opts = {}) ⇒ Hash<String, Object>
Generate a short-lived backend JWT a platform’s worker can use to call back into platform-service.
376 377 378 379 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 376 def generate_platform_backend_token(platform_id, opts = {}) data, _status_code, _headers = generate_platform_backend_token_with_http_info(platform_id, opts) data end |
#generate_platform_backend_token_with_http_info(platform_id, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Generate a short-lived backend JWT a platform's worker can use to call back into platform-service.
385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 385 def generate_platform_backend_token_with_http_info(platform_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlatformsApi.generate_platform_backend_token ...' end # verify the required parameter 'platform_id' is set if @api_client.config.client_side_validation && platform_id.nil? fail ArgumentError, "Missing the required parameter 'platform_id' when calling PlatformsApi.generate_platform_backend_token" end # resource path local_var_path = '/v1/platforms/{platformId}/backend-token'.sub('{platformId}', CGI.escape(platform_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Hash<String, Object>' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PlatformsApi.generate_platform_backend_token", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlatformsApi#generate_platform_backend_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_platform_catalog(opts = {}) ⇒ Hash<String, Object>
List the global platform catalog — every platform that exists, not just the ones the caller has installed.
436 437 438 439 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 436 def get_platform_catalog(opts = {}) data, _status_code, _headers = get_platform_catalog_with_http_info(opts) data end |
#get_platform_catalog_with_http_info(opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
List the global platform catalog — every platform that exists, not just the ones the caller has installed.
444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 444 def get_platform_catalog_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlatformsApi.get_platform_catalog ...' end # resource path local_var_path = '/v1/catalog/platforms' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Hash<String, Object>' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PlatformsApi.get_platform_catalog", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlatformsApi#get_platform_catalog\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_platform_manifest(platform_id, opts = {}) ⇒ Hash<String, Object>
Fetch a platform’s manifest (capabilities, schema, UI metadata).
492 493 494 495 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 492 def get_platform_manifest(platform_id, opts = {}) data, _status_code, _headers = get_platform_manifest_with_http_info(platform_id, opts) data end |
#get_platform_manifest_with_http_info(platform_id, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Fetch a platform's manifest (capabilities, schema, UI metadata).
501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 501 def get_platform_manifest_with_http_info(platform_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlatformsApi.get_platform_manifest ...' end # verify the required parameter 'platform_id' is set if @api_client.config.client_side_validation && platform_id.nil? fail ArgumentError, "Missing the required parameter 'platform_id' when calling PlatformsApi.get_platform_manifest" end # resource path local_var_path = '/v1/platforms/{platformId}/manifest'.sub('{platformId}', CGI.escape(platform_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Hash<String, Object>' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PlatformsApi.get_platform_manifest", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlatformsApi#get_platform_manifest\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_platform_accounts(platform_id, opts = {}) ⇒ Hash<String, Object>
List accounts the caller has connected for a platform.
553 554 555 556 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 553 def list_platform_accounts(platform_id, opts = {}) data, _status_code, _headers = list_platform_accounts_with_http_info(platform_id, opts) data end |
#list_platform_accounts_with_http_info(platform_id, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
List accounts the caller has connected for a platform.
562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 562 def list_platform_accounts_with_http_info(platform_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlatformsApi.list_platform_accounts ...' end # verify the required parameter 'platform_id' is set if @api_client.config.client_side_validation && platform_id.nil? fail ArgumentError, "Missing the required parameter 'platform_id' when calling PlatformsApi.list_platform_accounts" end # resource path local_var_path = '/v1/platforms/{platformId}/accounts'.sub('{platformId}', CGI.escape(platform_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Hash<String, Object>' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PlatformsApi.list_platform_accounts", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlatformsApi#list_platform_accounts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_platform_providers(platform_id, opts = {}) ⇒ Hash<String, Object>
Discover supported providers + capabilities for a platform.
614 615 616 617 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 614 def list_platform_providers(platform_id, opts = {}) data, _status_code, _headers = list_platform_providers_with_http_info(platform_id, opts) data end |
#list_platform_providers_with_http_info(platform_id, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Discover supported providers + capabilities for a platform.
623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 623 def list_platform_providers_with_http_info(platform_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlatformsApi.list_platform_providers ...' end # verify the required parameter 'platform_id' is set if @api_client.config.client_side_validation && platform_id.nil? fail ArgumentError, "Missing the required parameter 'platform_id' when calling PlatformsApi.list_platform_providers" end # resource path local_var_path = '/v1/platforms/{platformId}/providers'.sub('{platformId}', CGI.escape(platform_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Hash<String, Object>' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PlatformsApi.list_platform_providers", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlatformsApi#list_platform_providers\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_platform_secrets(platform_id, opts = {}) ⇒ Hash<String, Object>
List secret keys (values redacted).
675 676 677 678 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 675 def list_platform_secrets(platform_id, opts = {}) data, _status_code, _headers = list_platform_secrets_with_http_info(platform_id, opts) data end |
#list_platform_secrets_with_http_info(platform_id, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
List secret keys (values redacted).
684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 684 def list_platform_secrets_with_http_info(platform_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlatformsApi.list_platform_secrets ...' end # verify the required parameter 'platform_id' is set if @api_client.config.client_side_validation && platform_id.nil? fail ArgumentError, "Missing the required parameter 'platform_id' when calling PlatformsApi.list_platform_secrets" end # resource path local_var_path = '/v1/platforms/{platformId}/secrets'.sub('{platformId}', CGI.escape(platform_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Hash<String, Object>' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PlatformsApi.list_platform_secrets", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlatformsApi#list_platform_secrets\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_platform_tables(platform_id, opts = {}) ⇒ Hash<String, Object>
List tables in a platform’s data store.
736 737 738 739 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 736 def list_platform_tables(platform_id, opts = {}) data, _status_code, _headers = list_platform_tables_with_http_info(platform_id, opts) data end |
#list_platform_tables_with_http_info(platform_id, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
List tables in a platform's data store.
745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 745 def list_platform_tables_with_http_info(platform_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlatformsApi.list_platform_tables ...' end # verify the required parameter 'platform_id' is set if @api_client.config.client_side_validation && platform_id.nil? fail ArgumentError, "Missing the required parameter 'platform_id' when calling PlatformsApi.list_platform_tables" end # resource path local_var_path = '/v1/platforms/{platformId}/tables'.sub('{platformId}', CGI.escape(platform_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Hash<String, Object>' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PlatformsApi.list_platform_tables", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlatformsApi#list_platform_tables\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_platforms(opts = {}) ⇒ Hash<String, Object>
List installed platforms for the sidebar.
796 797 798 799 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 796 def list_platforms(opts = {}) data, _status_code, _headers = list_platforms_with_http_info(opts) data end |
#list_platforms_with_http_info(opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
List installed platforms for the sidebar.
804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 804 def list_platforms_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlatformsApi.list_platforms ...' end # resource path local_var_path = '/v1/platforms' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Hash<String, Object>' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PlatformsApi.list_platforms", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlatformsApi#list_platforms\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#query_platform_data(platform_id, request_body, opts = {}) ⇒ Hash<String, Object>
Run a SELECT query against a platform’s data store.
853 854 855 856 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 853 def query_platform_data(platform_id, request_body, opts = {}) data, _status_code, _headers = query_platform_data_with_http_info(platform_id, request_body, opts) data end |
#query_platform_data_with_http_info(platform_id, request_body, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Run a SELECT query against a platform's data store.
863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 863 def query_platform_data_with_http_info(platform_id, request_body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlatformsApi.query_platform_data ...' end # verify the required parameter 'platform_id' is set if @api_client.config.client_side_validation && platform_id.nil? fail ArgumentError, "Missing the required parameter 'platform_id' when calling PlatformsApi.query_platform_data" end # verify the required parameter 'request_body' is set if @api_client.config.client_side_validation && request_body.nil? fail ArgumentError, "Missing the required parameter 'request_body' when calling PlatformsApi.query_platform_data" end # resource path local_var_path = '/v1/platforms/{platformId}/query'.sub('{platformId}', CGI.escape(platform_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(request_body) # return_type return_type = opts[:debug_return_type] || 'Hash<String, Object>' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PlatformsApi.query_platform_data", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlatformsApi#query_platform_data\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#run_platform_migrations(platform_id, opts = {}) ⇒ Hash<String, Object>
Run pending migrations for a platform.
924 925 926 927 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 924 def run_platform_migrations(platform_id, opts = {}) data, _status_code, _headers = run_platform_migrations_with_http_info(platform_id, opts) data end |
#run_platform_migrations_with_http_info(platform_id, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Run pending migrations for a platform.
933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/spatio-sdk/api/platforms_api.rb', line 933 def run_platform_migrations_with_http_info(platform_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlatformsApi.run_platform_migrations ...' end # verify the required parameter 'platform_id' is set if @api_client.config.client_side_validation && platform_id.nil? fail ArgumentError, "Missing the required parameter 'platform_id' when calling PlatformsApi.run_platform_migrations" end # resource path local_var_path = '/v1/platforms/{platformId}/migrate'.sub('{platformId}', CGI.escape(platform_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Hash<String, Object>' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PlatformsApi.run_platform_migrations", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlatformsApi#run_platform_migrations\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |