Class: Spatio::ProposeRecommendationRequest

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/propose_recommendation_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ProposeRecommendationRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/spatio-sdk/models/propose_recommendation_request.rb', line 72

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::ProposeRecommendationRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::ProposeRecommendationRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'workspace_id')
    self.workspace_id = attributes[:'workspace_id']
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  else
    self.kind = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'body')
    self.body = attributes[:'body']
  end

  if attributes.key?(:'payload')
    if (value = attributes[:'payload']).is_a?(Hash)
      self.payload = value
    end
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  end
end

Instance Attribute Details

#bodyObject

Returns the value of attribute body.



24
25
26
# File 'lib/spatio-sdk/models/propose_recommendation_request.rb', line 24

def body
  @body
end

#expires_atObject

Returns the value of attribute expires_at.



28
29
30
# File 'lib/spatio-sdk/models/propose_recommendation_request.rb', line 28

def expires_at
  @expires_at
end

#kindObject

Returns the value of attribute kind.



20
21
22
# File 'lib/spatio-sdk/models/propose_recommendation_request.rb', line 20

def kind
  @kind
end

#payloadObject

Returns the value of attribute payload.



26
27
28
# File 'lib/spatio-sdk/models/propose_recommendation_request.rb', line 26

def payload
  @payload
end

#titleObject

Returns the value of attribute title.



22
23
24
# File 'lib/spatio-sdk/models/propose_recommendation_request.rb', line 22

def title
  @title
end

#workspace_idObject

Returns the value of attribute workspace_id.



18
19
20
# File 'lib/spatio-sdk/models/propose_recommendation_request.rb', line 18

def workspace_id
  @workspace_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



43
44
45
# File 'lib/spatio-sdk/models/propose_recommendation_request.rb', line 43

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



48
49
50
# File 'lib/spatio-sdk/models/propose_recommendation_request.rb', line 48

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
# File 'lib/spatio-sdk/models/propose_recommendation_request.rb', line 31

def self.attribute_map
  {
    :'workspace_id' => :'workspaceId',
    :'kind' => :'kind',
    :'title' => :'title',
    :'body' => :'body',
    :'payload' => :'payload',
    :'expires_at' => :'expiresAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/spatio-sdk/models/propose_recommendation_request.rb', line 173

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
# File 'lib/spatio-sdk/models/propose_recommendation_request.rb', line 65

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
62
# File 'lib/spatio-sdk/models/propose_recommendation_request.rb', line 53

def self.openapi_types
  {
    :'workspace_id' => :'String',
    :'kind' => :'String',
    :'title' => :'String',
    :'body' => :'String',
    :'payload' => :'Hash<String, Object>',
    :'expires_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



147
148
149
150
151
152
153
154
155
156
# File 'lib/spatio-sdk/models/propose_recommendation_request.rb', line 147

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      workspace_id == o.workspace_id &&
      kind == o.kind &&
      title == o.title &&
      body == o.body &&
      payload == o.payload &&
      expires_at == o.expires_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


160
161
162
# File 'lib/spatio-sdk/models/propose_recommendation_request.rb', line 160

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



166
167
168
# File 'lib/spatio-sdk/models/propose_recommendation_request.rb', line 166

def hash
  [workspace_id, kind, title, body, payload, expires_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



117
118
119
120
121
122
123
124
125
# File 'lib/spatio-sdk/models/propose_recommendation_request.rb', line 117

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @kind.nil?
    invalid_properties.push('invalid value for "kind", kind cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/spatio-sdk/models/propose_recommendation_request.rb', line 195

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



129
130
131
132
133
# File 'lib/spatio-sdk/models/propose_recommendation_request.rb', line 129

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @kind.nil?
  true
end