Class: Spatio::PublicInvitationPayload

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/public_invitation_payload.rb

Overview

Returned by ‘GET /invitations/token` (unauthenticated). Lets the renderer show invitation details (workspace name, inviter, role) before the user signs in.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PublicInvitationPayload

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/spatio-sdk/models/public_invitation_payload.rb', line 120

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::PublicInvitationPayload` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::PublicInvitationPayload`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  else
    self.kind = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'workspace_id')
    self.workspace_id = attributes[:'workspace_id']
  end

  if attributes.key?(:'organization_id')
    self.organization_id = attributes[:'organization_id']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  else
    self.email = nil
  end

  if attributes.key?(:'role')
    self.role = attributes[:'role']
  else
    self.role = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'workspace')
    if (value = attributes[:'workspace']).is_a?(Hash)
      self.workspace = value
    end
  end

  if attributes.key?(:'organization')
    if (value = attributes[:'organization']).is_a?(Hash)
      self.organization = value
    end
  end

  if attributes.key?(:'invited_by')
    if (value = attributes[:'invited_by']).is_a?(Hash)
      self.invited_by = value
    end
  end
end

Instance Attribute Details

#created_atObject

Returns the value of attribute created_at.



35
36
37
# File 'lib/spatio-sdk/models/public_invitation_payload.rb', line 35

def created_at
  @created_at
end

#emailObject

Returns the value of attribute email.



27
28
29
# File 'lib/spatio-sdk/models/public_invitation_payload.rb', line 27

def email
  @email
end

#expires_atObject

Returns the value of attribute expires_at.



33
34
35
# File 'lib/spatio-sdk/models/public_invitation_payload.rb', line 33

def expires_at
  @expires_at
end

#idObject

Returns the value of attribute id.



21
22
23
# File 'lib/spatio-sdk/models/public_invitation_payload.rb', line 21

def id
  @id
end

#invited_byObject

Returns the value of attribute invited_by.



41
42
43
# File 'lib/spatio-sdk/models/public_invitation_payload.rb', line 41

def invited_by
  @invited_by
end

#kindObject

Returns the value of attribute kind.



19
20
21
# File 'lib/spatio-sdk/models/public_invitation_payload.rb', line 19

def kind
  @kind
end

#organizationObject

Returns the value of attribute organization.



39
40
41
# File 'lib/spatio-sdk/models/public_invitation_payload.rb', line 39

def organization
  @organization
end

#organization_idObject

Returns the value of attribute organization_id.



25
26
27
# File 'lib/spatio-sdk/models/public_invitation_payload.rb', line 25

def organization_id
  @organization_id
end

#roleObject

Returns the value of attribute role.



29
30
31
# File 'lib/spatio-sdk/models/public_invitation_payload.rb', line 29

def role
  @role
end

#statusObject

Returns the value of attribute status.



31
32
33
# File 'lib/spatio-sdk/models/public_invitation_payload.rb', line 31

def status
  @status
end

#workspaceObject

Returns the value of attribute workspace.



37
38
39
# File 'lib/spatio-sdk/models/public_invitation_payload.rb', line 37

def workspace
  @workspace
end

#workspace_idObject

Returns the value of attribute workspace_id.



23
24
25
# File 'lib/spatio-sdk/models/public_invitation_payload.rb', line 23

def workspace_id
  @workspace_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



84
85
86
# File 'lib/spatio-sdk/models/public_invitation_payload.rb', line 84

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



89
90
91
# File 'lib/spatio-sdk/models/public_invitation_payload.rb', line 89

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/spatio-sdk/models/public_invitation_payload.rb', line 66

def self.attribute_map
  {
    :'kind' => :'kind',
    :'id' => :'id',
    :'workspace_id' => :'workspaceId',
    :'organization_id' => :'organizationId',
    :'email' => :'email',
    :'role' => :'role',
    :'status' => :'status',
    :'expires_at' => :'expiresAt',
    :'created_at' => :'createdAt',
    :'workspace' => :'workspace',
    :'organization' => :'organization',
    :'invited_by' => :'invitedBy'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/spatio-sdk/models/public_invitation_payload.rb', line 327

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



112
113
114
115
116
# File 'lib/spatio-sdk/models/public_invitation_payload.rb', line 112

def self.openapi_nullable
  Set.new([
    :'expires_at',
  ])
end

.openapi_typesObject

Attribute type mapping.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/spatio-sdk/models/public_invitation_payload.rb', line 94

def self.openapi_types
  {
    :'kind' => :'String',
    :'id' => :'String',
    :'workspace_id' => :'String',
    :'organization_id' => :'String',
    :'email' => :'String',
    :'role' => :'String',
    :'status' => :'String',
    :'expires_at' => :'Time',
    :'created_at' => :'Time',
    :'workspace' => :'Hash<String, Object>',
    :'organization' => :'Hash<String, Object>',
    :'invited_by' => :'Hash<String, Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/spatio-sdk/models/public_invitation_payload.rb', line 295

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      kind == o.kind &&
      id == o.id &&
      workspace_id == o.workspace_id &&
      organization_id == o.organization_id &&
      email == o.email &&
      role == o.role &&
      status == o.status &&
      expires_at == o.expires_at &&
      created_at == o.created_at &&
      workspace == o.workspace &&
      organization == o.organization &&
      invited_by == o.invited_by
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


314
315
316
# File 'lib/spatio-sdk/models/public_invitation_payload.rb', line 314

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



320
321
322
# File 'lib/spatio-sdk/models/public_invitation_payload.rb', line 320

def hash
  [kind, id, workspace_id, organization_id, email, role, status, expires_at, created_at, workspace, organization, invited_by].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/spatio-sdk/models/public_invitation_payload.rb', line 201

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @kind.nil?
    invalid_properties.push('invalid value for "kind", kind cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @email.nil?
    invalid_properties.push('invalid value for "email", email cannot be nil.')
  end

  if @role.nil?
    invalid_properties.push('invalid value for "role", role cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/spatio-sdk/models/public_invitation_payload.rb', line 349

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/spatio-sdk/models/public_invitation_payload.rb', line 229

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @kind.nil?
  kind_validator = EnumAttributeValidator.new('String', ["workspace", "organization"])
  return false unless kind_validator.valid?(@kind)
  return false if @id.nil?
  return false if @email.nil?
  return false if @role.nil?
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["pending", "accepted", "revoked", "expired"])
  return false unless status_validator.valid?(@status)
  true
end