Class: Spatio::RecordType

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/record_type.rb

Overview

Org-scoped record-type definition. ‘attribute_schema` defines the per-record attributes; treated as opaque here.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RecordType

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/spatio-sdk/models/record_type.rb', line 85

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::RecordType` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::RecordType`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'organization_id')
    self.organization_id = attributes[:'organization_id']
  else
    self.organization_id = nil
  end

  if attributes.key?(:'slug')
    self.slug = attributes[:'slug']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'name_plural')
    self.name_plural = attributes[:'name_plural']
  end

  if attributes.key?(:'icon')
    self.icon = attributes[:'icon']
  end

  if attributes.key?(:'attribute_schema')
    if (value = attributes[:'attribute_schema']).is_a?(Array)
      self.attribute_schema = value
    end
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#attribute_schemaObject

Returns the value of attribute attribute_schema.



31
32
33
# File 'lib/spatio-sdk/models/record_type.rb', line 31

def attribute_schema
  @attribute_schema
end

#created_atObject

Returns the value of attribute created_at.



33
34
35
# File 'lib/spatio-sdk/models/record_type.rb', line 33

def created_at
  @created_at
end

#iconObject

Returns the value of attribute icon.



29
30
31
# File 'lib/spatio-sdk/models/record_type.rb', line 29

def icon
  @icon
end

#idObject

Returns the value of attribute id.



19
20
21
# File 'lib/spatio-sdk/models/record_type.rb', line 19

def id
  @id
end

#nameObject

Returns the value of attribute name.



25
26
27
# File 'lib/spatio-sdk/models/record_type.rb', line 25

def name
  @name
end

#name_pluralObject

Returns the value of attribute name_plural.



27
28
29
# File 'lib/spatio-sdk/models/record_type.rb', line 27

def name_plural
  @name_plural
end

#organization_idObject

Returns the value of attribute organization_id.



21
22
23
# File 'lib/spatio-sdk/models/record_type.rb', line 21

def organization_id
  @organization_id
end

#slugObject

Returns the value of attribute slug.



23
24
25
# File 'lib/spatio-sdk/models/record_type.rb', line 23

def slug
  @slug
end

#updated_atObject

Returns the value of attribute updated_at.



35
36
37
# File 'lib/spatio-sdk/models/record_type.rb', line 35

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/spatio-sdk/models/record_type.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/spatio-sdk/models/record_type.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
49
50
# File 'lib/spatio-sdk/models/record_type.rb', line 38

def self.attribute_map
  {
    :'id' => :'id',
    :'organization_id' => :'organization_id',
    :'slug' => :'slug',
    :'name' => :'name',
    :'name_plural' => :'name_plural',
    :'icon' => :'icon',
    :'attribute_schema' => :'attribute_schema',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/spatio-sdk/models/record_type.rb', line 218

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



78
79
80
81
# File 'lib/spatio-sdk/models/record_type.rb', line 78

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/spatio-sdk/models/record_type.rb', line 63

def self.openapi_types
  {
    :'id' => :'String',
    :'organization_id' => :'String',
    :'slug' => :'String',
    :'name' => :'String',
    :'name_plural' => :'String',
    :'icon' => :'String',
    :'attribute_schema' => :'Array<Hash<String, Object>>',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/spatio-sdk/models/record_type.rb', line 189

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      organization_id == o.organization_id &&
      slug == o.slug &&
      name == o.name &&
      name_plural == o.name_plural &&
      icon == o.icon &&
      attribute_schema == o.attribute_schema &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


205
206
207
# File 'lib/spatio-sdk/models/record_type.rb', line 205

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



211
212
213
# File 'lib/spatio-sdk/models/record_type.rb', line 211

def hash
  [id, organization_id, slug, name, name_plural, icon, attribute_schema, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/spatio-sdk/models/record_type.rb', line 144

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @organization_id.nil?
    invalid_properties.push('invalid value for "organization_id", organization_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/spatio-sdk/models/record_type.rb', line 240

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



160
161
162
163
164
165
# File 'lib/spatio-sdk/models/record_type.rb', line 160

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @organization_id.nil?
  true
end