Class: Spatio::SendEmailRequest

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/send_email_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SendEmailRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/spatio-sdk/models/send_email_request.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::SendEmailRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::SendEmailRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'to')
    if (value = attributes[:'to']).is_a?(Array)
      self.to = value
    end
  else
    self.to = nil
  end

  if attributes.key?(:'cc')
    if (value = attributes[:'cc']).is_a?(Array)
      self.cc = value
    end
  end

  if attributes.key?(:'bcc')
    if (value = attributes[:'bcc']).is_a?(Array)
      self.bcc = value
    end
  end

  if attributes.key?(:'subject')
    self.subject = attributes[:'subject']
  else
    self.subject = nil
  end

  if attributes.key?(:'body')
    self.body = attributes[:'body']
  else
    self.body = nil
  end

  if attributes.key?(:'html')
    self.html = attributes[:'html']
  end

  if attributes.key?(:'attachments')
    if (value = attributes[:'attachments']).is_a?(Array)
      self.attachments = value
    end
  end

  if attributes.key?(:'in_reply_to')
    self.in_reply_to = attributes[:'in_reply_to']
  end

  if attributes.key?(:'references')
    if (value = attributes[:'references']).is_a?(Array)
      self.references = value
    end
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



18
19
20
# File 'lib/spatio-sdk/models/send_email_request.rb', line 18

def 
  @account_id
end

#attachmentsObject

Returns the value of attribute attachments.



32
33
34
# File 'lib/spatio-sdk/models/send_email_request.rb', line 32

def attachments
  @attachments
end

#bccObject

Returns the value of attribute bcc.



24
25
26
# File 'lib/spatio-sdk/models/send_email_request.rb', line 24

def bcc
  @bcc
end

#bodyObject

Returns the value of attribute body.



28
29
30
# File 'lib/spatio-sdk/models/send_email_request.rb', line 28

def body
  @body
end

#ccObject

Returns the value of attribute cc.



22
23
24
# File 'lib/spatio-sdk/models/send_email_request.rb', line 22

def cc
  @cc
end

#htmlObject

Returns the value of attribute html.



30
31
32
# File 'lib/spatio-sdk/models/send_email_request.rb', line 30

def html
  @html
end

#in_reply_toObject

Returns the value of attribute in_reply_to.



34
35
36
# File 'lib/spatio-sdk/models/send_email_request.rb', line 34

def in_reply_to
  @in_reply_to
end

#referencesObject

Returns the value of attribute references.



36
37
38
# File 'lib/spatio-sdk/models/send_email_request.rb', line 36

def references
  @references
end

#subjectObject

Returns the value of attribute subject.



26
27
28
# File 'lib/spatio-sdk/models/send_email_request.rb', line 26

def subject
  @subject
end

#toObject

Returns the value of attribute to.



20
21
22
# File 'lib/spatio-sdk/models/send_email_request.rb', line 20

def to
  @to
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



55
56
57
# File 'lib/spatio-sdk/models/send_email_request.rb', line 55

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



60
61
62
# File 'lib/spatio-sdk/models/send_email_request.rb', line 60

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/spatio-sdk/models/send_email_request.rb', line 39

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'to' => :'to',
    :'cc' => :'cc',
    :'bcc' => :'bcc',
    :'subject' => :'subject',
    :'body' => :'body',
    :'html' => :'html',
    :'attachments' => :'attachments',
    :'in_reply_to' => :'inReplyTo',
    :'references' => :'references'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/spatio-sdk/models/send_email_request.rb', line 251

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/spatio-sdk/models/send_email_request.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/spatio-sdk/models/send_email_request.rb', line 65

def self.openapi_types
  {
    :'account_id' => :'String',
    :'to' => :'Array<String>',
    :'cc' => :'Array<String>',
    :'bcc' => :'Array<String>',
    :'subject' => :'String',
    :'body' => :'String',
    :'html' => :'Boolean',
    :'attachments' => :'Array<AttachmentInput>',
    :'in_reply_to' => :'String',
    :'references' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/spatio-sdk/models/send_email_request.rb', line 221

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      to == o.to &&
      cc == o.cc &&
      bcc == o.bcc &&
      subject == o.subject &&
      body == o.body &&
      html == o.html &&
      attachments == o.attachments &&
      in_reply_to == o.in_reply_to &&
      references == o.references
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


238
239
240
# File 'lib/spatio-sdk/models/send_email_request.rb', line 238

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



244
245
246
# File 'lib/spatio-sdk/models/send_email_request.rb', line 244

def hash
  [, to, cc, bcc, subject, body, html, attachments, in_reply_to, references].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/spatio-sdk/models/send_email_request.rb', line 161

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @to.nil?
    invalid_properties.push('invalid value for "to", to cannot be nil.')
  end

  if @subject.nil?
    invalid_properties.push('invalid value for "subject", subject cannot be nil.')
  end

  if @body.nil?
    invalid_properties.push('invalid value for "body", body cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



273
274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/spatio-sdk/models/send_email_request.rb', line 273

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



181
182
183
184
185
186
187
# File 'lib/spatio-sdk/models/send_email_request.rb', line 181

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @to.nil?
  return false if @subject.nil?
  return false if @body.nil?
  true
end