Class: Spatio::Session

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/session.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Session

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/spatio-sdk/models/session.rb', line 92

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::Session` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::Session`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'ip_address')
    self.ip_address = attributes[:'ip_address']
  end

  if attributes.key?(:'user_agent')
    self.user_agent = attributes[:'user_agent']
  end

  if attributes.key?(:'device_type')
    self.device_type = attributes[:'device_type']
  end

  if attributes.key?(:'browser')
    self.browser = attributes[:'browser']
  end

  if attributes.key?(:'os')
    self.os = attributes[:'os']
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'last_active_at')
    self.last_active_at = attributes[:'last_active_at']
  end

  if attributes.key?(:'is_current')
    self.is_current = attributes[:'is_current']
  end
end

Instance Attribute Details

#browserObject

Returns the value of attribute browser.



26
27
28
# File 'lib/spatio-sdk/models/session.rb', line 26

def browser
  @browser
end

#cityObject

Returns the value of attribute city.



32
33
34
# File 'lib/spatio-sdk/models/session.rb', line 32

def city
  @city
end

#countryObject

Returns the value of attribute country.



30
31
32
# File 'lib/spatio-sdk/models/session.rb', line 30

def country
  @country
end

#created_atObject

Returns the value of attribute created_at.



34
35
36
# File 'lib/spatio-sdk/models/session.rb', line 34

def created_at
  @created_at
end

#device_typeObject

Returns the value of attribute device_type.



24
25
26
# File 'lib/spatio-sdk/models/session.rb', line 24

def device_type
  @device_type
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/spatio-sdk/models/session.rb', line 18

def id
  @id
end

#ip_addressObject

Returns the value of attribute ip_address.



20
21
22
# File 'lib/spatio-sdk/models/session.rb', line 20

def ip_address
  @ip_address
end

#is_currentObject

Returns the value of attribute is_current.



38
39
40
# File 'lib/spatio-sdk/models/session.rb', line 38

def is_current
  @is_current
end

#last_active_atObject

Returns the value of attribute last_active_at.



36
37
38
# File 'lib/spatio-sdk/models/session.rb', line 36

def last_active_at
  @last_active_at
end

#osObject

Returns the value of attribute os.



28
29
30
# File 'lib/spatio-sdk/models/session.rb', line 28

def os
  @os
end

#user_agentObject

Returns the value of attribute user_agent.



22
23
24
# File 'lib/spatio-sdk/models/session.rb', line 22

def user_agent
  @user_agent
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



58
59
60
# File 'lib/spatio-sdk/models/session.rb', line 58

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/spatio-sdk/models/session.rb', line 63

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/spatio-sdk/models/session.rb', line 41

def self.attribute_map
  {
    :'id' => :'id',
    :'ip_address' => :'ipAddress',
    :'user_agent' => :'userAgent',
    :'device_type' => :'deviceType',
    :'browser' => :'browser',
    :'os' => :'os',
    :'country' => :'country',
    :'city' => :'city',
    :'created_at' => :'createdAt',
    :'last_active_at' => :'lastActiveAt',
    :'is_current' => :'isCurrent'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/spatio-sdk/models/session.rb', line 216

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



85
86
87
88
# File 'lib/spatio-sdk/models/session.rb', line 85

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/spatio-sdk/models/session.rb', line 68

def self.openapi_types
  {
    :'id' => :'String',
    :'ip_address' => :'String',
    :'user_agent' => :'String',
    :'device_type' => :'String',
    :'browser' => :'String',
    :'os' => :'String',
    :'country' => :'String',
    :'city' => :'String',
    :'created_at' => :'Time',
    :'last_active_at' => :'Time',
    :'is_current' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/spatio-sdk/models/session.rb', line 185

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      ip_address == o.ip_address &&
      user_agent == o.user_agent &&
      device_type == o.device_type &&
      browser == o.browser &&
      os == o.os &&
      country == o.country &&
      city == o.city &&
      created_at == o.created_at &&
      last_active_at == o.last_active_at &&
      is_current == o.is_current
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


203
204
205
# File 'lib/spatio-sdk/models/session.rb', line 203

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



209
210
211
# File 'lib/spatio-sdk/models/session.rb', line 209

def hash
  [id, ip_address, user_agent, device_type, browser, os, country, city, created_at, last_active_at, is_current].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



155
156
157
158
159
160
161
162
163
# File 'lib/spatio-sdk/models/session.rb', line 155

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/spatio-sdk/models/session.rb', line 238

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



167
168
169
170
171
# File 'lib/spatio-sdk/models/session.rb', line 167

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  true
end