Class: Spatio::ShareSettings

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/share_settings.rb

Overview

Public share configuration for a note. Owner-only mutation; unauthenticated readers consume ‘GET /public/notes/token` instead.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ShareSettings

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/spatio-sdk/models/share_settings.rb', line 72

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::ShareSettings` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::ShareSettings`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'is_public')
    self.is_public = attributes[:'is_public']
  else
    self.is_public = nil
  end

  if attributes.key?(:'has_password')
    self.has_password = attributes[:'has_password']
  else
    self.has_password = nil
  end

  if attributes.key?(:'share_token')
    self.share_token = attributes[:'share_token']
  end

  if attributes.key?(:'share_url')
    self.share_url = attributes[:'share_url']
  end

  if attributes.key?(:'password_set_at')
    self.password_set_at = attributes[:'password_set_at']
  end
end

Instance Attribute Details

#has_passwordObject

Returns the value of attribute has_password.



21
22
23
# File 'lib/spatio-sdk/models/share_settings.rb', line 21

def has_password
  @has_password
end

#is_publicObject

Returns the value of attribute is_public.



19
20
21
# File 'lib/spatio-sdk/models/share_settings.rb', line 19

def is_public
  @is_public
end

#password_set_atObject

When the current password was set, if any.



30
31
32
# File 'lib/spatio-sdk/models/share_settings.rb', line 30

def password_set_at
  @password_set_at
end

#share_tokenObject

Opaque token embedded in the public URL. Empty when ‘isPublic` is false.



24
25
26
# File 'lib/spatio-sdk/models/share_settings.rb', line 24

def share_token
  @share_token
end

#share_urlObject

Fully-qualified public viewer URL. Computed server-side from ‘PUBLIC_VIEWER_BASE` (defaults to `spatio.app`) and the share token. Empty when the note is private.



27
28
29
# File 'lib/spatio-sdk/models/share_settings.rb', line 27

def share_url
  @share_url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



44
45
46
# File 'lib/spatio-sdk/models/share_settings.rb', line 44

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



49
50
51
# File 'lib/spatio-sdk/models/share_settings.rb', line 49

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
# File 'lib/spatio-sdk/models/share_settings.rb', line 33

def self.attribute_map
  {
    :'is_public' => :'isPublic',
    :'has_password' => :'hasPassword',
    :'share_token' => :'shareToken',
    :'share_url' => :'shareUrl',
    :'password_set_at' => :'passwordSetAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/spatio-sdk/models/share_settings.rb', line 183

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
# File 'lib/spatio-sdk/models/share_settings.rb', line 65

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
# File 'lib/spatio-sdk/models/share_settings.rb', line 54

def self.openapi_types
  {
    :'is_public' => :'Boolean',
    :'has_password' => :'Boolean',
    :'share_token' => :'String',
    :'share_url' => :'String',
    :'password_set_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



158
159
160
161
162
163
164
165
166
# File 'lib/spatio-sdk/models/share_settings.rb', line 158

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      is_public == o.is_public &&
      has_password == o.has_password &&
      share_token == o.share_token &&
      share_url == o.share_url &&
      password_set_at == o.password_set_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


170
171
172
# File 'lib/spatio-sdk/models/share_settings.rb', line 170

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



176
177
178
# File 'lib/spatio-sdk/models/share_settings.rb', line 176

def hash
  [is_public, has_password, share_token, share_url, password_set_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/spatio-sdk/models/share_settings.rb', line 113

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @is_public.nil?
    invalid_properties.push('invalid value for "is_public", is_public cannot be nil.')
  end

  if @has_password.nil?
    invalid_properties.push('invalid value for "has_password", has_password cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/spatio-sdk/models/share_settings.rb', line 205

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



129
130
131
132
133
134
# File 'lib/spatio-sdk/models/share_settings.rb', line 129

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @is_public.nil?
  return false if @has_password.nil?
  true
end