Class: Spatio::Slide

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/slide.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Slide

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/spatio-sdk/models/slide.rb', line 108

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::Slide` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::Slide`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'provider')
    self.provider = attributes[:'provider']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'presentation_id')
    self.presentation_id = attributes[:'presentation_id']
  else
    self.presentation_id = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'notes')
    self.notes = attributes[:'notes']
  end

  if attributes.key?(:'layout')
    self.layout = attributes[:'layout']
  end

  if attributes.key?(:'background_color')
    self.background_color = attributes[:'background_color']
  end

  if attributes.key?(:'background_image_url')
    self.background_image_url = attributes[:'background_image_url']
  end

  if attributes.key?(:'text_color')
    self.text_color = attributes[:'text_color']
  end

  if attributes.key?(:'transition')
    self.transition = attributes[:'transition']
  end

  if attributes.key?(:'position')
    self.position = attributes[:'position']
  else
    self.position = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



22
23
24
# File 'lib/spatio-sdk/models/slide.rb', line 22

def 
  @account_id
end

#background_colorObject

Returns the value of attribute background_color.



34
35
36
# File 'lib/spatio-sdk/models/slide.rb', line 34

def background_color
  @background_color
end

#background_image_urlObject

Returns the value of attribute background_image_url.



36
37
38
# File 'lib/spatio-sdk/models/slide.rb', line 36

def background_image_url
  @background_image_url
end

#created_atObject

Returns the value of attribute created_at.



46
47
48
# File 'lib/spatio-sdk/models/slide.rb', line 46

def created_at
  @created_at
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/spatio-sdk/models/slide.rb', line 18

def id
  @id
end

#layoutObject

Free-form layout id. Provider-specific (‘title`, `two-column`, `image-left`, custom). Not enumerated to avoid forcing a breaking change every time a provider adds one.



32
33
34
# File 'lib/spatio-sdk/models/slide.rb', line 32

def layout
  @layout
end

#notesObject

Speaker notes.



29
30
31
# File 'lib/spatio-sdk/models/slide.rb', line 29

def notes
  @notes
end

#positionObject

Zero-based position within the presentation.



44
45
46
# File 'lib/spatio-sdk/models/slide.rb', line 44

def position
  @position
end

#presentation_idObject

Returns the value of attribute presentation_id.



24
25
26
# File 'lib/spatio-sdk/models/slide.rb', line 24

def presentation_id
  @presentation_id
end

#providerObject

Returns the value of attribute provider.



20
21
22
# File 'lib/spatio-sdk/models/slide.rb', line 20

def provider
  @provider
end

#text_colorObject

Returns the value of attribute text_color.



38
39
40
# File 'lib/spatio-sdk/models/slide.rb', line 38

def text_color
  @text_color
end

#titleObject

Returns the value of attribute title.



26
27
28
# File 'lib/spatio-sdk/models/slide.rb', line 26

def title
  @title
end

#transitionObject

Free-form transition id.



41
42
43
# File 'lib/spatio-sdk/models/slide.rb', line 41

def transition
  @transition
end

#updated_atObject

Returns the value of attribute updated_at.



48
49
50
# File 'lib/spatio-sdk/models/slide.rb', line 48

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/spatio-sdk/models/slide.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/spatio-sdk/models/slide.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/spatio-sdk/models/slide.rb', line 51

def self.attribute_map
  {
    :'id' => :'id',
    :'provider' => :'provider',
    :'account_id' => :'accountId',
    :'presentation_id' => :'presentationId',
    :'title' => :'title',
    :'notes' => :'notes',
    :'layout' => :'layout',
    :'background_color' => :'backgroundColor',
    :'background_image_url' => :'backgroundImageUrl',
    :'text_color' => :'textColor',
    :'transition' => :'transition',
    :'position' => :'position',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
# File 'lib/spatio-sdk/models/slide.rb', line 332

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



101
102
103
104
# File 'lib/spatio-sdk/models/slide.rb', line 101

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/spatio-sdk/models/slide.rb', line 81

def self.openapi_types
  {
    :'id' => :'String',
    :'provider' => :'String',
    :'account_id' => :'String',
    :'presentation_id' => :'String',
    :'title' => :'String',
    :'notes' => :'String',
    :'layout' => :'String',
    :'background_color' => :'String',
    :'background_image_url' => :'String',
    :'text_color' => :'String',
    :'transition' => :'String',
    :'position' => :'Integer',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/spatio-sdk/models/slide.rb', line 298

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      provider == o.provider &&
       == o. &&
      presentation_id == o.presentation_id &&
      title == o.title &&
      notes == o.notes &&
      layout == o.layout &&
      background_color == o.background_color &&
      background_image_url == o.background_image_url &&
      text_color == o.text_color &&
      transition == o.transition &&
      position == o.position &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


319
320
321
# File 'lib/spatio-sdk/models/slide.rb', line 319

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



325
326
327
# File 'lib/spatio-sdk/models/slide.rb', line 325

def hash
  [id, provider, , presentation_id, title, notes, layout, background_color, background_image_url, text_color, transition, position, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/spatio-sdk/models/slide.rb', line 193

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @presentation_id.nil?
    invalid_properties.push('invalid value for "presentation_id", presentation_id cannot be nil.')
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  if @position.nil?
    invalid_properties.push('invalid value for "position", position cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



354
355
356
357
358
359
360
361
362
363
364
365
366
# File 'lib/spatio-sdk/models/slide.rb', line 354

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



225
226
227
228
229
230
231
232
233
234
# File 'lib/spatio-sdk/models/slide.rb', line 225

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @presentation_id.nil?
  return false if @title.nil?
  return false if @position.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  true
end