Class: Spatio::SpatioConnection

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/spatio_connection.rb

Overview

OAuth/native integration descriptor. Open shape — categories add provider-specific capability flags. Treat unknown fields as additive.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SpatioConnection

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/spatio-sdk/models/spatio_connection.rb', line 94

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::SpatioConnection` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::SpatioConnection`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'auth_type')
    self.auth_type = attributes[:'auth_type']
  end

  if attributes.key?(:'connected')
    self.connected = attributes[:'connected']
  end

  if attributes.key?(:'connected_accounts')
    if (value = attributes[:'connected_accounts']).is_a?(Array)
      self.connected_accounts = value
    end
  end

  if attributes.key?(:'capabilities')
    if (value = attributes[:'capabilities']).is_a?(Hash)
      self.capabilities = value
    end
  end

  if attributes.key?(:'gradient_from')
    self.gradient_from = attributes[:'gradient_from']
  end

  if attributes.key?(:'gradient_to')
    self.gradient_to = attributes[:'gradient_to']
  end

  if attributes.key?(:'icon')
    self.icon = attributes[:'icon']
  end
end

Instance Attribute Details

#auth_typeObject

Returns the value of attribute auth_type.



27
28
29
# File 'lib/spatio-sdk/models/spatio_connection.rb', line 27

def auth_type
  @auth_type
end

#capabilitiesObject

Returns the value of attribute capabilities.



33
34
35
# File 'lib/spatio-sdk/models/spatio_connection.rb', line 33

def capabilities
  @capabilities
end

#categoryObject

Returns the value of attribute category.



23
24
25
# File 'lib/spatio-sdk/models/spatio_connection.rb', line 23

def category
  @category
end

#connectedObject

Returns the value of attribute connected.



29
30
31
# File 'lib/spatio-sdk/models/spatio_connection.rb', line 29

def connected
  @connected
end

#connected_accountsObject

Returns the value of attribute connected_accounts.



31
32
33
# File 'lib/spatio-sdk/models/spatio_connection.rb', line 31

def connected_accounts
  @connected_accounts
end

#descriptionObject

Returns the value of attribute description.



25
26
27
# File 'lib/spatio-sdk/models/spatio_connection.rb', line 25

def description
  @description
end

#gradient_fromObject

Returns the value of attribute gradient_from.



35
36
37
# File 'lib/spatio-sdk/models/spatio_connection.rb', line 35

def gradient_from
  @gradient_from
end

#gradient_toObject

Returns the value of attribute gradient_to.



37
38
39
# File 'lib/spatio-sdk/models/spatio_connection.rb', line 37

def gradient_to
  @gradient_to
end

#iconObject

Returns the value of attribute icon.



39
40
41
# File 'lib/spatio-sdk/models/spatio_connection.rb', line 39

def icon
  @icon
end

#idObject

Returns the value of attribute id.



19
20
21
# File 'lib/spatio-sdk/models/spatio_connection.rb', line 19

def id
  @id
end

#nameObject

Returns the value of attribute name.



21
22
23
# File 'lib/spatio-sdk/models/spatio_connection.rb', line 21

def name
  @name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



59
60
61
# File 'lib/spatio-sdk/models/spatio_connection.rb', line 59

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



64
65
66
# File 'lib/spatio-sdk/models/spatio_connection.rb', line 64

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/spatio-sdk/models/spatio_connection.rb', line 42

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'category' => :'category',
    :'description' => :'description',
    :'auth_type' => :'authType',
    :'connected' => :'connected',
    :'connected_accounts' => :'connectedAccounts',
    :'capabilities' => :'capabilities',
    :'gradient_from' => :'gradientFrom',
    :'gradient_to' => :'gradientTo',
    :'icon' => :'icon'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/spatio-sdk/models/spatio_connection.rb', line 222

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



86
87
88
89
90
# File 'lib/spatio-sdk/models/spatio_connection.rb', line 86

def self.openapi_nullable
  Set.new([
    :'connected_accounts',
  ])
end

.openapi_typesObject

Attribute type mapping.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/spatio-sdk/models/spatio_connection.rb', line 69

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'category' => :'String',
    :'description' => :'String',
    :'auth_type' => :'String',
    :'connected' => :'Boolean',
    :'connected_accounts' => :'Array<Hash<String, Object>>',
    :'capabilities' => :'Hash<String, Object>',
    :'gradient_from' => :'String',
    :'gradient_to' => :'String',
    :'icon' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/spatio-sdk/models/spatio_connection.rb', line 191

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      category == o.category &&
      description == o.description &&
      auth_type == o.auth_type &&
      connected == o.connected &&
      connected_accounts == o.connected_accounts &&
      capabilities == o.capabilities &&
      gradient_from == o.gradient_from &&
      gradient_to == o.gradient_to &&
      icon == o.icon
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


209
210
211
# File 'lib/spatio-sdk/models/spatio_connection.rb', line 209

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



215
216
217
# File 'lib/spatio-sdk/models/spatio_connection.rb', line 215

def hash
  [id, name, category, description, auth_type, connected, connected_accounts, capabilities, gradient_from, gradient_to, icon].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



161
162
163
164
165
166
167
168
169
# File 'lib/spatio-sdk/models/spatio_connection.rb', line 161

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/spatio-sdk/models/spatio_connection.rb', line 244

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



173
174
175
176
177
# File 'lib/spatio-sdk/models/spatio_connection.rb', line 173

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  true
end