Class: Spatio::SpatioFile

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/spatio_file.rb

Overview

A user file. Files belong to one connected file provider account (‘accountId` + `provider`); native storage uses Spatio’s block-store, external providers (Google Drive, Dropbox, etc.) round-trip through Spatio. Schema name is ‘SpatioFile` (not `File`) to avoid the `java.io.File` collision that breaks the Kotlin SDK generator when the schema is named `File`.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SpatioFile

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/spatio-sdk/models/spatio_file.rb', line 101

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::SpatioFile` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::SpatioFile`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'provider')
    self.provider = attributes[:'provider']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'size')
    self.size = attributes[:'size']
  else
    self.size = nil
  end

  if attributes.key?(:'mime_type')
    self.mime_type = attributes[:'mime_type']
  else
    self.mime_type = nil
  end

  if attributes.key?(:'folder_id')
    self.folder_id = attributes[:'folder_id']
  end

  if attributes.key?(:'storage_type')
    self.storage_type = attributes[:'storage_type']
  else
    self.storage_type = nil
  end

  if attributes.key?(:'download_url')
    self.download_url = attributes[:'download_url']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



23
24
25
# File 'lib/spatio-sdk/models/spatio_file.rb', line 23

def 
  @account_id
end

#created_atObject

Returns the value of attribute created_at.



42
43
44
# File 'lib/spatio-sdk/models/spatio_file.rb', line 42

def created_at
  @created_at
end

#download_urlObject

Pre-signed download URL when one is cached on the row. Use ‘GET /v1/files/#id/download` for a guaranteed-fresh URL — this field can lag past expiry.



38
39
40
# File 'lib/spatio-sdk/models/spatio_file.rb', line 38

def download_url
  @download_url
end

#folder_idObject

Returns the value of attribute folder_id.



32
33
34
# File 'lib/spatio-sdk/models/spatio_file.rb', line 32

def folder_id
  @folder_id
end

#idObject

Returns the value of attribute id.



19
20
21
# File 'lib/spatio-sdk/models/spatio_file.rb', line 19

def id
  @id
end

#metadataObject

Returns the value of attribute metadata.



40
41
42
# File 'lib/spatio-sdk/models/spatio_file.rb', line 40

def 
  @metadata
end

#mime_typeObject

Returns the value of attribute mime_type.



30
31
32
# File 'lib/spatio-sdk/models/spatio_file.rb', line 30

def mime_type
  @mime_type
end

#nameObject

Returns the value of attribute name.



25
26
27
# File 'lib/spatio-sdk/models/spatio_file.rb', line 25

def name
  @name
end

#providerObject

Returns the value of attribute provider.



21
22
23
# File 'lib/spatio-sdk/models/spatio_file.rb', line 21

def provider
  @provider
end

#sizeObject

Bytes.



28
29
30
# File 'lib/spatio-sdk/models/spatio_file.rb', line 28

def size
  @size
end

#storage_typeObject

Backing storage class — ‘r2`, `gdrive`, `dropbox`, etc. Provider-specific; treat as opaque.



35
36
37
# File 'lib/spatio-sdk/models/spatio_file.rb', line 35

def storage_type
  @storage_type
end

#updated_atObject

Returns the value of attribute updated_at.



44
45
46
# File 'lib/spatio-sdk/models/spatio_file.rb', line 44

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



65
66
67
# File 'lib/spatio-sdk/models/spatio_file.rb', line 65

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/spatio-sdk/models/spatio_file.rb', line 70

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/spatio-sdk/models/spatio_file.rb', line 47

def self.attribute_map
  {
    :'id' => :'id',
    :'provider' => :'provider',
    :'account_id' => :'accountId',
    :'name' => :'name',
    :'size' => :'size',
    :'mime_type' => :'mimeType',
    :'folder_id' => :'folderId',
    :'storage_type' => :'storageType',
    :'download_url' => :'downloadUrl',
    :'metadata' => :'metadata',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/spatio-sdk/models/spatio_file.rb', line 334

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



93
94
95
96
97
# File 'lib/spatio-sdk/models/spatio_file.rb', line 93

def self.openapi_nullable
  Set.new([
    :'folder_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/spatio-sdk/models/spatio_file.rb', line 75

def self.openapi_types
  {
    :'id' => :'String',
    :'provider' => :'String',
    :'account_id' => :'String',
    :'name' => :'String',
    :'size' => :'Integer',
    :'mime_type' => :'String',
    :'folder_id' => :'String',
    :'storage_type' => :'String',
    :'download_url' => :'String',
    :'metadata' => :'Hash<String, Object>',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/spatio-sdk/models/spatio_file.rb', line 302

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      provider == o.provider &&
       == o. &&
      name == o.name &&
      size == o.size &&
      mime_type == o.mime_type &&
      folder_id == o.folder_id &&
      storage_type == o.storage_type &&
      download_url == o.download_url &&
       == o. &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


321
322
323
# File 'lib/spatio-sdk/models/spatio_file.rb', line 321

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



327
328
329
# File 'lib/spatio-sdk/models/spatio_file.rb', line 327

def hash
  [id, provider, , name, size, mime_type, folder_id, storage_type, download_url, , created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/spatio-sdk/models/spatio_file.rb', line 182

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @size.nil?
    invalid_properties.push('invalid value for "size", size cannot be nil.')
  end

  if @mime_type.nil?
    invalid_properties.push('invalid value for "mime_type", mime_type cannot be nil.')
  end

  if @storage_type.nil?
    invalid_properties.push('invalid value for "storage_type", storage_type cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'lib/spatio-sdk/models/spatio_file.rb', line 356

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



218
219
220
221
222
223
224
225
226
227
228
# File 'lib/spatio-sdk/models/spatio_file.rb', line 218

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @size.nil?
  return false if @mime_type.nil?
  return false if @storage_type.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  true
end