Class: Spatio::TokenResponse

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/token_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TokenResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/spatio-sdk/models/token_response.rb', line 75

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::TokenResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::TokenResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'access_token')
    self.access_token = attributes[:'access_token']
  else
    self.access_token = nil
  end

  if attributes.key?(:'token_type')
    self.token_type = attributes[:'token_type']
  else
    self.token_type = nil
  end

  if attributes.key?(:'expires_in')
    self.expires_in = attributes[:'expires_in']
  else
    self.expires_in = nil
  end

  if attributes.key?(:'refresh_token')
    self.refresh_token = attributes[:'refresh_token']
  end

  if attributes.key?(:'scope')
    self.scope = attributes[:'scope']
  end

  if attributes.key?(:'id_token')
    self.id_token = attributes[:'id_token']
  end
end

Instance Attribute Details

#access_tokenObject

Opaque bearer token. Format ‘tok_<32 random base64url>`.



19
20
21
# File 'lib/spatio-sdk/models/token_response.rb', line 19

def access_token
  @access_token
end

#expires_inObject

Seconds until access_token expires.



24
25
26
# File 'lib/spatio-sdk/models/token_response.rb', line 24

def expires_in
  @expires_in
end

#id_tokenObject

Only present when ‘openid` scope was granted. RS256-signed JWT — verify against the JWKS.



31
32
33
# File 'lib/spatio-sdk/models/token_response.rb', line 31

def id_token
  @id_token
end

#refresh_tokenObject

Returns the value of attribute refresh_token.



26
27
28
# File 'lib/spatio-sdk/models/token_response.rb', line 26

def refresh_token
  @refresh_token
end

#scopeObject

Returns the value of attribute scope.



28
29
30
# File 'lib/spatio-sdk/models/token_response.rb', line 28

def scope
  @scope
end

#token_typeObject

Returns the value of attribute token_type.



21
22
23
# File 'lib/spatio-sdk/models/token_response.rb', line 21

def token_type
  @token_type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



46
47
48
# File 'lib/spatio-sdk/models/token_response.rb', line 46

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/spatio-sdk/models/token_response.rb', line 51

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
43
# File 'lib/spatio-sdk/models/token_response.rb', line 34

def self.attribute_map
  {
    :'access_token' => :'access_token',
    :'token_type' => :'token_type',
    :'expires_in' => :'expires_in',
    :'refresh_token' => :'refresh_token',
    :'scope' => :'scope',
    :'id_token' => :'id_token'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/spatio-sdk/models/token_response.rb', line 208

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



68
69
70
71
# File 'lib/spatio-sdk/models/token_response.rb', line 68

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
65
# File 'lib/spatio-sdk/models/token_response.rb', line 56

def self.openapi_types
  {
    :'access_token' => :'String',
    :'token_type' => :'String',
    :'expires_in' => :'Integer',
    :'refresh_token' => :'String',
    :'scope' => :'String',
    :'id_token' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



182
183
184
185
186
187
188
189
190
191
# File 'lib/spatio-sdk/models/token_response.rb', line 182

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      access_token == o.access_token &&
      token_type == o.token_type &&
      expires_in == o.expires_in &&
      refresh_token == o.refresh_token &&
      scope == o.scope &&
      id_token == o.id_token
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


195
196
197
# File 'lib/spatio-sdk/models/token_response.rb', line 195

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



201
202
203
# File 'lib/spatio-sdk/models/token_response.rb', line 201

def hash
  [access_token, token_type, expires_in, refresh_token, scope, id_token].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/spatio-sdk/models/token_response.rb', line 122

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @access_token.nil?
    invalid_properties.push('invalid value for "access_token", access_token cannot be nil.')
  end

  if @token_type.nil?
    invalid_properties.push('invalid value for "token_type", token_type cannot be nil.')
  end

  if @expires_in.nil?
    invalid_properties.push('invalid value for "expires_in", expires_in cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/spatio-sdk/models/token_response.rb', line 230

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



142
143
144
145
146
147
148
# File 'lib/spatio-sdk/models/token_response.rb', line 142

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @access_token.nil?
  return false if @token_type.nil?
  return false if @expires_in.nil?
  true
end