Class: Spatio::UpdateDraftRequest

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/update_draft_request.rb

Overview

Partial update — every field optional.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateDraftRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/spatio-sdk/models/update_draft_request.rb', line 81

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::UpdateDraftRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::UpdateDraftRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'to')
    if (value = attributes[:'to']).is_a?(Array)
      self.to = value
    end
  end

  if attributes.key?(:'cc')
    if (value = attributes[:'cc']).is_a?(Array)
      self.cc = value
    end
  end

  if attributes.key?(:'bcc')
    if (value = attributes[:'bcc']).is_a?(Array)
      self.bcc = value
    end
  end

  if attributes.key?(:'subject')
    self.subject = attributes[:'subject']
  end

  if attributes.key?(:'body')
    self.body = attributes[:'body']
  end

  if attributes.key?(:'html')
    self.html = attributes[:'html']
  end

  if attributes.key?(:'attachments')
    if (value = attributes[:'attachments']).is_a?(Array)
      self.attachments = value
    end
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



19
20
21
# File 'lib/spatio-sdk/models/update_draft_request.rb', line 19

def 
  @account_id
end

#attachmentsObject

Returns the value of attribute attachments.



33
34
35
# File 'lib/spatio-sdk/models/update_draft_request.rb', line 33

def attachments
  @attachments
end

#bccObject

Returns the value of attribute bcc.



25
26
27
# File 'lib/spatio-sdk/models/update_draft_request.rb', line 25

def bcc
  @bcc
end

#bodyObject

Returns the value of attribute body.



29
30
31
# File 'lib/spatio-sdk/models/update_draft_request.rb', line 29

def body
  @body
end

#ccObject

Returns the value of attribute cc.



23
24
25
# File 'lib/spatio-sdk/models/update_draft_request.rb', line 23

def cc
  @cc
end

#htmlObject

Returns the value of attribute html.



31
32
33
# File 'lib/spatio-sdk/models/update_draft_request.rb', line 31

def html
  @html
end

#subjectObject

Returns the value of attribute subject.



27
28
29
# File 'lib/spatio-sdk/models/update_draft_request.rb', line 27

def subject
  @subject
end

#toObject

Returns the value of attribute to.



21
22
23
# File 'lib/spatio-sdk/models/update_draft_request.rb', line 21

def to
  @to
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



50
51
52
# File 'lib/spatio-sdk/models/update_draft_request.rb', line 50

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/spatio-sdk/models/update_draft_request.rb', line 55

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
46
47
# File 'lib/spatio-sdk/models/update_draft_request.rb', line 36

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'to' => :'to',
    :'cc' => :'cc',
    :'bcc' => :'bcc',
    :'subject' => :'subject',
    :'body' => :'body',
    :'html' => :'html',
    :'attachments' => :'attachments'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/spatio-sdk/models/update_draft_request.rb', line 181

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



74
75
76
77
# File 'lib/spatio-sdk/models/update_draft_request.rb', line 74

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/spatio-sdk/models/update_draft_request.rb', line 60

def self.openapi_types
  {
    :'account_id' => :'String',
    :'to' => :'Array<String>',
    :'cc' => :'Array<String>',
    :'bcc' => :'Array<String>',
    :'subject' => :'String',
    :'body' => :'String',
    :'html' => :'Boolean',
    :'attachments' => :'Array<AttachmentInput>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/spatio-sdk/models/update_draft_request.rb', line 153

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      to == o.to &&
      cc == o.cc &&
      bcc == o.bcc &&
      subject == o.subject &&
      body == o.body &&
      html == o.html &&
      attachments == o.attachments
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


168
169
170
# File 'lib/spatio-sdk/models/update_draft_request.rb', line 168

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



174
175
176
# File 'lib/spatio-sdk/models/update_draft_request.rb', line 174

def hash
  [, to, cc, bcc, subject, body, html, attachments].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



138
139
140
141
142
# File 'lib/spatio-sdk/models/update_draft_request.rb', line 138

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/spatio-sdk/models/update_draft_request.rb', line 203

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



146
147
148
149
# File 'lib/spatio-sdk/models/update_draft_request.rb', line 146

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end