Class: Spatio::UpdateEventRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Spatio::UpdateEventRequest
- Defined in:
- lib/spatio-sdk/models/update_event_request.rb
Overview
Sparse update. ‘updates` is a free-form map of fields to change; only keys present are applied. The server-side capability gate rejects fields that the underlying provider doesn’t support.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#send_updates ⇒ Object
Returns the value of attribute send_updates.
-
#updates ⇒ Object
Returns the value of attribute updates.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateEventRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateEventRequest
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/spatio-sdk/models/update_event_request.rb', line 83 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::UpdateEventRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::UpdateEventRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'updates') if (value = attributes[:'updates']).is_a?(Hash) self.updates = value end else self.updates = nil end if attributes.key?(:'send_updates') self.send_updates = attributes[:'send_updates'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
19 20 21 |
# File 'lib/spatio-sdk/models/update_event_request.rb', line 19 def account_id @account_id end |
#send_updates ⇒ Object
Returns the value of attribute send_updates.
23 24 25 |
# File 'lib/spatio-sdk/models/update_event_request.rb', line 23 def send_updates @send_updates end |
#updates ⇒ Object
Returns the value of attribute updates.
21 22 23 |
# File 'lib/spatio-sdk/models/update_event_request.rb', line 21 def updates @updates end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
57 58 59 |
# File 'lib/spatio-sdk/models/update_event_request.rb', line 57 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/spatio-sdk/models/update_event_request.rb', line 62 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
48 49 50 51 52 53 54 |
# File 'lib/spatio-sdk/models/update_event_request.rb', line 48 def self.attribute_map { :'account_id' => :'account_id', :'updates' => :'updates', :'send_updates' => :'send_updates' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/spatio-sdk/models/update_event_request.rb', line 198 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
76 77 78 79 |
# File 'lib/spatio-sdk/models/update_event_request.rb', line 76 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 |
# File 'lib/spatio-sdk/models/update_event_request.rb', line 67 def self.openapi_types { :'account_id' => :'String', :'updates' => :'Hash<String, Object>', :'send_updates' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
175 176 177 178 179 180 181 |
# File 'lib/spatio-sdk/models/update_event_request.rb', line 175 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && updates == o.updates && send_updates == o.send_updates end |
#eql?(o) ⇒ Boolean
185 186 187 |
# File 'lib/spatio-sdk/models/update_event_request.rb', line 185 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
191 192 193 |
# File 'lib/spatio-sdk/models/update_event_request.rb', line 191 def hash [account_id, updates, send_updates].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/spatio-sdk/models/update_event_request.rb', line 118 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @updates.nil? invalid_properties.push('invalid value for "updates", updates cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/spatio-sdk/models/update_event_request.rb', line 220 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
134 135 136 137 138 139 140 141 |
# File 'lib/spatio-sdk/models/update_event_request.rb', line 134 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @account_id.nil? return false if @updates.nil? send_updates_validator = EnumAttributeValidator.new('String', ["all", "externalOnly", "none"]) return false unless send_updates_validator.valid?(@send_updates) true end |