Class: Spatio::UpdateNoteRequest

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/update_note_request.rb

Overview

Partial update. Every field is optional; only fields present in the body are touched. ‘null` for `parentId` clears the parent.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateNoteRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/spatio-sdk/models/update_note_request.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::UpdateNoteRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::UpdateNoteRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'content')
    self.content = attributes[:'content']
  end

  if attributes.key?(:'icon')
    self.icon = attributes[:'icon']
  end

  if attributes.key?(:'cover_image')
    self.cover_image = attributes[:'cover_image']
  end

  if attributes.key?(:'parent_id')
    self.parent_id = attributes[:'parent_id']
  end

  if attributes.key?(:'properties')
    if (value = attributes[:'properties']).is_a?(Hash)
      self.properties = value
    end
  end

  if attributes.key?(:'archived')
    self.archived = attributes[:'archived']
  end
end

Instance Attribute Details

#archivedObject

Returns the value of attribute archived.



31
32
33
# File 'lib/spatio-sdk/models/update_note_request.rb', line 31

def archived
  @archived
end

#contentObject

Returns the value of attribute content.



21
22
23
# File 'lib/spatio-sdk/models/update_note_request.rb', line 21

def content
  @content
end

#cover_imageObject

Returns the value of attribute cover_image.



25
26
27
# File 'lib/spatio-sdk/models/update_note_request.rb', line 25

def cover_image
  @cover_image
end

#iconObject

Returns the value of attribute icon.



23
24
25
# File 'lib/spatio-sdk/models/update_note_request.rb', line 23

def icon
  @icon
end

#parent_idObject

Returns the value of attribute parent_id.



27
28
29
# File 'lib/spatio-sdk/models/update_note_request.rb', line 27

def parent_id
  @parent_id
end

#propertiesObject

Returns the value of attribute properties.



29
30
31
# File 'lib/spatio-sdk/models/update_note_request.rb', line 29

def properties
  @properties
end

#titleObject

Returns the value of attribute title.



19
20
21
# File 'lib/spatio-sdk/models/update_note_request.rb', line 19

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



47
48
49
# File 'lib/spatio-sdk/models/update_note_request.rb', line 47

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



52
53
54
# File 'lib/spatio-sdk/models/update_note_request.rb', line 52

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
43
44
# File 'lib/spatio-sdk/models/update_note_request.rb', line 34

def self.attribute_map
  {
    :'title' => :'title',
    :'content' => :'content',
    :'icon' => :'icon',
    :'cover_image' => :'coverImage',
    :'parent_id' => :'parentId',
    :'properties' => :'properties',
    :'archived' => :'archived'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/spatio-sdk/models/update_note_request.rb', line 167

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



70
71
72
73
74
# File 'lib/spatio-sdk/models/update_note_request.rb', line 70

def self.openapi_nullable
  Set.new([
    :'parent_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



57
58
59
60
61
62
63
64
65
66
67
# File 'lib/spatio-sdk/models/update_note_request.rb', line 57

def self.openapi_types
  {
    :'title' => :'String',
    :'content' => :'String',
    :'icon' => :'String',
    :'cover_image' => :'String',
    :'parent_id' => :'String',
    :'properties' => :'Hash<String, Object>',
    :'archived' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



140
141
142
143
144
145
146
147
148
149
150
# File 'lib/spatio-sdk/models/update_note_request.rb', line 140

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      title == o.title &&
      content == o.content &&
      icon == o.icon &&
      cover_image == o.cover_image &&
      parent_id == o.parent_id &&
      properties == o.properties &&
      archived == o.archived
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


154
155
156
# File 'lib/spatio-sdk/models/update_note_request.rb', line 154

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



160
161
162
# File 'lib/spatio-sdk/models/update_note_request.rb', line 160

def hash
  [title, content, icon, cover_image, parent_id, properties, archived].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



125
126
127
128
129
# File 'lib/spatio-sdk/models/update_note_request.rb', line 125

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/spatio-sdk/models/update_note_request.rb', line 189

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



133
134
135
136
# File 'lib/spatio-sdk/models/update_note_request.rb', line 133

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end