Class: Spatio::UpdateSheetRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Spatio::UpdateSheetRequest
- Defined in:
- lib/spatio-sdk/models/update_sheet_request.rb
Overview
Partial update — every field is optional.
Instance Attribute Summary collapse
-
#column_count ⇒ Object
Returns the value of attribute column_count.
-
#data ⇒ Object
Returns the value of attribute data.
-
#description ⇒ Object
Returns the value of attribute description.
-
#is_public ⇒ Object
Returns the value of attribute is_public.
-
#is_read_only ⇒ Object
Returns the value of attribute is_read_only.
-
#name ⇒ Object
Returns the value of attribute name.
-
#row_count ⇒ Object
Returns the value of attribute row_count.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateSheetRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateSheetRequest
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/spatio-sdk/models/update_sheet_request.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::UpdateSheetRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::UpdateSheetRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'data') if (value = attributes[:'data']).is_a?(Hash) self.data = value end end if attributes.key?(:'row_count') self.row_count = attributes[:'row_count'] end if attributes.key?(:'column_count') self.column_count = attributes[:'column_count'] end if attributes.key?(:'is_public') self.is_public = attributes[:'is_public'] end if attributes.key?(:'is_read_only') self.is_read_only = attributes[:'is_read_only'] end end |
Instance Attribute Details
#column_count ⇒ Object
Returns the value of attribute column_count.
27 28 29 |
# File 'lib/spatio-sdk/models/update_sheet_request.rb', line 27 def column_count @column_count end |
#data ⇒ Object
Returns the value of attribute data.
23 24 25 |
# File 'lib/spatio-sdk/models/update_sheet_request.rb', line 23 def data @data end |
#description ⇒ Object
Returns the value of attribute description.
21 22 23 |
# File 'lib/spatio-sdk/models/update_sheet_request.rb', line 21 def description @description end |
#is_public ⇒ Object
Returns the value of attribute is_public.
29 30 31 |
# File 'lib/spatio-sdk/models/update_sheet_request.rb', line 29 def is_public @is_public end |
#is_read_only ⇒ Object
Returns the value of attribute is_read_only.
31 32 33 |
# File 'lib/spatio-sdk/models/update_sheet_request.rb', line 31 def is_read_only @is_read_only end |
#name ⇒ Object
Returns the value of attribute name.
19 20 21 |
# File 'lib/spatio-sdk/models/update_sheet_request.rb', line 19 def name @name end |
#row_count ⇒ Object
Returns the value of attribute row_count.
25 26 27 |
# File 'lib/spatio-sdk/models/update_sheet_request.rb', line 25 def row_count @row_count end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
47 48 49 |
# File 'lib/spatio-sdk/models/update_sheet_request.rb', line 47 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
52 53 54 |
# File 'lib/spatio-sdk/models/update_sheet_request.rb', line 52 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/spatio-sdk/models/update_sheet_request.rb', line 34 def self.attribute_map { :'name' => :'name', :'description' => :'description', :'data' => :'data', :'row_count' => :'rowCount', :'column_count' => :'columnCount', :'is_public' => :'isPublic', :'is_read_only' => :'isReadOnly' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/spatio-sdk/models/update_sheet_request.rb', line 167 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
70 71 72 73 74 |
# File 'lib/spatio-sdk/models/update_sheet_request.rb', line 70 def self.openapi_nullable Set.new([ :'description', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/spatio-sdk/models/update_sheet_request.rb', line 57 def self.openapi_types { :'name' => :'String', :'description' => :'String', :'data' => :'Hash<String, Object>', :'row_count' => :'Integer', :'column_count' => :'Integer', :'is_public' => :'Boolean', :'is_read_only' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/spatio-sdk/models/update_sheet_request.rb', line 140 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && description == o.description && data == o.data && row_count == o.row_count && column_count == o.column_count && is_public == o.is_public && is_read_only == o.is_read_only end |
#eql?(o) ⇒ Boolean
154 155 156 |
# File 'lib/spatio-sdk/models/update_sheet_request.rb', line 154 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
160 161 162 |
# File 'lib/spatio-sdk/models/update_sheet_request.rb', line 160 def hash [name, description, data, row_count, column_count, is_public, is_read_only].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
125 126 127 128 129 |
# File 'lib/spatio-sdk/models/update_sheet_request.rb', line 125 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/spatio-sdk/models/update_sheet_request.rb', line 189 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
133 134 135 136 |
# File 'lib/spatio-sdk/models/update_sheet_request.rb', line 133 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |