Class: Spatio::UpdateSlideElementRequest

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/update_slide_element_request.rb

Overview

Partial update — every field optional.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateSlideElementRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/spatio-sdk/models/update_slide_element_request.rb', line 81

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::UpdateSlideElementRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::UpdateSlideElementRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'element_type')
    self.element_type = attributes[:'element_type']
  end

  if attributes.key?(:'content')
    if (value = attributes[:'content']).is_a?(Hash)
      self.content = value
    end
  end

  if attributes.key?(:'x')
    self.x = attributes[:'x']
  end

  if attributes.key?(:'y')
    self.y = attributes[:'y']
  end

  if attributes.key?(:'width')
    self.width = attributes[:'width']
  end

  if attributes.key?(:'height')
    self.height = attributes[:'height']
  end

  if attributes.key?(:'rotation')
    self.rotation = attributes[:'rotation']
  end

  if attributes.key?(:'z_index')
    self.z_index = attributes[:'z_index']
  end
end

Instance Attribute Details

#contentObject

Returns the value of attribute content.



21
22
23
# File 'lib/spatio-sdk/models/update_slide_element_request.rb', line 21

def content
  @content
end

#element_typeObject

Returns the value of attribute element_type.



19
20
21
# File 'lib/spatio-sdk/models/update_slide_element_request.rb', line 19

def element_type
  @element_type
end

#heightObject

Returns the value of attribute height.



29
30
31
# File 'lib/spatio-sdk/models/update_slide_element_request.rb', line 29

def height
  @height
end

#rotationObject

Returns the value of attribute rotation.



31
32
33
# File 'lib/spatio-sdk/models/update_slide_element_request.rb', line 31

def rotation
  @rotation
end

#widthObject

Returns the value of attribute width.



27
28
29
# File 'lib/spatio-sdk/models/update_slide_element_request.rb', line 27

def width
  @width
end

#xObject

Returns the value of attribute x.



23
24
25
# File 'lib/spatio-sdk/models/update_slide_element_request.rb', line 23

def x
  @x
end

#yObject

Returns the value of attribute y.



25
26
27
# File 'lib/spatio-sdk/models/update_slide_element_request.rb', line 25

def y
  @y
end

#z_indexObject

Returns the value of attribute z_index.



33
34
35
# File 'lib/spatio-sdk/models/update_slide_element_request.rb', line 33

def z_index
  @z_index
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



50
51
52
# File 'lib/spatio-sdk/models/update_slide_element_request.rb', line 50

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/spatio-sdk/models/update_slide_element_request.rb', line 55

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
46
47
# File 'lib/spatio-sdk/models/update_slide_element_request.rb', line 36

def self.attribute_map
  {
    :'element_type' => :'elementType',
    :'content' => :'content',
    :'x' => :'x',
    :'y' => :'y',
    :'width' => :'width',
    :'height' => :'height',
    :'rotation' => :'rotation',
    :'z_index' => :'zIndex'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/spatio-sdk/models/update_slide_element_request.rb', line 175

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



74
75
76
77
# File 'lib/spatio-sdk/models/update_slide_element_request.rb', line 74

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/spatio-sdk/models/update_slide_element_request.rb', line 60

def self.openapi_types
  {
    :'element_type' => :'String',
    :'content' => :'Hash<String, Object>',
    :'x' => :'Float',
    :'y' => :'Float',
    :'width' => :'Float',
    :'height' => :'Float',
    :'rotation' => :'Float',
    :'z_index' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/spatio-sdk/models/update_slide_element_request.rb', line 147

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      element_type == o.element_type &&
      content == o.content &&
      x == o.x &&
      y == o.y &&
      width == o.width &&
      height == o.height &&
      rotation == o.rotation &&
      z_index == o.z_index
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


162
163
164
# File 'lib/spatio-sdk/models/update_slide_element_request.rb', line 162

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



168
169
170
# File 'lib/spatio-sdk/models/update_slide_element_request.rb', line 168

def hash
  [element_type, content, x, y, width, height, rotation, z_index].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



132
133
134
135
136
# File 'lib/spatio-sdk/models/update_slide_element_request.rb', line 132

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/spatio-sdk/models/update_slide_element_request.rb', line 197

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



140
141
142
143
# File 'lib/spatio-sdk/models/update_slide_element_request.rb', line 140

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end