Class: Spatio::UpdateTaskRequest

Inherits:
ApiModelBase show all
Defined in:
lib/spatio-sdk/models/update_task_request.rb

Overview

Partial update — every field is optional. ‘dueDate` and `parentTaskId` are nullable: send `null` to clear, omit to leave untouched, send a value to set.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateTaskRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/spatio-sdk/models/update_task_request.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::UpdateTaskRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::UpdateTaskRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'due_date')
    self.due_date = attributes[:'due_date']
  end

  if attributes.key?(:'priority')
    self.priority = attributes[:'priority']
  end

  if attributes.key?(:'labels')
    if (value = attributes[:'labels']).is_a?(Array)
      self.labels = value
    end
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'assignee_id')
    self.assignee_id = attributes[:'assignee_id']
  end

  if attributes.key?(:'parent_task_id')
    self.parent_task_id = attributes[:'parent_task_id']
  end
end

Instance Attribute Details

#assignee_idObject

Returns the value of attribute assignee_id.



33
34
35
# File 'lib/spatio-sdk/models/update_task_request.rb', line 33

def assignee_id
  @assignee_id
end

#descriptionObject

Returns the value of attribute description.



21
22
23
# File 'lib/spatio-sdk/models/update_task_request.rb', line 21

def description
  @description
end

#due_dateObject

Returns the value of attribute due_date.



25
26
27
# File 'lib/spatio-sdk/models/update_task_request.rb', line 25

def due_date
  @due_date
end

#labelsObject

Returns the value of attribute labels.



29
30
31
# File 'lib/spatio-sdk/models/update_task_request.rb', line 29

def labels
  @labels
end

#parent_task_idObject

Returns the value of attribute parent_task_id.



35
36
37
# File 'lib/spatio-sdk/models/update_task_request.rb', line 35

def parent_task_id
  @parent_task_id
end

#priorityObject

Returns the value of attribute priority.



27
28
29
# File 'lib/spatio-sdk/models/update_task_request.rb', line 27

def priority
  @priority
end

#statusObject

Returns the value of attribute status.



23
24
25
# File 'lib/spatio-sdk/models/update_task_request.rb', line 23

def status
  @status
end

#tagsObject

Returns the value of attribute tags.



31
32
33
# File 'lib/spatio-sdk/models/update_task_request.rb', line 31

def tags
  @tags
end

#titleObject

Returns the value of attribute title.



19
20
21
# File 'lib/spatio-sdk/models/update_task_request.rb', line 19

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



75
76
77
# File 'lib/spatio-sdk/models/update_task_request.rb', line 75

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/spatio-sdk/models/update_task_request.rb', line 80

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/spatio-sdk/models/update_task_request.rb', line 60

def self.attribute_map
  {
    :'title' => :'title',
    :'description' => :'description',
    :'status' => :'status',
    :'due_date' => :'dueDate',
    :'priority' => :'priority',
    :'labels' => :'labels',
    :'tags' => :'tags',
    :'assignee_id' => :'assigneeId',
    :'parent_task_id' => :'parentTaskId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/spatio-sdk/models/update_task_request.rb', line 222

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



100
101
102
103
104
105
# File 'lib/spatio-sdk/models/update_task_request.rb', line 100

def self.openapi_nullable
  Set.new([
    :'due_date',
    :'parent_task_id'
  ])
end

.openapi_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/spatio-sdk/models/update_task_request.rb', line 85

def self.openapi_types
  {
    :'title' => :'String',
    :'description' => :'String',
    :'status' => :'String',
    :'due_date' => :'Time',
    :'priority' => :'String',
    :'labels' => :'Array<String>',
    :'tags' => :'Array<String>',
    :'assignee_id' => :'String',
    :'parent_task_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/spatio-sdk/models/update_task_request.rb', line 193

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      title == o.title &&
      description == o.description &&
      status == o.status &&
      due_date == o.due_date &&
      priority == o.priority &&
      labels == o.labels &&
      tags == o.tags &&
      assignee_id == o.assignee_id &&
      parent_task_id == o.parent_task_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


209
210
211
# File 'lib/spatio-sdk/models/update_task_request.rb', line 209

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



215
216
217
# File 'lib/spatio-sdk/models/update_task_request.rb', line 215

def hash
  [title, description, status, due_date, priority, labels, tags, assignee_id, parent_task_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



166
167
168
169
170
# File 'lib/spatio-sdk/models/update_task_request.rb', line 166

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/spatio-sdk/models/update_task_request.rb', line 244

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



174
175
176
177
178
179
# File 'lib/spatio-sdk/models/update_task_request.rb', line 174

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  priority_validator = EnumAttributeValidator.new('String', ["none", "low", "medium", "high", "urgent"])
  return false unless priority_validator.valid?(@priority)
  true
end