Class: Spatio::UserInfoResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Spatio::UserInfoResponse
- Defined in:
- lib/spatio-sdk/models/user_info_response.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
Returns the value of attribute email.
-
#email_verified ⇒ Object
Returns the value of attribute email_verified.
-
#family_name ⇒ Object
Returns the value of attribute family_name.
-
#given_name ⇒ Object
Returns the value of attribute given_name.
-
#name ⇒ Object
Returns the value of attribute name.
-
#picture ⇒ Object
Returns the value of attribute picture.
-
#preferred_username ⇒ Object
Returns the value of attribute preferred_username.
-
#sub ⇒ Object
User identifier (stable for the lifetime of the user).
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UserInfoResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UserInfoResponse
Initializes the object
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/spatio-sdk/models/user_info_response.rb', line 85 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::UserInfoResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::UserInfoResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'sub') self.sub = attributes[:'sub'] else self.sub = nil end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'email_verified') self.email_verified = attributes[:'email_verified'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'given_name') self.given_name = attributes[:'given_name'] end if attributes.key?(:'family_name') self.family_name = attributes[:'family_name'] end if attributes.key?(:'preferred_username') self.preferred_username = attributes[:'preferred_username'] end if attributes.key?(:'picture') self.picture = attributes[:'picture'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#email ⇒ Object
Returns the value of attribute email.
21 22 23 |
# File 'lib/spatio-sdk/models/user_info_response.rb', line 21 def email @email end |
#email_verified ⇒ Object
Returns the value of attribute email_verified.
23 24 25 |
# File 'lib/spatio-sdk/models/user_info_response.rb', line 23 def email_verified @email_verified end |
#family_name ⇒ Object
Returns the value of attribute family_name.
29 30 31 |
# File 'lib/spatio-sdk/models/user_info_response.rb', line 29 def family_name @family_name end |
#given_name ⇒ Object
Returns the value of attribute given_name.
27 28 29 |
# File 'lib/spatio-sdk/models/user_info_response.rb', line 27 def given_name @given_name end |
#name ⇒ Object
Returns the value of attribute name.
25 26 27 |
# File 'lib/spatio-sdk/models/user_info_response.rb', line 25 def name @name end |
#picture ⇒ Object
Returns the value of attribute picture.
33 34 35 |
# File 'lib/spatio-sdk/models/user_info_response.rb', line 33 def picture @picture end |
#preferred_username ⇒ Object
Returns the value of attribute preferred_username.
31 32 33 |
# File 'lib/spatio-sdk/models/user_info_response.rb', line 31 def preferred_username @preferred_username end |
#sub ⇒ Object
User identifier (stable for the lifetime of the user).
19 20 21 |
# File 'lib/spatio-sdk/models/user_info_response.rb', line 19 def sub @sub end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
35 36 37 |
# File 'lib/spatio-sdk/models/user_info_response.rb', line 35 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
53 54 55 |
# File 'lib/spatio-sdk/models/user_info_response.rb', line 53 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/spatio-sdk/models/user_info_response.rb', line 58 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/spatio-sdk/models/user_info_response.rb', line 38 def self.attribute_map { :'sub' => :'sub', :'email' => :'email', :'email_verified' => :'email_verified', :'name' => :'name', :'given_name' => :'given_name', :'family_name' => :'family_name', :'preferred_username' => :'preferred_username', :'picture' => :'picture', :'updated_at' => :'updated_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/spatio-sdk/models/user_info_response.rb', line 199 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
78 79 80 81 |
# File 'lib/spatio-sdk/models/user_info_response.rb', line 78 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/spatio-sdk/models/user_info_response.rb', line 63 def self.openapi_types { :'sub' => :'String', :'email' => :'String', :'email_verified' => :'Boolean', :'name' => :'String', :'given_name' => :'String', :'family_name' => :'String', :'preferred_username' => :'String', :'picture' => :'String', :'updated_at' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/spatio-sdk/models/user_info_response.rb', line 170 def ==(o) return true if self.equal?(o) self.class == o.class && sub == o.sub && email == o.email && email_verified == o.email_verified && name == o.name && given_name == o.given_name && family_name == o.family_name && preferred_username == o.preferred_username && picture == o.picture && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
186 187 188 |
# File 'lib/spatio-sdk/models/user_info_response.rb', line 186 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
192 193 194 |
# File 'lib/spatio-sdk/models/user_info_response.rb', line 192 def hash [sub, email, email_verified, name, given_name, family_name, preferred_username, picture, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
140 141 142 143 144 145 146 147 148 |
# File 'lib/spatio-sdk/models/user_info_response.rb', line 140 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @sub.nil? invalid_properties.push('invalid value for "sub", sub cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/spatio-sdk/models/user_info_response.rb', line 221 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
152 153 154 155 156 |
# File 'lib/spatio-sdk/models/user_info_response.rb', line 152 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @sub.nil? true end |