Class: Spatio::Workspace
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Spatio::Workspace
- Defined in:
- lib/spatio-sdk/models/workspace.rb
Overview
A workspace within an organization. Returned in list responses (‘GET /v1/workspaces`, `GET /v1/organizations/#id/workspaces`) and the single-get response (`GET /v1/workspaces/#id`, wrapped in `…`). `settings` shape varies by endpoint — sometimes a JSON object, sometimes a JSON-encoded string. Treat as opaque.
Instance Attribute Summary collapse
-
#billing_tier ⇒ Object
Returns the value of attribute billing_tier.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#description ⇒ Object
Returns the value of attribute description.
-
#id ⇒ Object
Returns the value of attribute id.
-
#is_default ⇒ Object
Returns the value of attribute is_default.
-
#logo_url ⇒ Object
Returns the value of attribute logo_url.
-
#member_count ⇒ Object
Returns the value of attribute member_count.
-
#name ⇒ Object
Returns the value of attribute name.
-
#organization ⇒ Object
Returns the value of attribute organization.
-
#organization_id ⇒ Object
Returns the value of attribute organization_id.
-
#role ⇒ Object
The caller’s role in this workspace (‘owner`, `admin`, `member`, `guest`).
-
#settings ⇒ Object
Per-workspace settings.
-
#slug ⇒ Object
Returns the value of attribute slug.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Workspace
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Workspace
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/spatio-sdk/models/workspace.rb', line 110 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::Workspace` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::Workspace`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'slug') self.slug = attributes[:'slug'] else self.slug = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'logo_url') self.logo_url = attributes[:'logo_url'] end if attributes.key?(:'organization_id') self.organization_id = attributes[:'organization_id'] end if attributes.key?(:'organization') self.organization = attributes[:'organization'] end if attributes.key?(:'role') self.role = attributes[:'role'] end if attributes.key?(:'settings') self.settings = attributes[:'settings'] end if attributes.key?(:'is_default') self.is_default = attributes[:'is_default'] end if attributes.key?(:'member_count') self.member_count = attributes[:'member_count'] end if attributes.key?(:'billing_tier') self.billing_tier = attributes[:'billing_tier'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#billing_tier ⇒ Object
Returns the value of attribute billing_tier.
43 44 45 |
# File 'lib/spatio-sdk/models/workspace.rb', line 43 def billing_tier @billing_tier end |
#created_at ⇒ Object
Returns the value of attribute created_at.
45 46 47 |
# File 'lib/spatio-sdk/models/workspace.rb', line 45 def created_at @created_at end |
#description ⇒ Object
Returns the value of attribute description.
25 26 27 |
# File 'lib/spatio-sdk/models/workspace.rb', line 25 def description @description end |
#id ⇒ Object
Returns the value of attribute id.
19 20 21 |
# File 'lib/spatio-sdk/models/workspace.rb', line 19 def id @id end |
#is_default ⇒ Object
Returns the value of attribute is_default.
39 40 41 |
# File 'lib/spatio-sdk/models/workspace.rb', line 39 def is_default @is_default end |
#logo_url ⇒ Object
Returns the value of attribute logo_url.
27 28 29 |
# File 'lib/spatio-sdk/models/workspace.rb', line 27 def logo_url @logo_url end |
#member_count ⇒ Object
Returns the value of attribute member_count.
41 42 43 |
# File 'lib/spatio-sdk/models/workspace.rb', line 41 def member_count @member_count end |
#name ⇒ Object
Returns the value of attribute name.
21 22 23 |
# File 'lib/spatio-sdk/models/workspace.rb', line 21 def name @name end |
#organization ⇒ Object
Returns the value of attribute organization.
31 32 33 |
# File 'lib/spatio-sdk/models/workspace.rb', line 31 def organization @organization end |
#organization_id ⇒ Object
Returns the value of attribute organization_id.
29 30 31 |
# File 'lib/spatio-sdk/models/workspace.rb', line 29 def organization_id @organization_id end |
#role ⇒ Object
The caller’s role in this workspace (‘owner`, `admin`, `member`, `guest`).
34 35 36 |
# File 'lib/spatio-sdk/models/workspace.rb', line 34 def role @role end |
#settings ⇒ Object
37 38 39 |
# File 'lib/spatio-sdk/models/workspace.rb', line 37 def settings @settings end |
#slug ⇒ Object
Returns the value of attribute slug.
23 24 25 |
# File 'lib/spatio-sdk/models/workspace.rb', line 23 def slug @slug end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
47 48 49 |
# File 'lib/spatio-sdk/models/workspace.rb', line 47 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
70 71 72 |
# File 'lib/spatio-sdk/models/workspace.rb', line 70 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
75 76 77 |
# File 'lib/spatio-sdk/models/workspace.rb', line 75 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/spatio-sdk/models/workspace.rb', line 50 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'slug' => :'slug', :'description' => :'description', :'logo_url' => :'logoUrl', :'organization_id' => :'organizationId', :'organization' => :'organization', :'role' => :'role', :'settings' => :'settings', :'is_default' => :'isDefault', :'member_count' => :'memberCount', :'billing_tier' => :'billingTier', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/spatio-sdk/models/workspace.rb', line 283 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
100 101 102 103 104 105 106 |
# File 'lib/spatio-sdk/models/workspace.rb', line 100 def self.openapi_nullable Set.new([ :'description', :'logo_url', :'settings', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/spatio-sdk/models/workspace.rb', line 80 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'slug' => :'String', :'description' => :'String', :'logo_url' => :'String', :'organization_id' => :'String', :'organization' => :'WorkspaceOrganization', :'role' => :'String', :'settings' => :'Object', :'is_default' => :'Boolean', :'member_count' => :'Integer', :'billing_tier' => :'String', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/spatio-sdk/models/workspace.rb', line 249 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && slug == o.slug && description == o.description && logo_url == o.logo_url && organization_id == o.organization_id && organization == o.organization && role == o.role && settings == o.settings && is_default == o.is_default && member_count == o.member_count && billing_tier == o.billing_tier && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
270 271 272 |
# File 'lib/spatio-sdk/models/workspace.rb', line 270 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
276 277 278 |
# File 'lib/spatio-sdk/models/workspace.rb', line 276 def hash [id, name, slug, description, logo_url, organization_id, organization, role, settings, is_default, member_count, billing_tier, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/spatio-sdk/models/workspace.rb', line 189 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @slug.nil? invalid_properties.push('invalid value for "slug", slug cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/spatio-sdk/models/workspace.rb', line 305 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
209 210 211 212 213 214 215 |
# File 'lib/spatio-sdk/models/workspace.rb', line 209 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @name.nil? return false if @slug.nil? true end |