Class: Spatio::AccountUsage
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Spatio::AccountUsage
- Defined in:
- lib/spatio-sdk/models/account_usage.rb
Overview
Today’s usage counters. Snapshot reflects the in-memory rollup; counts reset at UTC midnight.
Instance Attribute Summary collapse
-
#api_calls ⇒ Object
Returns the value of attribute api_calls.
-
#date ⇒ Object
Always ‘today` for the current-day rollup.
-
#email_sends ⇒ Object
Returns the value of attribute email_sends.
-
#files_count ⇒ Object
Returns the value of attribute files_count.
-
#notes_count ⇒ Object
Returns the value of attribute notes_count.
-
#sheets_count ⇒ Object
Returns the value of attribute sheets_count.
-
#slides_count ⇒ Object
Returns the value of attribute slides_count.
-
#tasks_count ⇒ Object
Returns the value of attribute tasks_count.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AccountUsage
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AccountUsage
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/spatio-sdk/models/account_usage.rb', line 82 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::AccountUsage` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::AccountUsage`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'date') self.date = attributes[:'date'] else self.date = nil end if attributes.key?(:'api_calls') self.api_calls = attributes[:'api_calls'] end if attributes.key?(:'email_sends') self.email_sends = attributes[:'email_sends'] end if attributes.key?(:'notes_count') self.notes_count = attributes[:'notes_count'] end if attributes.key?(:'sheets_count') self.sheets_count = attributes[:'sheets_count'] end if attributes.key?(:'slides_count') self. = attributes[:'slides_count'] end if attributes.key?(:'files_count') self.files_count = attributes[:'files_count'] end if attributes.key?(:'tasks_count') self.tasks_count = attributes[:'tasks_count'] end end |
Instance Attribute Details
#api_calls ⇒ Object
Returns the value of attribute api_calls.
22 23 24 |
# File 'lib/spatio-sdk/models/account_usage.rb', line 22 def api_calls @api_calls end |
#date ⇒ Object
Always ‘today` for the current-day rollup.
20 21 22 |
# File 'lib/spatio-sdk/models/account_usage.rb', line 20 def date @date end |
#email_sends ⇒ Object
Returns the value of attribute email_sends.
24 25 26 |
# File 'lib/spatio-sdk/models/account_usage.rb', line 24 def email_sends @email_sends end |
#files_count ⇒ Object
Returns the value of attribute files_count.
32 33 34 |
# File 'lib/spatio-sdk/models/account_usage.rb', line 32 def files_count @files_count end |
#notes_count ⇒ Object
Returns the value of attribute notes_count.
26 27 28 |
# File 'lib/spatio-sdk/models/account_usage.rb', line 26 def notes_count @notes_count end |
#sheets_count ⇒ Object
Returns the value of attribute sheets_count.
28 29 30 |
# File 'lib/spatio-sdk/models/account_usage.rb', line 28 def sheets_count @sheets_count end |
#slides_count ⇒ Object
Returns the value of attribute slides_count.
30 31 32 |
# File 'lib/spatio-sdk/models/account_usage.rb', line 30 def @slides_count end |
#tasks_count ⇒ Object
Returns the value of attribute tasks_count.
34 35 36 |
# File 'lib/spatio-sdk/models/account_usage.rb', line 34 def tasks_count @tasks_count end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
51 52 53 |
# File 'lib/spatio-sdk/models/account_usage.rb', line 51 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
56 57 58 |
# File 'lib/spatio-sdk/models/account_usage.rb', line 56 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/spatio-sdk/models/account_usage.rb', line 37 def self.attribute_map { :'date' => :'date', :'api_calls' => :'api_calls', :'email_sends' => :'email_sends', :'notes_count' => :'notes_count', :'sheets_count' => :'sheets_count', :'slides_count' => :'slides_count', :'files_count' => :'files_count', :'tasks_count' => :'tasks_count' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/spatio-sdk/models/account_usage.rb', line 191 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
75 76 77 78 |
# File 'lib/spatio-sdk/models/account_usage.rb', line 75 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/spatio-sdk/models/account_usage.rb', line 61 def self.openapi_types { :'date' => :'String', :'api_calls' => :'Integer', :'email_sends' => :'Integer', :'notes_count' => :'Integer', :'sheets_count' => :'Integer', :'slides_count' => :'Integer', :'files_count' => :'Integer', :'tasks_count' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/spatio-sdk/models/account_usage.rb', line 163 def ==(o) return true if self.equal?(o) self.class == o.class && date == o.date && api_calls == o.api_calls && email_sends == o.email_sends && notes_count == o.notes_count && sheets_count == o.sheets_count && == o. && files_count == o.files_count && tasks_count == o.tasks_count end |
#eql?(o) ⇒ Boolean
178 179 180 |
# File 'lib/spatio-sdk/models/account_usage.rb', line 178 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
184 185 186 |
# File 'lib/spatio-sdk/models/account_usage.rb', line 184 def hash [date, api_calls, email_sends, notes_count, sheets_count, , files_count, tasks_count].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
133 134 135 136 137 138 139 140 141 |
# File 'lib/spatio-sdk/models/account_usage.rb', line 133 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @date.nil? invalid_properties.push('invalid value for "date", date cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/spatio-sdk/models/account_usage.rb', line 213 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
145 146 147 148 149 |
# File 'lib/spatio-sdk/models/account_usage.rb', line 145 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @date.nil? true end |