Class: Spatio::AmbiguousAccountError
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Spatio::AmbiguousAccountError
- Defined in:
- lib/spatio-sdk/models/ambiguous_account_error.rb
Overview
Returned when the caller’s request matches more than one connected account and no ‘accountId` query param disambiguates which one to target. The `accounts` array enumerates the candidates so the client can prompt the user to pick.
Instance Attribute Summary collapse
-
#accounts ⇒ Object
Returns the value of attribute accounts.
-
#code ⇒ Object
Machine-readable error code.
-
#error ⇒ Object
Human-readable error message.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AmbiguousAccountError
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AmbiguousAccountError
Initializes the object
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/spatio-sdk/models/ambiguous_account_error.rb', line 70 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::AmbiguousAccountError` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::AmbiguousAccountError`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'error') self.error = attributes[:'error'] else self.error = nil end if attributes.key?(:'code') self.code = attributes[:'code'] end if attributes.key?(:'accounts') if (value = attributes[:'accounts']).is_a?(Array) self.accounts = value end end end |
Instance Attribute Details
#accounts ⇒ Object
Returns the value of attribute accounts.
25 26 27 |
# File 'lib/spatio-sdk/models/ambiguous_account_error.rb', line 25 def accounts @accounts end |
#code ⇒ Object
Machine-readable error code. Stable across releases for the canonical codes (‘ambiguous_account`, `no_notes_provider`, `note_not_found`). Absent for generic errors.
23 24 25 |
# File 'lib/spatio-sdk/models/ambiguous_account_error.rb', line 23 def code @code end |
#error ⇒ Object
Human-readable error message.
20 21 22 |
# File 'lib/spatio-sdk/models/ambiguous_account_error.rb', line 20 def error @error end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
37 38 39 |
# File 'lib/spatio-sdk/models/ambiguous_account_error.rb', line 37 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
42 43 44 |
# File 'lib/spatio-sdk/models/ambiguous_account_error.rb', line 42 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 |
# File 'lib/spatio-sdk/models/ambiguous_account_error.rb', line 28 def self.attribute_map { :'error' => :'error', :'code' => :'code', :'accounts' => :'accounts' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/spatio-sdk/models/ambiguous_account_error.rb', line 156 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
62 63 64 65 66 |
# File 'lib/spatio-sdk/models/ambiguous_account_error.rb', line 62 def self.openapi_all_of [ :'ApiError' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
56 57 58 59 |
# File 'lib/spatio-sdk/models/ambiguous_account_error.rb', line 56 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 |
# File 'lib/spatio-sdk/models/ambiguous_account_error.rb', line 47 def self.openapi_types { :'error' => :'String', :'code' => :'String', :'accounts' => :'Array<AccountChoice>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
133 134 135 136 137 138 139 |
# File 'lib/spatio-sdk/models/ambiguous_account_error.rb', line 133 def ==(o) return true if self.equal?(o) self.class == o.class && error == o.error && code == o.code && accounts == o.accounts end |
#eql?(o) ⇒ Boolean
143 144 145 |
# File 'lib/spatio-sdk/models/ambiguous_account_error.rb', line 143 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
149 150 151 |
# File 'lib/spatio-sdk/models/ambiguous_account_error.rb', line 149 def hash [error, code, accounts].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
103 104 105 106 107 108 109 110 111 |
# File 'lib/spatio-sdk/models/ambiguous_account_error.rb', line 103 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @error.nil? invalid_properties.push('invalid value for "error", error cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/spatio-sdk/models/ambiguous_account_error.rb', line 178 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
115 116 117 118 119 |
# File 'lib/spatio-sdk/models/ambiguous_account_error.rb', line 115 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @error.nil? true end |