Class: Spatio::CalendarProviderInfo
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Spatio::CalendarProviderInfo
- Defined in:
- lib/spatio-sdk/models/calendar_provider_info.rb
Overview
Metadata about one registered calendar provider.
Instance Attribute Summary collapse
-
#description ⇒ Object
Returns the value of attribute description.
-
#display_name ⇒ Object
Returns the value of attribute display_name.
-
#id ⇒ Object
Stable provider id (e.g. ‘google-calendar`, `native-calendar`).
-
#is_system ⇒ Object
‘true` for built-in providers (the native calendar).
-
#name ⇒ Object
Returns the value of attribute name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CalendarProviderInfo
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CalendarProviderInfo
Initializes the object
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/spatio-sdk/models/calendar_provider_info.rb', line 71 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::CalendarProviderInfo` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::CalendarProviderInfo`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'is_system') self.is_system = attributes[:'is_system'] end end |
Instance Attribute Details
#description ⇒ Object
Returns the value of attribute description.
26 27 28 |
# File 'lib/spatio-sdk/models/calendar_provider_info.rb', line 26 def description @description end |
#display_name ⇒ Object
Returns the value of attribute display_name.
24 25 26 |
# File 'lib/spatio-sdk/models/calendar_provider_info.rb', line 24 def display_name @display_name end |
#id ⇒ Object
Stable provider id (e.g. ‘google-calendar`, `native-calendar`).
20 21 22 |
# File 'lib/spatio-sdk/models/calendar_provider_info.rb', line 20 def id @id end |
#is_system ⇒ Object
‘true` for built-in providers (the native calendar).
29 30 31 |
# File 'lib/spatio-sdk/models/calendar_provider_info.rb', line 29 def is_system @is_system end |
#name ⇒ Object
Returns the value of attribute name.
22 23 24 |
# File 'lib/spatio-sdk/models/calendar_provider_info.rb', line 22 def name @name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
43 44 45 |
# File 'lib/spatio-sdk/models/calendar_provider_info.rb', line 43 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
48 49 50 |
# File 'lib/spatio-sdk/models/calendar_provider_info.rb', line 48 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 |
# File 'lib/spatio-sdk/models/calendar_provider_info.rb', line 32 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'display_name' => :'display_name', :'description' => :'description', :'is_system' => :'is_system' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/spatio-sdk/models/calendar_provider_info.rb', line 182 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
64 65 66 67 |
# File 'lib/spatio-sdk/models/calendar_provider_info.rb', line 64 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 |
# File 'lib/spatio-sdk/models/calendar_provider_info.rb', line 53 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'display_name' => :'String', :'description' => :'String', :'is_system' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
157 158 159 160 161 162 163 164 165 |
# File 'lib/spatio-sdk/models/calendar_provider_info.rb', line 157 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && display_name == o.display_name && description == o.description && is_system == o.is_system end |
#eql?(o) ⇒ Boolean
169 170 171 |
# File 'lib/spatio-sdk/models/calendar_provider_info.rb', line 169 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
175 176 177 |
# File 'lib/spatio-sdk/models/calendar_provider_info.rb', line 175 def hash [id, name, display_name, description, is_system].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/spatio-sdk/models/calendar_provider_info.rb', line 112 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/spatio-sdk/models/calendar_provider_info.rb', line 204 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
128 129 130 131 132 133 |
# File 'lib/spatio-sdk/models/calendar_provider_info.rb', line 128 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @name.nil? true end |