Class: Spatio::ChatActionDefinition
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Spatio::ChatActionDefinition
- Defined in:
- lib/spatio-sdk/models/chat_action_definition.rb
Overview
One entry in ‘GET /actions`. Action ids are dotted (e.g. `direct-messages.send`, `channels.list`); the `executeAction` endpoint accepts the id with a free-form `params` object.
Instance Attribute Summary collapse
-
#category ⇒ Object
Common values: ‘read`, `write`, `delete`, `manage`, `sync`.
-
#description ⇒ Object
Returns the value of attribute description.
-
#id ⇒ Object
Returns the value of attribute id.
-
#input_type ⇒ Object
Returns the value of attribute input_type.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#name ⇒ Object
Returns the value of attribute name.
-
#output_type ⇒ Object
Returns the value of attribute output_type.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#scopes ⇒ Object
‘null` when no scopes are declared (Go nil-slice).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ChatActionDefinition
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ChatActionDefinition
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/spatio-sdk/models/chat_action_definition.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::ChatActionDefinition` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::ChatActionDefinition`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] else self.platform = nil end if attributes.key?(:'category') self.category = attributes[:'category'] end if attributes.key?(:'input_type') self.input_type = attributes[:'input_type'] end if attributes.key?(:'output_type') self.output_type = attributes[:'output_type'] end if attributes.key?(:'scopes') if (value = attributes[:'scopes']).is_a?(Array) self.scopes = value end end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end end |
Instance Attribute Details
#category ⇒ Object
Common values: ‘read`, `write`, `delete`, `manage`, `sync`.
28 29 30 |
# File 'lib/spatio-sdk/models/chat_action_definition.rb', line 28 def category @category end |
#description ⇒ Object
Returns the value of attribute description.
23 24 25 |
# File 'lib/spatio-sdk/models/chat_action_definition.rb', line 23 def description @description end |
#id ⇒ Object
Returns the value of attribute id.
19 20 21 |
# File 'lib/spatio-sdk/models/chat_action_definition.rb', line 19 def id @id end |
#input_type ⇒ Object
Returns the value of attribute input_type.
30 31 32 |
# File 'lib/spatio-sdk/models/chat_action_definition.rb', line 30 def input_type @input_type end |
#metadata ⇒ Object
Returns the value of attribute metadata.
37 38 39 |
# File 'lib/spatio-sdk/models/chat_action_definition.rb', line 37 def @metadata end |
#name ⇒ Object
Returns the value of attribute name.
21 22 23 |
# File 'lib/spatio-sdk/models/chat_action_definition.rb', line 21 def name @name end |
#output_type ⇒ Object
Returns the value of attribute output_type.
32 33 34 |
# File 'lib/spatio-sdk/models/chat_action_definition.rb', line 32 def output_type @output_type end |
#platform ⇒ Object
Returns the value of attribute platform.
25 26 27 |
# File 'lib/spatio-sdk/models/chat_action_definition.rb', line 25 def platform @platform end |
#scopes ⇒ Object
‘null` when no scopes are declared (Go nil-slice).
35 36 37 |
# File 'lib/spatio-sdk/models/chat_action_definition.rb', line 35 def scopes @scopes end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
55 56 57 |
# File 'lib/spatio-sdk/models/chat_action_definition.rb', line 55 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
60 61 62 |
# File 'lib/spatio-sdk/models/chat_action_definition.rb', line 60 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/spatio-sdk/models/chat_action_definition.rb', line 40 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'description' => :'description', :'platform' => :'platform', :'category' => :'category', :'input_type' => :'inputType', :'output_type' => :'outputType', :'scopes' => :'scopes', :'metadata' => :'metadata' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/spatio-sdk/models/chat_action_definition.rb', line 240 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
80 81 82 83 84 |
# File 'lib/spatio-sdk/models/chat_action_definition.rb', line 80 def self.openapi_nullable Set.new([ :'scopes', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/spatio-sdk/models/chat_action_definition.rb', line 65 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'description' => :'String', :'platform' => :'String', :'category' => :'String', :'input_type' => :'String', :'output_type' => :'String', :'scopes' => :'Array<String>', :'metadata' => :'Hash<String, Object>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/spatio-sdk/models/chat_action_definition.rb', line 211 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && description == o.description && platform == o.platform && category == o.category && input_type == o.input_type && output_type == o.output_type && scopes == o.scopes && == o. end |
#eql?(o) ⇒ Boolean
227 228 229 |
# File 'lib/spatio-sdk/models/chat_action_definition.rb', line 227 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
233 234 235 |
# File 'lib/spatio-sdk/models/chat_action_definition.rb', line 233 def hash [id, name, description, platform, category, input_type, output_type, scopes, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/spatio-sdk/models/chat_action_definition.rb', line 151 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @platform.nil? invalid_properties.push('invalid value for "platform", platform cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/spatio-sdk/models/chat_action_definition.rb', line 262 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
171 172 173 174 175 176 177 |
# File 'lib/spatio-sdk/models/chat_action_definition.rb', line 171 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @name.nil? return false if @platform.nil? true end |