Class: Spatio::ChatMessage
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Spatio::ChatMessage
- Defined in:
- lib/spatio-sdk/models/chat_message.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#channel_id ⇒ Object
Returns the value of attribute channel_id.
-
#extra ⇒ Object
Provider-specific extras.
-
#id ⇒ Object
Returns the value of attribute id.
-
#provider ⇒ Object
Returns the value of attribute provider.
-
#reply_count ⇒ Object
Returns the value of attribute reply_count.
-
#text ⇒ Object
Returns the value of attribute text.
-
#thread_id ⇒ Object
Set on replies and on parent messages once a thread exists.
-
#timestamp ⇒ Object
Returns the value of attribute timestamp.
-
#user_id ⇒ Object
Returns the value of attribute user_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ChatMessage
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ChatMessage
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/spatio-sdk/models/chat_message.rb', line 90 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::ChatMessage` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::ChatMessage`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'provider') self.provider = attributes[:'provider'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'channel_id') self.channel_id = attributes[:'channel_id'] else self.channel_id = nil end if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] else self.user_id = nil end if attributes.key?(:'text') self.text = attributes[:'text'] else self.text = nil end if attributes.key?(:'thread_id') self.thread_id = attributes[:'thread_id'] end if attributes.key?(:'timestamp') self. = attributes[:'timestamp'] else self. = nil end if attributes.key?(:'reply_count') self.reply_count = attributes[:'reply_count'] end if attributes.key?(:'extra') if (value = attributes[:'extra']).is_a?(Hash) self.extra = value end end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
22 23 24 |
# File 'lib/spatio-sdk/models/chat_message.rb', line 22 def account_id @account_id end |
#channel_id ⇒ Object
Returns the value of attribute channel_id.
24 25 26 |
# File 'lib/spatio-sdk/models/chat_message.rb', line 24 def channel_id @channel_id end |
#extra ⇒ Object
Provider-specific extras.
38 39 40 |
# File 'lib/spatio-sdk/models/chat_message.rb', line 38 def extra @extra end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/spatio-sdk/models/chat_message.rb', line 18 def id @id end |
#provider ⇒ Object
Returns the value of attribute provider.
20 21 22 |
# File 'lib/spatio-sdk/models/chat_message.rb', line 20 def provider @provider end |
#reply_count ⇒ Object
Returns the value of attribute reply_count.
35 36 37 |
# File 'lib/spatio-sdk/models/chat_message.rb', line 35 def reply_count @reply_count end |
#text ⇒ Object
Returns the value of attribute text.
28 29 30 |
# File 'lib/spatio-sdk/models/chat_message.rb', line 28 def text @text end |
#thread_id ⇒ Object
Set on replies and on parent messages once a thread exists.
31 32 33 |
# File 'lib/spatio-sdk/models/chat_message.rb', line 31 def thread_id @thread_id end |
#timestamp ⇒ Object
Returns the value of attribute timestamp.
33 34 35 |
# File 'lib/spatio-sdk/models/chat_message.rb', line 33 def @timestamp end |
#user_id ⇒ Object
Returns the value of attribute user_id.
26 27 28 |
# File 'lib/spatio-sdk/models/chat_message.rb', line 26 def user_id @user_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
57 58 59 |
# File 'lib/spatio-sdk/models/chat_message.rb', line 57 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/spatio-sdk/models/chat_message.rb', line 62 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/spatio-sdk/models/chat_message.rb', line 41 def self.attribute_map { :'id' => :'id', :'provider' => :'provider', :'account_id' => :'accountId', :'channel_id' => :'channelId', :'user_id' => :'userId', :'text' => :'text', :'thread_id' => :'threadId', :'timestamp' => :'timestamp', :'reply_count' => :'replyCount', :'extra' => :'extra' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/spatio-sdk/models/chat_message.rb', line 279 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
83 84 85 86 |
# File 'lib/spatio-sdk/models/chat_message.rb', line 83 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/spatio-sdk/models/chat_message.rb', line 67 def self.openapi_types { :'id' => :'String', :'provider' => :'String', :'account_id' => :'String', :'channel_id' => :'String', :'user_id' => :'String', :'text' => :'String', :'thread_id' => :'String', :'timestamp' => :'Time', :'reply_count' => :'Integer', :'extra' => :'Hash<String, Object>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
249 250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/spatio-sdk/models/chat_message.rb', line 249 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && provider == o.provider && account_id == o.account_id && channel_id == o.channel_id && user_id == o.user_id && text == o.text && thread_id == o.thread_id && == o. && reply_count == o.reply_count && extra == o.extra end |
#eql?(o) ⇒ Boolean
266 267 268 |
# File 'lib/spatio-sdk/models/chat_message.rb', line 266 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
272 273 274 |
# File 'lib/spatio-sdk/models/chat_message.rb', line 272 def hash [id, provider, account_id, channel_id, user_id, text, thread_id, , reply_count, extra].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/spatio-sdk/models/chat_message.rb', line 159 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @channel_id.nil? invalid_properties.push('invalid value for "channel_id", channel_id cannot be nil.') end if @user_id.nil? invalid_properties.push('invalid value for "user_id", user_id cannot be nil.') end if @text.nil? invalid_properties.push('invalid value for "text", text cannot be nil.') end if @timestamp.nil? invalid_properties.push('invalid value for "timestamp", timestamp cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/spatio-sdk/models/chat_message.rb', line 301 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
187 188 189 190 191 192 193 194 195 |
# File 'lib/spatio-sdk/models/chat_message.rb', line 187 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @channel_id.nil? return false if @user_id.nil? return false if @text.nil? return false if @timestamp.nil? true end |