Class: Spatio::Conversation
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Spatio::Conversation
- Defined in:
- lib/spatio-sdk/models/conversation.rb
Overview
LLM conversation persisted by the platform-service. Stored in snake_case at the wire (legacy DTO; predates the camelCase rest of the API). Treat field names as authoritative.
Instance Attribute Summary collapse
-
#context ⇒ Object
Free-form context tag (e.g. ‘sidebar:sheets:entity:<id>`).
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#cwd ⇒ Object
Returns the value of attribute cwd.
-
#id ⇒ Object
Returns the value of attribute id.
-
#is_active ⇒ Object
Returns the value of attribute is_active.
-
#last_message_at ⇒ Object
Returns the value of attribute last_message_at.
-
#message_count ⇒ Object
Returns the value of attribute message_count.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#pinned ⇒ Object
Returns the value of attribute pinned.
-
#session_id ⇒ Object
Returns the value of attribute session_id.
-
#title ⇒ Object
Returns the value of attribute title.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
-
#user_id ⇒ Object
Returns the value of attribute user_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Conversation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Conversation
Initializes the object
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/spatio-sdk/models/conversation.rb', line 106 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::Conversation` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::Conversation`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] else self.user_id = nil end if attributes.key?(:'title') self.title = attributes[:'title'] else self.title = nil end if attributes.key?(:'context') self.context = attributes[:'context'] end if attributes.key?(:'cwd') self.cwd = attributes[:'cwd'] end if attributes.key?(:'session_id') self.session_id = attributes[:'session_id'] end if attributes.key?(:'pinned') self.pinned = attributes[:'pinned'] end if attributes.key?(:'last_message_at') self. = attributes[:'last_message_at'] end if attributes.key?(:'message_count') self. = attributes[:'message_count'] end if attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#context ⇒ Object
Free-form context tag (e.g. ‘sidebar:sheets:entity:<id>`).
26 27 28 |
# File 'lib/spatio-sdk/models/conversation.rb', line 26 def context @context end |
#created_at ⇒ Object
Returns the value of attribute created_at.
42 43 44 |
# File 'lib/spatio-sdk/models/conversation.rb', line 42 def created_at @created_at end |
#cwd ⇒ Object
Returns the value of attribute cwd.
28 29 30 |
# File 'lib/spatio-sdk/models/conversation.rb', line 28 def cwd @cwd end |
#id ⇒ Object
Returns the value of attribute id.
19 20 21 |
# File 'lib/spatio-sdk/models/conversation.rb', line 19 def id @id end |
#is_active ⇒ Object
Returns the value of attribute is_active.
38 39 40 |
# File 'lib/spatio-sdk/models/conversation.rb', line 38 def is_active @is_active end |
#last_message_at ⇒ Object
Returns the value of attribute last_message_at.
34 35 36 |
# File 'lib/spatio-sdk/models/conversation.rb', line 34 def @last_message_at end |
#message_count ⇒ Object
Returns the value of attribute message_count.
36 37 38 |
# File 'lib/spatio-sdk/models/conversation.rb', line 36 def @message_count end |
#metadata ⇒ Object
Returns the value of attribute metadata.
40 41 42 |
# File 'lib/spatio-sdk/models/conversation.rb', line 40 def @metadata end |
#pinned ⇒ Object
Returns the value of attribute pinned.
32 33 34 |
# File 'lib/spatio-sdk/models/conversation.rb', line 32 def pinned @pinned end |
#session_id ⇒ Object
Returns the value of attribute session_id.
30 31 32 |
# File 'lib/spatio-sdk/models/conversation.rb', line 30 def session_id @session_id end |
#title ⇒ Object
Returns the value of attribute title.
23 24 25 |
# File 'lib/spatio-sdk/models/conversation.rb', line 23 def title @title end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
44 45 46 |
# File 'lib/spatio-sdk/models/conversation.rb', line 44 def updated_at @updated_at end |
#user_id ⇒ Object
Returns the value of attribute user_id.
21 22 23 |
# File 'lib/spatio-sdk/models/conversation.rb', line 21 def user_id @user_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
66 67 68 |
# File 'lib/spatio-sdk/models/conversation.rb', line 66 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
71 72 73 |
# File 'lib/spatio-sdk/models/conversation.rb', line 71 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/spatio-sdk/models/conversation.rb', line 47 def self.attribute_map { :'id' => :'id', :'user_id' => :'user_id', :'title' => :'title', :'context' => :'context', :'cwd' => :'cwd', :'session_id' => :'session_id', :'pinned' => :'pinned', :'last_message_at' => :'last_message_at', :'message_count' => :'message_count', :'is_active' => :'is_active', :'metadata' => :'metadata', :'created_at' => :'created_at', :'updated_at' => :'updated_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/spatio-sdk/models/conversation.rb', line 276 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
95 96 97 98 99 100 101 102 |
# File 'lib/spatio-sdk/models/conversation.rb', line 95 def self.openapi_nullable Set.new([ :'context', :'cwd', :'session_id', :'last_message_at', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/spatio-sdk/models/conversation.rb', line 76 def self.openapi_types { :'id' => :'String', :'user_id' => :'String', :'title' => :'String', :'context' => :'String', :'cwd' => :'String', :'session_id' => :'String', :'pinned' => :'Boolean', :'last_message_at' => :'Time', :'message_count' => :'Integer', :'is_active' => :'Boolean', :'metadata' => :'Hash<String, Object>', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/spatio-sdk/models/conversation.rb', line 243 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && user_id == o.user_id && title == o.title && context == o.context && cwd == o.cwd && session_id == o.session_id && pinned == o.pinned && == o. && == o. && is_active == o.is_active && == o. && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
263 264 265 |
# File 'lib/spatio-sdk/models/conversation.rb', line 263 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
269 270 271 |
# File 'lib/spatio-sdk/models/conversation.rb', line 269 def hash [id, user_id, title, context, cwd, session_id, pinned, , , is_active, , created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/spatio-sdk/models/conversation.rb', line 183 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @user_id.nil? invalid_properties.push('invalid value for "user_id", user_id cannot be nil.') end if @title.nil? invalid_properties.push('invalid value for "title", title cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/spatio-sdk/models/conversation.rb', line 298 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
203 204 205 206 207 208 209 |
# File 'lib/spatio-sdk/models/conversation.rb', line 203 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @user_id.nil? return false if @title.nil? true end |