Class: Spatio::CreateDraftRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Spatio::CreateDraftRequest
- Defined in:
- lib/spatio-sdk/models/create_draft_request.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#attachments ⇒ Object
Returns the value of attribute attachments.
-
#bcc ⇒ Object
Returns the value of attribute bcc.
-
#body ⇒ Object
Returns the value of attribute body.
-
#cc ⇒ Object
Returns the value of attribute cc.
-
#html ⇒ Object
Returns the value of attribute html.
-
#in_reply_to ⇒ Object
Returns the value of attribute in_reply_to.
-
#references ⇒ Object
Returns the value of attribute references.
-
#subject ⇒ Object
Returns the value of attribute subject.
-
#thread_id ⇒ Object
Provider thread id — set when this draft is a reply, so the sent message lands inside the parent thread.
-
#to ⇒ Object
Returns the value of attribute to.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDraftRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateDraftRequest
Initializes the object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/spatio-sdk/models/create_draft_request.rb', line 93 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::CreateDraftRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::CreateDraftRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'to') if (value = attributes[:'to']).is_a?(Array) self.to = value end end if attributes.key?(:'cc') if (value = attributes[:'cc']).is_a?(Array) self.cc = value end end if attributes.key?(:'bcc') if (value = attributes[:'bcc']).is_a?(Array) self.bcc = value end end if attributes.key?(:'subject') self.subject = attributes[:'subject'] end if attributes.key?(:'body') self.body = attributes[:'body'] end if attributes.key?(:'html') self.html = attributes[:'html'] end if attributes.key?(:'attachments') if (value = attributes[:'attachments']).is_a?(Array) self. = value end end if attributes.key?(:'thread_id') self.thread_id = attributes[:'thread_id'] end if attributes.key?(:'in_reply_to') self.in_reply_to = attributes[:'in_reply_to'] end if attributes.key?(:'references') if (value = attributes[:'references']).is_a?(Array) self.references = value end end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
18 19 20 |
# File 'lib/spatio-sdk/models/create_draft_request.rb', line 18 def account_id @account_id end |
#attachments ⇒ Object
Returns the value of attribute attachments.
32 33 34 |
# File 'lib/spatio-sdk/models/create_draft_request.rb', line 32 def @attachments end |
#bcc ⇒ Object
Returns the value of attribute bcc.
24 25 26 |
# File 'lib/spatio-sdk/models/create_draft_request.rb', line 24 def bcc @bcc end |
#body ⇒ Object
Returns the value of attribute body.
28 29 30 |
# File 'lib/spatio-sdk/models/create_draft_request.rb', line 28 def body @body end |
#cc ⇒ Object
Returns the value of attribute cc.
22 23 24 |
# File 'lib/spatio-sdk/models/create_draft_request.rb', line 22 def cc @cc end |
#html ⇒ Object
Returns the value of attribute html.
30 31 32 |
# File 'lib/spatio-sdk/models/create_draft_request.rb', line 30 def html @html end |
#in_reply_to ⇒ Object
Returns the value of attribute in_reply_to.
37 38 39 |
# File 'lib/spatio-sdk/models/create_draft_request.rb', line 37 def in_reply_to @in_reply_to end |
#references ⇒ Object
Returns the value of attribute references.
39 40 41 |
# File 'lib/spatio-sdk/models/create_draft_request.rb', line 39 def references @references end |
#subject ⇒ Object
Returns the value of attribute subject.
26 27 28 |
# File 'lib/spatio-sdk/models/create_draft_request.rb', line 26 def subject @subject end |
#thread_id ⇒ Object
Provider thread id — set when this draft is a reply, so the sent message lands inside the parent thread.
35 36 37 |
# File 'lib/spatio-sdk/models/create_draft_request.rb', line 35 def thread_id @thread_id end |
#to ⇒ Object
Returns the value of attribute to.
20 21 22 |
# File 'lib/spatio-sdk/models/create_draft_request.rb', line 20 def to @to end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
59 60 61 |
# File 'lib/spatio-sdk/models/create_draft_request.rb', line 59 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
64 65 66 |
# File 'lib/spatio-sdk/models/create_draft_request.rb', line 64 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/spatio-sdk/models/create_draft_request.rb', line 42 def self.attribute_map { :'account_id' => :'accountId', :'to' => :'to', :'cc' => :'cc', :'bcc' => :'bcc', :'subject' => :'subject', :'body' => :'body', :'html' => :'html', :'attachments' => :'attachments', :'thread_id' => :'threadId', :'in_reply_to' => :'inReplyTo', :'references' => :'references' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/spatio-sdk/models/create_draft_request.rb', line 210 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
86 87 88 89 |
# File 'lib/spatio-sdk/models/create_draft_request.rb', line 86 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/spatio-sdk/models/create_draft_request.rb', line 69 def self.openapi_types { :'account_id' => :'String', :'to' => :'Array<String>', :'cc' => :'Array<String>', :'bcc' => :'Array<String>', :'subject' => :'String', :'body' => :'String', :'html' => :'Boolean', :'attachments' => :'Array<AttachmentInput>', :'thread_id' => :'String', :'in_reply_to' => :'String', :'references' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/spatio-sdk/models/create_draft_request.rb', line 179 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && to == o.to && cc == o.cc && bcc == o.bcc && subject == o.subject && body == o.body && html == o.html && == o. && thread_id == o.thread_id && in_reply_to == o.in_reply_to && references == o.references end |
#eql?(o) ⇒ Boolean
197 198 199 |
# File 'lib/spatio-sdk/models/create_draft_request.rb', line 197 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
203 204 205 |
# File 'lib/spatio-sdk/models/create_draft_request.rb', line 203 def hash [account_id, to, cc, bcc, subject, body, html, , thread_id, in_reply_to, references].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
164 165 166 167 168 |
# File 'lib/spatio-sdk/models/create_draft_request.rb', line 164 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/spatio-sdk/models/create_draft_request.rb', line 232 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
172 173 174 175 |
# File 'lib/spatio-sdk/models/create_draft_request.rb', line 172 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |