Class: Spatio::DMAttachRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Spatio::DMAttachRequest
- Defined in:
- lib/spatio-sdk/models/dm_attach_request.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#filename ⇒ Object
Returns the value of attribute filename.
-
#height ⇒ Object
Returns the value of attribute height.
-
#kind ⇒ Object
Attachment kind (‘image`, `file`, `audio`, `video`, etc.).
-
#mime_type ⇒ Object
Returns the value of attribute mime_type.
-
#size_bytes ⇒ Object
Returns the value of attribute size_bytes.
-
#thumbnail_url ⇒ Object
Returns the value of attribute thumbnail_url.
-
#url ⇒ Object
Returns the value of attribute url.
-
#width ⇒ Object
Returns the value of attribute width.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DMAttachRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DMAttachRequest
Initializes the object
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/spatio-sdk/models/dm_attach_request.rb', line 85 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::DMAttachRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::DMAttachRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'kind') self.kind = attributes[:'kind'] else self.kind = nil end if attributes.key?(:'url') self.url = attributes[:'url'] else self.url = nil end if attributes.key?(:'filename') self.filename = attributes[:'filename'] end if attributes.key?(:'size_bytes') self.size_bytes = attributes[:'size_bytes'] end if attributes.key?(:'mime_type') self.mime_type = attributes[:'mime_type'] end if attributes.key?(:'thumbnail_url') self.thumbnail_url = attributes[:'thumbnail_url'] end if attributes.key?(:'width') self.width = attributes[:'width'] end if attributes.key?(:'height') self.height = attributes[:'height'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
35 36 37 |
# File 'lib/spatio-sdk/models/dm_attach_request.rb', line 35 def account_id @account_id end |
#filename ⇒ Object
Returns the value of attribute filename.
23 24 25 |
# File 'lib/spatio-sdk/models/dm_attach_request.rb', line 23 def filename @filename end |
#height ⇒ Object
Returns the value of attribute height.
33 34 35 |
# File 'lib/spatio-sdk/models/dm_attach_request.rb', line 33 def height @height end |
#kind ⇒ Object
Attachment kind (‘image`, `file`, `audio`, `video`, etc.).
19 20 21 |
# File 'lib/spatio-sdk/models/dm_attach_request.rb', line 19 def kind @kind end |
#mime_type ⇒ Object
Returns the value of attribute mime_type.
27 28 29 |
# File 'lib/spatio-sdk/models/dm_attach_request.rb', line 27 def mime_type @mime_type end |
#size_bytes ⇒ Object
Returns the value of attribute size_bytes.
25 26 27 |
# File 'lib/spatio-sdk/models/dm_attach_request.rb', line 25 def size_bytes @size_bytes end |
#thumbnail_url ⇒ Object
Returns the value of attribute thumbnail_url.
29 30 31 |
# File 'lib/spatio-sdk/models/dm_attach_request.rb', line 29 def thumbnail_url @thumbnail_url end |
#url ⇒ Object
Returns the value of attribute url.
21 22 23 |
# File 'lib/spatio-sdk/models/dm_attach_request.rb', line 21 def url @url end |
#width ⇒ Object
Returns the value of attribute width.
31 32 33 |
# File 'lib/spatio-sdk/models/dm_attach_request.rb', line 31 def width @width end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
53 54 55 |
# File 'lib/spatio-sdk/models/dm_attach_request.rb', line 53 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/spatio-sdk/models/dm_attach_request.rb', line 58 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/spatio-sdk/models/dm_attach_request.rb', line 38 def self.attribute_map { :'kind' => :'kind', :'url' => :'url', :'filename' => :'filename', :'size_bytes' => :'sizeBytes', :'mime_type' => :'mimeType', :'thumbnail_url' => :'thumbnailUrl', :'width' => :'width', :'height' => :'height', :'account_id' => :'accountId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/spatio-sdk/models/dm_attach_request.rb', line 216 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
78 79 80 81 |
# File 'lib/spatio-sdk/models/dm_attach_request.rb', line 78 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/spatio-sdk/models/dm_attach_request.rb', line 63 def self.openapi_types { :'kind' => :'String', :'url' => :'String', :'filename' => :'String', :'size_bytes' => :'Integer', :'mime_type' => :'String', :'thumbnail_url' => :'String', :'width' => :'Integer', :'height' => :'Integer', :'account_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/spatio-sdk/models/dm_attach_request.rb', line 187 def ==(o) return true if self.equal?(o) self.class == o.class && kind == o.kind && url == o.url && filename == o.filename && size_bytes == o.size_bytes && mime_type == o.mime_type && thumbnail_url == o.thumbnail_url && width == o.width && height == o.height && account_id == o.account_id end |
#eql?(o) ⇒ Boolean
203 204 205 |
# File 'lib/spatio-sdk/models/dm_attach_request.rb', line 203 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
209 210 211 |
# File 'lib/spatio-sdk/models/dm_attach_request.rb', line 209 def hash [kind, url, filename, size_bytes, mime_type, thumbnail_url, width, height, account_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/spatio-sdk/models/dm_attach_request.rb', line 142 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @kind.nil? invalid_properties.push('invalid value for "kind", kind cannot be nil.') end if @url.nil? invalid_properties.push('invalid value for "url", url cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/spatio-sdk/models/dm_attach_request.rb', line 238 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
158 159 160 161 162 163 |
# File 'lib/spatio-sdk/models/dm_attach_request.rb', line 158 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @kind.nil? return false if @url.nil? true end |