Class: Spatio::Draft
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Spatio::Draft
- Defined in:
- lib/spatio-sdk/models/draft.rb
Instance Attribute Summary collapse
-
#attachments ⇒ Object
Returns the value of attribute attachments.
-
#bcc ⇒ Object
Returns the value of attribute bcc.
-
#body ⇒ Object
Returns the value of attribute body.
-
#cc ⇒ Object
Returns the value of attribute cc.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#html ⇒ Object
Returns the value of attribute html.
-
#id ⇒ Object
Returns the value of attribute id.
-
#message_id ⇒ Object
Returns the value of attribute message_id.
-
#subject ⇒ Object
Returns the value of attribute subject.
-
#thread_id ⇒ Object
Returns the value of attribute thread_id.
-
#to ⇒ Object
Returns the value of attribute to.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Draft
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Draft
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/spatio-sdk/models/draft.rb', line 96 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::Draft` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::Draft`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'message_id') self. = attributes[:'message_id'] else self. = nil end if attributes.key?(:'thread_id') self.thread_id = attributes[:'thread_id'] end if attributes.key?(:'to') if (value = attributes[:'to']).is_a?(Array) self.to = value end end if attributes.key?(:'cc') if (value = attributes[:'cc']).is_a?(Array) self.cc = value end end if attributes.key?(:'bcc') if (value = attributes[:'bcc']).is_a?(Array) self.bcc = value end end if attributes.key?(:'subject') self.subject = attributes[:'subject'] end if attributes.key?(:'body') self.body = attributes[:'body'] end if attributes.key?(:'html') self.html = attributes[:'html'] else self.html = nil end if attributes.key?(:'attachments') if (value = attributes[:'attachments']).is_a?(Array) self. = value end end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end end |
Instance Attribute Details
#attachments ⇒ Object
Returns the value of attribute attachments.
36 37 38 |
# File 'lib/spatio-sdk/models/draft.rb', line 36 def @attachments end |
#bcc ⇒ Object
Returns the value of attribute bcc.
28 29 30 |
# File 'lib/spatio-sdk/models/draft.rb', line 28 def bcc @bcc end |
#body ⇒ Object
Returns the value of attribute body.
32 33 34 |
# File 'lib/spatio-sdk/models/draft.rb', line 32 def body @body end |
#cc ⇒ Object
Returns the value of attribute cc.
26 27 28 |
# File 'lib/spatio-sdk/models/draft.rb', line 26 def cc @cc end |
#created_at ⇒ Object
Returns the value of attribute created_at.
38 39 40 |
# File 'lib/spatio-sdk/models/draft.rb', line 38 def created_at @created_at end |
#html ⇒ Object
Returns the value of attribute html.
34 35 36 |
# File 'lib/spatio-sdk/models/draft.rb', line 34 def html @html end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/spatio-sdk/models/draft.rb', line 18 def id @id end |
#message_id ⇒ Object
Returns the value of attribute message_id.
20 21 22 |
# File 'lib/spatio-sdk/models/draft.rb', line 20 def @message_id end |
#subject ⇒ Object
Returns the value of attribute subject.
30 31 32 |
# File 'lib/spatio-sdk/models/draft.rb', line 30 def subject @subject end |
#thread_id ⇒ Object
Returns the value of attribute thread_id.
22 23 24 |
# File 'lib/spatio-sdk/models/draft.rb', line 22 def thread_id @thread_id end |
#to ⇒ Object
Returns the value of attribute to.
24 25 26 |
# File 'lib/spatio-sdk/models/draft.rb', line 24 def to @to end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
40 41 42 |
# File 'lib/spatio-sdk/models/draft.rb', line 40 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
61 62 63 |
# File 'lib/spatio-sdk/models/draft.rb', line 61 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
66 67 68 |
# File 'lib/spatio-sdk/models/draft.rb', line 66 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/spatio-sdk/models/draft.rb', line 43 def self.attribute_map { :'id' => :'id', :'message_id' => :'messageId', :'thread_id' => :'threadId', :'to' => :'to', :'cc' => :'cc', :'bcc' => :'bcc', :'subject' => :'subject', :'body' => :'body', :'html' => :'html', :'attachments' => :'attachments', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/spatio-sdk/models/draft.rb', line 301 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
89 90 91 92 |
# File 'lib/spatio-sdk/models/draft.rb', line 89 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/spatio-sdk/models/draft.rb', line 71 def self.openapi_types { :'id' => :'String', :'message_id' => :'String', :'thread_id' => :'String', :'to' => :'Array<String>', :'cc' => :'Array<String>', :'bcc' => :'Array<String>', :'subject' => :'String', :'body' => :'String', :'html' => :'Boolean', :'attachments' => :'Array<AttachmentMeta>', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/spatio-sdk/models/draft.rb', line 269 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && == o. && thread_id == o.thread_id && to == o.to && cc == o.cc && bcc == o.bcc && subject == o.subject && body == o.body && html == o.html && == o. && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
288 289 290 |
# File 'lib/spatio-sdk/models/draft.rb', line 288 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
294 295 296 |
# File 'lib/spatio-sdk/models/draft.rb', line 294 def hash [id, , thread_id, to, cc, bcc, subject, body, html, , created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/spatio-sdk/models/draft.rb', line 179 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @message_id.nil? invalid_properties.push('invalid value for "message_id", message_id cannot be nil.') end if @html.nil? invalid_properties.push('invalid value for "html", html cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/spatio-sdk/models/draft.rb', line 323 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
207 208 209 210 211 212 213 214 215 |
# File 'lib/spatio-sdk/models/draft.rb', line 207 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @message_id.nil? return false if @html.nil? return false if @created_at.nil? return false if @updated_at.nil? true end |