Class: Spatio::Recommendation
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Spatio::Recommendation
- Defined in:
- lib/spatio-sdk/models/recommendation.rb
Overview
Agent-authored proposal that surfaces on the home feed. Status transitions: ‘pending` → `accepted | dismissed | expired`.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#body ⇒ Object
Returns the value of attribute body.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#expires_at ⇒ Object
Returns the value of attribute expires_at.
-
#id ⇒ Object
Returns the value of attribute id.
-
#kind ⇒ Object
Provider-tagged proposal kind (e.g. ‘note.draft`, `task.followup`).
-
#payload ⇒ Object
Returns the value of attribute payload.
-
#status ⇒ Object
Returns the value of attribute status.
-
#title ⇒ Object
Returns the value of attribute title.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
-
#user_id ⇒ Object
Returns the value of attribute user_id.
-
#workspace_id ⇒ Object
Returns the value of attribute workspace_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Recommendation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Recommendation
Initializes the object
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/spatio-sdk/models/recommendation.rb', line 117 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::Recommendation` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::Recommendation`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'workspace_id') self.workspace_id = attributes[:'workspace_id'] end if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] end if attributes.key?(:'kind') self.kind = attributes[:'kind'] end if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'body') self.body = attributes[:'body'] end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'payload') if (value = attributes[:'payload']).is_a?(Hash) self.payload = value end end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end if attributes.key?(:'expires_at') self.expires_at = attributes[:'expires_at'] end end |
Instance Attribute Details
#body ⇒ Object
Returns the value of attribute body.
30 31 32 |
# File 'lib/spatio-sdk/models/recommendation.rb', line 30 def body @body end |
#created_at ⇒ Object
Returns the value of attribute created_at.
36 37 38 |
# File 'lib/spatio-sdk/models/recommendation.rb', line 36 def created_at @created_at end |
#expires_at ⇒ Object
Returns the value of attribute expires_at.
40 41 42 |
# File 'lib/spatio-sdk/models/recommendation.rb', line 40 def expires_at @expires_at end |
#id ⇒ Object
Returns the value of attribute id.
19 20 21 |
# File 'lib/spatio-sdk/models/recommendation.rb', line 19 def id @id end |
#kind ⇒ Object
Provider-tagged proposal kind (e.g. ‘note.draft`, `task.followup`).
26 27 28 |
# File 'lib/spatio-sdk/models/recommendation.rb', line 26 def kind @kind end |
#payload ⇒ Object
Returns the value of attribute payload.
34 35 36 |
# File 'lib/spatio-sdk/models/recommendation.rb', line 34 def payload @payload end |
#status ⇒ Object
Returns the value of attribute status.
32 33 34 |
# File 'lib/spatio-sdk/models/recommendation.rb', line 32 def status @status end |
#title ⇒ Object
Returns the value of attribute title.
28 29 30 |
# File 'lib/spatio-sdk/models/recommendation.rb', line 28 def title @title end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
38 39 40 |
# File 'lib/spatio-sdk/models/recommendation.rb', line 38 def updated_at @updated_at end |
#user_id ⇒ Object
Returns the value of attribute user_id.
23 24 25 |
# File 'lib/spatio-sdk/models/recommendation.rb', line 23 def user_id @user_id end |
#workspace_id ⇒ Object
Returns the value of attribute workspace_id.
21 22 23 |
# File 'lib/spatio-sdk/models/recommendation.rb', line 21 def workspace_id @workspace_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
82 83 84 |
# File 'lib/spatio-sdk/models/recommendation.rb', line 82 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
87 88 89 |
# File 'lib/spatio-sdk/models/recommendation.rb', line 87 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/spatio-sdk/models/recommendation.rb', line 65 def self.attribute_map { :'id' => :'id', :'workspace_id' => :'workspaceId', :'user_id' => :'userId', :'kind' => :'kind', :'title' => :'title', :'body' => :'body', :'status' => :'status', :'payload' => :'payload', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt', :'expires_at' => :'expiresAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/spatio-sdk/models/recommendation.rb', line 262 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
109 110 111 112 113 |
# File 'lib/spatio-sdk/models/recommendation.rb', line 109 def self.openapi_nullable Set.new([ :'expires_at' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/spatio-sdk/models/recommendation.rb', line 92 def self.openapi_types { :'id' => :'String', :'workspace_id' => :'String', :'user_id' => :'String', :'kind' => :'String', :'title' => :'String', :'body' => :'String', :'status' => :'String', :'payload' => :'Hash<String, Object>', :'created_at' => :'Time', :'updated_at' => :'Time', :'expires_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/spatio-sdk/models/recommendation.rb', line 231 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && workspace_id == o.workspace_id && user_id == o.user_id && kind == o.kind && title == o.title && body == o.body && status == o.status && payload == o.payload && created_at == o.created_at && updated_at == o.updated_at && expires_at == o.expires_at end |
#eql?(o) ⇒ Boolean
249 250 251 |
# File 'lib/spatio-sdk/models/recommendation.rb', line 249 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
255 256 257 |
# File 'lib/spatio-sdk/models/recommendation.rb', line 255 def hash [id, workspace_id, user_id, kind, title, body, status, payload, created_at, updated_at, expires_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/spatio-sdk/models/recommendation.rb', line 184 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/spatio-sdk/models/recommendation.rb', line 284 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
200 201 202 203 204 205 206 207 |
# File 'lib/spatio-sdk/models/recommendation.rb', line 200 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["pending", "accepted", "dismissed", "expired"]) return false unless status_validator.valid?(@status) true end |