Class: Spatio::WorkspaceInvitation
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Spatio::WorkspaceInvitation
- Defined in:
- lib/spatio-sdk/models/workspace_invitation.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#accepted_at ⇒ Object
Returns the value of attribute accepted_at.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#email ⇒ Object
Returns the value of attribute email.
-
#expires_at ⇒ Object
Returns the value of attribute expires_at.
-
#id ⇒ Object
Returns the value of attribute id.
-
#revoked_at ⇒ Object
Returns the value of attribute revoked_at.
-
#role ⇒ Object
Returns the value of attribute role.
-
#status ⇒ Object
Returns the value of attribute status.
-
#workspace_id ⇒ Object
Returns the value of attribute workspace_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WorkspaceInvitation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WorkspaceInvitation
Initializes the object
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/spatio-sdk/models/workspace_invitation.rb', line 109 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Spatio::WorkspaceInvitation` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Spatio::WorkspaceInvitation`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'workspace_id') self.workspace_id = attributes[:'workspace_id'] end if attributes.key?(:'email') self.email = attributes[:'email'] else self.email = nil end if attributes.key?(:'role') self.role = attributes[:'role'] else self.role = nil end if attributes.key?(:'expires_at') self.expires_at = attributes[:'expires_at'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'accepted_at') self.accepted_at = attributes[:'accepted_at'] end if attributes.key?(:'revoked_at') self.revoked_at = attributes[:'revoked_at'] end if attributes.key?(:'status') self.status = attributes[:'status'] end end |
Instance Attribute Details
#accepted_at ⇒ Object
Returns the value of attribute accepted_at.
30 31 32 |
# File 'lib/spatio-sdk/models/workspace_invitation.rb', line 30 def accepted_at @accepted_at end |
#created_at ⇒ Object
Returns the value of attribute created_at.
28 29 30 |
# File 'lib/spatio-sdk/models/workspace_invitation.rb', line 28 def created_at @created_at end |
#email ⇒ Object
Returns the value of attribute email.
22 23 24 |
# File 'lib/spatio-sdk/models/workspace_invitation.rb', line 22 def email @email end |
#expires_at ⇒ Object
Returns the value of attribute expires_at.
26 27 28 |
# File 'lib/spatio-sdk/models/workspace_invitation.rb', line 26 def expires_at @expires_at end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/spatio-sdk/models/workspace_invitation.rb', line 18 def id @id end |
#revoked_at ⇒ Object
Returns the value of attribute revoked_at.
32 33 34 |
# File 'lib/spatio-sdk/models/workspace_invitation.rb', line 32 def revoked_at @revoked_at end |
#role ⇒ Object
Returns the value of attribute role.
24 25 26 |
# File 'lib/spatio-sdk/models/workspace_invitation.rb', line 24 def role @role end |
#status ⇒ Object
Returns the value of attribute status.
34 35 36 |
# File 'lib/spatio-sdk/models/workspace_invitation.rb', line 34 def status @status end |
#workspace_id ⇒ Object
Returns the value of attribute workspace_id.
20 21 22 |
# File 'lib/spatio-sdk/models/workspace_invitation.rb', line 20 def workspace_id @workspace_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
74 75 76 |
# File 'lib/spatio-sdk/models/workspace_invitation.rb', line 74 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
79 80 81 |
# File 'lib/spatio-sdk/models/workspace_invitation.rb', line 79 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/spatio-sdk/models/workspace_invitation.rb', line 59 def self.attribute_map { :'id' => :'id', :'workspace_id' => :'workspaceId', :'email' => :'email', :'role' => :'role', :'expires_at' => :'expiresAt', :'created_at' => :'createdAt', :'accepted_at' => :'acceptedAt', :'revoked_at' => :'revokedAt', :'status' => :'status' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/spatio-sdk/models/workspace_invitation.rb', line 286 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
99 100 101 102 103 104 105 |
# File 'lib/spatio-sdk/models/workspace_invitation.rb', line 99 def self.openapi_nullable Set.new([ :'expires_at', :'accepted_at', :'revoked_at', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/spatio-sdk/models/workspace_invitation.rb', line 84 def self.openapi_types { :'id' => :'String', :'workspace_id' => :'String', :'email' => :'String', :'role' => :'String', :'expires_at' => :'Time', :'created_at' => :'Time', :'accepted_at' => :'Time', :'revoked_at' => :'Time', :'status' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/spatio-sdk/models/workspace_invitation.rb', line 257 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && workspace_id == o.workspace_id && email == o.email && role == o.role && expires_at == o.expires_at && created_at == o.created_at && accepted_at == o.accepted_at && revoked_at == o.revoked_at && status == o.status end |
#eql?(o) ⇒ Boolean
273 274 275 |
# File 'lib/spatio-sdk/models/workspace_invitation.rb', line 273 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
279 280 281 |
# File 'lib/spatio-sdk/models/workspace_invitation.rb', line 279 def hash [id, workspace_id, email, role, expires_at, created_at, accepted_at, revoked_at, status].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/spatio-sdk/models/workspace_invitation.rb', line 170 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @email.nil? invalid_properties.push('invalid value for "email", email cannot be nil.') end if @role.nil? invalid_properties.push('invalid value for "role", role cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/spatio-sdk/models/workspace_invitation.rb', line 308 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
194 195 196 197 198 199 200 201 202 203 |
# File 'lib/spatio-sdk/models/workspace_invitation.rb', line 194 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @email.nil? return false if @role.nil? return false if @created_at.nil? status_validator = EnumAttributeValidator.new('String', ["pending", "accepted", "revoked", "expired"]) return false unless status_validator.valid?(@status) true end |